@@ -1,7 +1,7 @@
 #!/bin/bash
 #
-# Copyright (c) 2001 SuSE GmbH, Nuernberg, Germany
-# Copyright (c) 2002 SuSE Linux AG, Nuernberg, Germany
+# Copyright (c) 2001 SUSE GmbH, Nuernberg, Germany
+# Copyright (c) 2002 SUSE Linux AG, Nuernberg, Germany
 #
 # Author: Vladimir Linek <vinil@suse.cz>
 # Support for directory listing by Dimitar Pashov <d.pashov@gmail.com>
@@ -105,6 +105,35 @@ test -n "$CMD" && $CMD "$SRC" >"$TMPF_pre" 2>/dev/null
 			# assuming ls is always available
 			ls -lh "$TMPF_pre" >"$TMPF" 2>/dev/null
 			;;
+	        *diff\ output*)
+			# I haven't found way, to set less -R from this script
+			# so check, if '-R' or '--RAW-CONTROL-CHARS' is set in environment
+			R_NOT_SET=true
+			for i in $LESS; do
+				if [ "${i:0:1}" = "-" ]; then
+					if [ "${i:1:1}" = "-" ]; then
+						if [ "$i" = --RAW-CONTROL-CHARS ]; then
+							R_NOT_SET=false
+							break
+						else
+							continue
+						fi
+					else
+						for j in `seq 1 $((${#i} - 1 ))`; do
+							if [ "${i:j:1}" = R ]; then
+								R_NOT_SET=false
+								break
+							fi
+						done
+					fi
+				fi
+			done
+			# if we have -R and colordiff, we can continue
+			if [ $R_NOT_SET = false ] && \
+				[ -x "`which colordiff 2>/dev/null`" ]; then
+			colordiff < "$TMPF_pre" | cat > "$TMPF" 2>/dev/null
+			else rm -f "$TMPF"; TMPF="$TMPF_pre"; fi
+			;;
 		*)
 			if [ "$LESS_ADVANCED_PREPROCESSOR" = "yes" ]; then
 				case ${type#"$TMPF_pre": } in
