@@ -22,15 +22,9 @@ function set_proxy() {
 # If Proxy: is set in install.inf export the env
 # variables for http_proxy and ftp_proxy
 # ---
-	if [ -f /etc/install.inf ];then
-	if grep -qs '^Proxy:.*' /etc/install.inf ; then
-		Proxy=$(awk ' /^Proxy:/ { print $2 }' < /etc/install.inf)
-		ProxyPort=$(awk ' /^ProxyPort:/ { print $2 }' < /etc/install.inf)
-		ProxyProto=$(awk ' /^ProxyProto:/ { print $2 }' < /etc/install.inf)
-		FullProxy="${ProxyProto}://${Proxy}:${ProxyPort}/"
-		export http_proxy=$FullProxy
-		export ftp_proxy=$FullProxy
-	fi
+	if [ "$ProxyURL" ] ; then
+		export http_proxy="$ProxyURL"
+		export ftp_proxy="$ProxyURL"
 	fi
 }
 
@@ -208,12 +202,35 @@ function load_module () {
 	/sbin/modprobe $1
 }
 
-#----[ skip_initvicons ]----#
-function skip_initvicons () {
+#----[ skip_initviocons ]----#
+function skip_initviocons () {
 #------------------------------------------------------
-# check if the call to initvicons must be skipped
+# check if the call to initviocons must be skipped
 # ---
-	# #173426#c17: it is missing on single-CD repos
-	test -x /bin/initviocons || return 1
+	# bnc #173426#c17: it is missing on single-CD repos
+	if [ ! -x /bin/initviocons ] ; then
+		return 0
+	fi
+
+	# initviocons should only be required on consoles, see bnc #800790
+	TTY=`/usr/bin/tty`
+	if [ "$TTY" != "/dev/console" -a "$TTY" == "${TTY#/dev/tty[0-9]}" ] ; then
+		return 0
+	fi
+
 	grep -qw TERM /proc/cmdline && return 0 || return 1
 }
+
+function log_export()
+{
+    IFS_SAVE=$IFS
+    IFS="
+"
+    for i in `export` ; do
+	i=${i//Password=*/Password=\"<Password> (sensitive information)\"}
+	i=${i//RepoURL=*/RepoURL=\"<RepoURL (may contain sensitive information)>\"}
+	i=${i//ZyppRepoURL=*/ZyppRepoURL=\"<ZyppRepoURL (may contain sensitive information)>\"}
+	log "\t$i"
+    done
+    IFS=$IFS_SAVE
+}
