@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use vars '%Config', '$VERSION';
 
-$VERSION = "5.018001";
+$VERSION = "5.020001";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,12 +56,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (5.18.1) doesn't match executable '$0' version ($])"
+die "$0: Perl lib version (5.20.1) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.18.1
-    or die "Perl lib version (5.18.1) doesn't match executable '$0' version (" .
-	sprintf("v%vd",$^V) . ")";
+$^V eq 5.20.1
+    or die sprintf "%s: Perl lib version (5.20.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -85,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib/perl5/5.18.1/x86_64-linux-thread-multi',
+    archlibexp => '/usr/lib/perl5/5.20.1/x86_64-linux-thread-multi',
     archname => 'x86_64-linux-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
@@ -94,19 +93,19 @@ tie %Config, 'Config', {
     dlsrc => 'dl_dlopen.xs',
     dont_use_nlink => undef,
     exe_ext => '',
-    inc_version_list => '5.18.0/x86_64-linux-thread-multi 5.18.0',
+    inc_version_list => '5.20.0/x86_64-linux-thread-multi 5.20.0',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/lib64 /usr/lib64 /usr/local/lib64',
+    libpth => '/usr/local/lib /usr/lib64/gcc/x86_64-suse-linux/4.8/include-fixed /usr/lib64/gcc/x86_64-suse-linux/4.8/../../../../x86_64-suse-linux/lib /usr/lib /lib/../lib64 /usr/lib/../lib64 /lib /lib64 /usr/lib64 /usr/local/lib64',
     osname => 'linux',
-    osvers => '3.4.6-2.10-xen',
+    osvers => '3.16.7-35-default',
     path_sep => ':',
-    privlibexp => '/usr/lib/perl5/5.18.1',
+    privlibexp => '/usr/lib/perl5/5.20.1',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/lib/perl5/site_perl/5.18.1/x86_64-linux-thread-multi',
-    sitelibexp => '/usr/lib/perl5/site_perl/5.18.1',
+    sitearchexp => '/usr/lib/perl5/site_perl/5.20.1/x86_64-linux-thread-multi',
+    sitelibexp => '/usr/lib/perl5/site_perl/5.20.1',
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.18.1',
+    version => '5.20.1',
 };
