@@ -80,7 +80,7 @@ C<< $lines_ref = Bootloader::Core->PrepareMenuFileLines (\@sectinos, \%global, $
 
 C<< $status = Bootloader::Core->UpdateBootloader (); >>
 
-C<< $status = Bootloader::Core->RunCommand ($command, $log_file); >>
+C<< $status = Bootloader::Core->RunCommand ($command, $try); >>
 
 C<< $mapping_ref = Bootloader::Core->GetDeviceMapping (); >>
 
@@ -100,14 +100,6 @@ C<< $canonical = Bootloader::Core->CanonicalPath ($path); >>
 
 C<< $real = Bootloader::Core->RealFileName ($filename); >>
 
-C<< Bootloader::Core->l_debug ($message); >>
-
-C<< Bootloader::Core->l_milestone ($message); >>
-
-C<< Bootloader::Core->l_warning ($message); >>
-
-C<< Bootloader::Core->l_error ($message); >>
-
 C<< $records_ref = Bootloader::Core->GetLogRecords (); >>
 
 C<< Bootloader::Core->MangleSections (\@sections, \%global); >>
@@ -122,6 +114,8 @@ package Bootloader::Core;
 
 use strict;
 
+use base qw ( Bootloader::FileIO Bootloader::Logger );
+
 #constants
 
 my $headline = "# Modified by YaST2. Last modification on ";
@@ -144,59 +138,6 @@ sub trim{
     return $string;
 }
 
-=item
-C<< Bootloader::Core->l_debug ($message); >>
-
-Writes a debug message to the system log buffer.
-
-=cut
-sub l_debug {
-    my $self = shift;
-    my $message = shift;
- 
-    $self->{"logger"}->debug($message);
-}
-
-=item
-C<< Bootloader::Core->l_milestone ($message); >>
-
-Writes a milestone message to the system log buffer.
-
-=cut
-sub l_milestone {
-    my $self = shift;
-    my $message = shift;
- 
-    $self->{"logger"}->milestone($message);
-}
-
-=item
-C<< Bootloader::Core->l_warning ($message); >>
-
-Writes a warning message to the system log buffer.
-
-=cut
-sub l_warning {
-    my $self = shift;
-    my $message = shift;
- 
-    $self->{"logger"}->warning($message);
-}
-
-=item
-C<< Bootloader::Core->l_error ($message); >>
-
-Writes an error message to the system log buffer.
-
-=cut
-sub l_error {
-    my $self = shift;
-    my $message = shift;
-
-    $self->{"logger"}->error($message);
-}
-
-
 =item
 C<< $members_ref = Bootloader::Core->MD2Members ($md_device); >>
 
@@ -225,11 +166,14 @@ name.
 =cut
 
 #string Member2MD (string md_member)
-sub Member2MD {
-    my $self = shift;
-    my $member = shift;
+sub Member2MD
+{
+  my $self = shift;
+  my $member = shift;
 
-    my $find = undef;
+  my $orig = $member;
+
+  my $find = undef;
 
     while ((my $md, my $mem_ref) = each (%{$self->{"md_arrays"}}))
     {
@@ -250,7 +194,10 @@ sub Member2MD {
 	}
       }
     }
-    return $member;
+
+  $self->milestone("$orig => $member");
+
+  return $member;
 }
 
 =item
@@ -303,12 +250,12 @@ sub SplitDevPath {
     my $mp = $path || "/";
     until (exists $self->{"mountpoints"}{$mp}) {
 	unless ($mp =~ s#/[^/]*$##) {
-	    $self->l_error ("Core::SplitDevPath: Cannot get device for $path");
+	    $self->error("Cannot get device for $path");
 	    return undef;
 	}
  	if ($mp eq "") {
 	    unless (exists $self->{"mountpoints"}{"/"}) {
-	    	$self->l_error ("Core::SplitDevPath: Cannot get device for $path, no root mount point set");
+	    	$self->error("Cannot get device for $path, no root mount point set");
 	    	return undef;
 	    }
 	    $mp = "/";
@@ -317,7 +264,7 @@ sub SplitDevPath {
 
     my $dev = $self->{"mountpoints"}{$mp};
     $path =~ s#^$mp/?#/#;
-    $self->l_milestone ("Core::SplitDevPath: $orig was split to $dev + $path");
+    $self->milestone("$orig was split to $dev + $path");
     return ($dev, $path);
 }
 
@@ -338,7 +285,7 @@ sub GetExtendedPartition {
 
     # Check for valid devices
     unless (defined $part_dev and $part_dev =~ m/^\/dev\/[shv]d[a-z](\d+)?$/) {
-	$self->l_milestone ("Core::GetExtendedPartition: Specified device ".
+	$self->milestone("Specified device ".
 	    $part_dev||"undefined partdev".
             " is not valid and cannot be used as base for detecting an
             extended partition on the same disk.");
@@ -817,28 +764,35 @@ C<< $obj_ref = Bootloader::Core->new ($old); >>
 Creates an instance of the Bootloader::Core class.
 Optional parameter 'old' is object reference to former bootloader
 =cut
-sub new {
-    my $self = shift;
-    my $old = shift;
+sub new
+{
+  my $self = shift;
+  my $ref = shift;
+  my $old = shift;
 
-    my $loader = {};
-    # keep old settings if given as parameter
-    if (defined($old)) {
-	foreach my $key (keys %{$old}) {
-	    $loader->{$key} = $old->{$key};
-	}
+  my $loader = {};
+  bless($loader);
+
+  # keep old settings if given as parameter
+  if(defined $old) {
+    $ref->milestone("keeping old settings");
+    for my $key (keys %{$old}) {
+      $loader->{$key} = $old->{$key};
     }
-    $loader->{"logger"} = Bootloader::Logger::instance();
+  }
 
-    bless ($loader);
-    return $loader;
+  # copy log data from Library object
+  $loader->CloneLog($ref);
+
+  return $loader;
 }
 
+
 # list<string> ListFiles ();
 # must be overridden
 sub ListFiles {
     my $self = shift;
-    $self->l_error ("Bootloader::Core::ListFiles: Running generic function, it should never be called");
+    $self->error("Running generic function, it should never be called");
     return [];
 }
 
@@ -857,91 +811,39 @@ sub ListMenuFiles {
     return $self->ListFiles ();
 }
 
-=item
-C<< $files_ref = Bootloader::Core->ReadFiles (\@file_names); >>
-
-Actually reads the files from the disk. As argument, takes a reference
-to the list of file names, returns a hash, where key is file name and value
-a reference to the list of lines of the file.
-
-=cut
-
-# map<string,list<string>> ReadFiles (list<string> files)
-sub ReadFiles {
-    my $self = shift;
-    my @filenames = @{+shift};
-
-    my %files = ();
-    foreach my $filename (@filenames)
-    {
-	my @lines = ();
-	if (not open (FILE, $filename))
-	{
-	    $self->l_error ("Core::ReadFiles: Failed to open $filename") && return undef;
-	}
-	while (my $line = <FILE>)
-	{
-	    chomp $line;
-	    push @lines, $line;
-	}
-	close (FILE);
-	$files{$filename} = \@lines;
-    }
-    return \%files;
-}
 
 =item
 C<< $status = Bootloader::Core->WriteFiles (\%files, $suffix, $menu_only); >>
 
-Writes the files to the disk. As arguments, it takes a reference to a hash,
-where key is file name and value a reference to the list of lines to write
-to the file, and a suffix.
-Does not write the contents directly to the files, but $suffix is
-appended to the file names.
-On success, returns defined value > 0, on fail, returns undef;
+Writes the files to the disk.
+As 1st argument it takes a reference to a hash where the keys are file names and
+values are references to a list of lines to write to the file.
+The 2nd argument is an extra file suffix to append.
+If the 3rd argument is true it only writes those files that ListMenuFiles() returns.
+
+Returns 1 on success, 0 otherwise.
 
 =cut
 
 # boolean WriteFiles (map<string,list<string>>, string suffix, boolean menu_only)
-sub WriteFiles {
-    my $self = shift;
-    my %files = %{+shift};
-    my $suffix = shift || "";
-    my $menu_only = shift || 0;
+sub WriteFiles
+{
+  my $self = shift;
+  my $files = shift;
+  my $suffix = shift;
+  my $menu_only = shift;
+  my $ok = 1;
+  local $_;
 
-    umask 0066;
+  $self->milestone("menu_only = $menu_only, suffix = $suffix, files =", [ sort keys %$files ] );
 
-    my @menu_files = keys (%files);
-    if ($menu_only)
-    {
-	@menu_files = @{$self->ListMenuFiles () || []};
-    }
-    my %menu_files = ();
-    foreach my $mf (@menu_files) {
-	$menu_files{$mf} = 1;
-    }
+  my $files2write = $menu_only ? $self->ListMenuFiles() : [ sort keys %$files ];
 
-    while ((my $filename, my $lines_ref) = each (%files))
-    {
-	if (! defined ($menu_files{$filename}))
-	{
-	    $self->l_milestone ("Core::WriteFiles: Not writing $filename");
-	    next;
-	}
+  for (@$files2write) {
+    $ok &= $self->WriteFile($_ . $suffix, $files->{$_}) if exists $files->{$_};
+  }
 
-	$filename = "$filename$suffix";
-	if (not open (FILE, ">$filename"))
-	{
-	    $self->l_error ("Core::WriteFiles: Failed to open $filename") && return undef;
-	}
-	my @lines = @{$lines_ref};
-	foreach my $line (@lines)
-	{
-	    print FILE "$line\n";
-	};
-	close (FILE);
-    }
-    return 1;
+  return $ok;
 }
 
 =item
@@ -957,7 +859,7 @@ sub CompleteSection($) {
 
   unless (defined $info->{"__handled"})
   {
-    $self->l_milestone("Core::CompleteSection: Add missing handled section");
+    $self->milestone("Add missing handled section");
     if ($info->{"type"} eq "image"
       || $info->{"type"} eq "xen")
     {
@@ -1053,13 +955,13 @@ sub UpdateSectionNameLine {
           my $flavor = $section->{"__flavor"};
           my $comment = sprintf($auto_comment_write, $original_name, $flavor);
 	  push @comment_before, $comment;
-          $self->l_milestone( "Core::UpdateSectionNameLine: section name: $name comment: $comment" );
+          $self->milestone("section name: $name comment: $comment" );
         }
         elsif( $section->{"__handled"} eq "manual")
         {
           my $comment = sprintf($manual_comment_write, $original_name);
 	  push @comment_before, $comment;
-          $self->l_milestone( "Core::UpdateSectionNameLine: section name: $name comment: $comment" );
+          $self->milestone("section name: $name comment: $comment" );
         }
 =cut
 	$line_ref->{"comment_before"} = \@comment_before;
@@ -1103,7 +1005,7 @@ sub CreateRemovedDefaultLine {
 
     push @comment_before, "${remove_default_comment}";
 
-    $self->l_milestone("Core::CreateRemovedDefaultLine: put removed default comment");
+    $self->milestone("put removed default comment");
 		
     $line_ref->{"comment_before"} = \@comment_before;
 
@@ -1308,7 +1210,7 @@ sub Info2Section {
 	}
         else
         {
-          $self->l_milestone ("Core::Info2Section: Unknown key $key with value $value");
+          $self->milestone("Unknown key $key with value $value");
         }
     }
 
@@ -1560,8 +1462,9 @@ sub MarkInitialSection {
     return \@sects;
 }
 
+
 =item
-C<< ($global_ref, $sections_ref) Bootloader::Core->ParseMenuFileLines ($separator, \@start_keys, \@lines); >>
+C<< ($global_ref, $sections_ref) Bootloader::Core->ParseMenuFileLines($separator, \@start_keys, \@lines); >>
 
 Parses the lines of the file containing the bootloader menu, and creates the hashes representing
 the global settings and the sections. As arguments takes the separator of the key and value in the
@@ -1572,44 +1475,44 @@ reference to a hash representing global options and reference to a list represen
 
 # (map<string,any> global, list<map<string,any>> sections) ParseMenuFileLines
 #   (string separator, list<string> section_start_keys, list<string> lines)
-sub ParseMenuFileLines {
-    my $self = shift;
-    my $separator = shift;
-    my $section_starts_ref = shift;
-    my @lines = @{+shift};
+sub ParseMenuFileLines
+{
+  my $self = shift;
+  my $separator = shift;
+  my $section_starts_ref = shift;
+  my @lines = @{+shift};
 
-    @lines = $self->ProcessMenuFileLines (\@lines, $separator);
-    my @sects = @{$self->SplitLinesToSections (\@lines,
-	$section_starts_ref)};
-    my @global = @{+shift @sects};
+  @lines = $self->ProcessMenuFileLines (\@lines, $separator);
+  my @sects = @{$self->SplitLinesToSections (\@lines, $section_starts_ref)};
+  my @global = @{+shift @sects};
 
-    @sects = map {
-	$self->l_milestone ("Core::ParseMenuFileLines: section lines to convert :\n'" .
-			join("'\n' ",
-			     map {
-				 $_->{"key"} . " => " . $_->{"value"};
-			     } @{$_}) . "'"
-			);
-	my $s = $self->Section2Info ($_);
-	$self->l_milestone ("Core::ParseMenuFileLines: parsing result :\n'" .
-			join("'\n' ",
-			     map {
-				 m/^__/ ? () : $_ . " => '" . $s->{$_} . "'";
-			     } keys %{$s}) . "'"
-			);
-	$s;
-    } @sects;
+  @sects = map {
+    $self->milestone(
+      "section lines to convert:\n\{\n" .
+      join("\n", map { "  '$_->{key}'" . " => " . "'$_->{value}'," } @$_) .
+      "\n\}"
+    );
 
-    $self->MangleSections(\@sects, \@global);
-    my @sect_names = map {
-	$_->{"name"} || "";
-    } @sects;
-    my %global = %{$self->Global2Info (\@global, \@sect_names)};
-    @sects = @{$self->MarkInitialSection (\@sects, $global{"default"} || "")};
+    my $s = $self->Section2Info($_);
 
-    return (\%global, \@sects);
+    $self->milestone(
+      "parsing result:\n\{\n" .
+      join("\n", map { m/^__/ ? () : "  '$_'" . " => " . "'$s->{$_}'," } keys %$s) .
+      "\n\}"
+    );
+
+    $s;
+  } @sects;
+
+  $self->MangleSections(\@sects, \@global);
+  my @sect_names = map { $_->{name} || "" } @sects;
+  my %global = %{$self->Global2Info (\@global, \@sect_names)};
+  @sects = @{$self->MarkInitialSection (\@sects, $global{default} || "")};
+
+  return (\%global, \@sects);
 }
 
+
 =item
 C<< $lines_ref = Bootloader::Core->PrepareMenuFileLines (\@sectinos, \%global, $indent, $separator); >>
 
@@ -1648,7 +1551,7 @@ sub PrepareMenuFileLines {
 # must be overridden
 sub ParseLines {
     my $self = shift;
-    $self->l_error ("Bootloader::Core::ParseLines: Running generic function, it should never be called");
+    $self->error("Running generic function, it should never be called");
     return undef;
 }
 
@@ -1656,7 +1559,7 @@ sub ParseLines {
 # must be overridden
 sub CreateLines {
     my $self = shift;
-    $self->l_error ("Bootloader::Core::CreateLines: Running generic function, it should never be called");
+    $self->error("Running generic function, it should never be called");
     return {};
 }
 
@@ -1668,77 +1571,94 @@ up and replaces them with the ones with the '.new' suffix. If other operations
 are needed to make the change effect, they must be done
 in the loader-specific package (eg. not needed for GRUB, run
 '/sbin/lilo' for LILO).
-Returns undef on fail, defined nonzero value on success.
+Returns undef on fail, 1 on success.
 
 =cut
 
 # boolean UpdateBootloader ()
-sub UpdateBootloader {
-    my $self = shift;
+sub UpdateBootloader
+{
+  my $self = shift;
 
-    my $files_ref = $self->ListFiles ();
-    my @files = @{$files_ref};
-    my $ok = 1;
-    foreach my $file (@files) {
-	if ( -f "$file.new" ) {
-            #backup file only if they exist and previos backup is enought old
-            # 6 hours
-            if (-f "$file")
-            {
-              if (-f "$file.old")
-              {
-                my $mtime = time - ( stat("$file.old"))[9];
-                my $hours = $mtime / 3600;
-                if ($hours > 6) 
-                {
-	          rename "$file", "$file.old";
-                }
-              }
-              else
-              {
-	        rename "$file", "$file.old";
-              }
-            }
-	    unless ( rename "$file.new",  "$file" ) {
-		$self->l_error ("Core::UpdateBootloader: Error occurred while updating file $file");
-		$ok = undef;
-	    }
-	}
+  my $files_ref = $self->ListFiles();
+  my @files = @{$files_ref};
+  my $ok = 1;
+
+  $self->milestone("Files to update:", $files_ref);
+
+  foreach my $file (@files) {
+    next unless -f "$file.new";
+
+    # backup file only if is exists and previos backup is older than 6 hours
+    if(-f $file) {
+      if(-f "$file.old") {
+        my $mtime = time - (stat "$file.old")[9];
+        if($mtime > 6 * 3600) {
+          rename $file, "$file.old";
+          $self->milestone("rename $file -> $file.old");
+        }
+      }
+      else {
+        rename $file, "$file.old";
+        $self->milestone("rename $file -> $file.old");
+      }
     }
-    return $ok;
+
+    $self->milestone("rename $file.new -> $file");
+
+    if(!rename("$file.new", $file)) {
+      $self->error("Error occurred while updating $file: $!");
+      $ok = undef;
+    }
+  }
+
+  return $ok;
 }
 
 =item
-C<< $status = Bootloader::Core->RunCommand ($command, $log_file); >>
+C<< $status = Bootloader::Core->RunCommand ($command, $try); >>
 
-Runs specified command. If log file is defined, its stdout and stderr
-are appended to the log file.
-As arguments, takes the command end the log file name. Returns
-exit code of the command.
+Runs specified command.
+If $try is set, ignores command errors and returns 0.
+Otherwise it returns the exit code of the command.
+command, exit code, and output are stored internally in $self->{last_command}.
 
 =cut
 
-# integer RunCommand (string command, string log_file)
-sub RunCommand {
-    my $self = shift;
-    my $command = shift;
-    my $log = shift;
+# integer RunCommand (string command, integer try)
+sub RunCommand
+{
+  my $self = shift;
+  my $command = shift;
+  my $try = shift;
 
-    if (defined ($log))
-    {
-	$command = "$command >$log 2>&1";
-    }
-    else
-    {
-	$command = "$command >/dev/null 2>/dev/null";
-    }
-    my $ret = system ($command);
+  my $ret;
+  my $output;
 
-    my $output = `cat $log`;
-    $self->l_milestone("run $command - ret $ret + output: $output");
-    $self->l_error("Command '$command' failed with code $ret and output: $output") unless $ret == 0;
+  if(open my $f, "($command) 2>&1 |") {
+    local $/;
+    $output = <$f>;
+    close $f;
+    $ret = $? >> 8;
+    chomp $output;
+    $output .= "\n";
+  }
+  else {
+    $ret = 127;
+    $output = "$command: " . ($! == 13 ? $! : "command not found") . " \n";
+  }
 
-    return $ret;
+  $self->{last_command} = { cmd => $command, exit => $ret, out => $output};
+
+  if(!$ret || $try) {
+    $self->milestone("'$command' = $ret, output:", $output);
+    $ret = 0;
+  }
+  else {
+    $self->error("'$command' failed with exit code $ret, output:", $output);
+  }
+
+  return $ret;
 }
 
 =item
@@ -1772,10 +1692,10 @@ sub SetDeviceMapping {
     my $self = shift;
     my $devmap_ref = shift;
 
-    $self->l_debug ("Core::SetDeviceMapping: called.");
+    $self->debug("TRACE");
     $self->{"device_map"} = $devmap_ref;
     while  ( my ($key, $value) = each (%$devmap_ref)){
-        $self->l_milestone ("Core::SetDeviceMapping: device_mapping: $key <=> $value");
+        $self->milestone("device_mapping: $key <=> $value");
     }
     return 1;
 }
@@ -1789,35 +1709,22 @@ from the system, but returns internal structures.
 =cut
 
 # map<string,any> GetSettings ()
-sub GetSettings {
-    my $self = shift;
+sub GetSettings
+{
+  my $self = shift;
 
-    my %ret = ();
-    foreach my $key ("global", "exports", "sections", "device_map")
-    {
-	if (defined ($self->{$key}))
-	{
-	    $ret{$key} = $self->{$key};
-            if ($key eq "sections")
-            {
-              foreach my $section (@{$ret{$key}})
-              {
-                $self->l_milestone ("Core::GetSettings: store: $key:" . join( " - ", %{$section}));
-              }
-            }
-            elsif ($key eq "global" or $key eq "device_map")
-            {
-              $self->l_milestone ("Core::GetSettings: store: $key:" . join( ",", %{$ret{$key}}));
-            }
-            else
-            {
-              $self->l_milestone ("Core::GetSettings: store: $key:" . join( ",", $ret{$key}));
-            }
-	}
-    }
-    return \%ret;
+  my $ret = {};
+
+  for ("global", "exports", "sections", "device_map") {
+    $ret->{$_} = $self->{$_} if defined $self->{$_};
+  }
+
+  $self->milestone("ret =", $ret);
+
+  return $ret;
 }
 
+
 =item
 C<< $status = Bootloader::Core->SetSettings (\%settings); >>
 
@@ -1841,16 +1748,16 @@ sub SetSettings {
             {
               foreach my $section (@{$settings{$key}})
               {
-                $self->l_milestone ("Core::SetSettings: store: $key:" . join( " - ", %{$section}||""));
+                $self->milestone("store: $key:" . join( " - ", %{$section}||""));
               }
             }
             elsif ($key eq "global" or $key eq "device_map")
             {
-              $self->l_milestone ("Core::SetSettings: store: $key:" . join( ",", %{$settings{$key}} || ""));
+              $self->milestone("store: $key:" . join( ",", %{$settings{$key}} || ""));
             }
             else
             {
-              $self->l_milestone ("Core::SetSettings: store: $key:" . join( ",", $settings{$key}||""));
+              $self->milestone("store: $key:" . join( ",", $settings{$key}||""));
             }
         }
     }
@@ -1897,7 +1804,7 @@ sub SymlinkCrossesDevice($$) {
 
     my ($dev_file,)  = stat($path);
     my ($dev_symlink,) = lstat($path);
-    $self->l_milestone ("Core::SymlinkCrossesDevice: dev_file: $dev_file, dev_symlink: $dev_symlink");
+    $self->milestone("dev_file: $dev_file, dev_symlink: $dev_symlink");
 
     if (defined ($dev_file) && defined ($dev_symlink))
     {
@@ -1923,25 +1830,25 @@ sub ResolveCrossDeviceSymlinks($$) {
     my $readlink;
 
     while ($path =~ s#^(/*)[^/]+##) {
-	$self->l_milestone ("Core::ResolveCrossDeviceSymlinks: path: $path, \$1: $1, \$&: $&");
+	$self->milestone("path: $path, \$1: $1, \$&: $&");
 
 	my $here = $self->ConcatPath($resolved, $&);
-	$self->l_milestone ("Core::ResolveCrossDeviceSymlinks: here: $here, resolved: $resolved");
+	$self->milestone("here: $here, resolved: $resolved");
 
 	if (-l $here && ($readlink = readlink $here) =~ /\//) {
-	    $self->l_milestone ("Core::ResolveCrossDeviceSymlinks: readlink: $readlink");
+	    $self->milestone("readlink: $readlink");
 	    $resolved = ""
 	    	if ($readlink =~ m#^/#);
-	    $self->l_milestone ("Core::ResolveCrossDeviceSymlinks: \$&: $&");
+	    $self->milestone("\$&: $&");
 	    $path = $self->ConcatPath(($1 || '') . $readlink, $path);
-	    $self->l_milestone ("Core::ResolveCrossDeviceSymlinks: path: $path, \$1: $1");
+	    $self->milestone("path: $path, \$1: $1");
 	    next;
 	}
 	$resolved = $self->ConcatPath($resolved, $&);
-	$self->l_milestone ("Core::ResolveCrossDeviceSymlinks: resolved: $path, \$&: $&");
+	$self->milestone("resolved: $path, \$&: $&");
     }
     $resolved = $self->ConcatPath($resolved, $path);
-    $self->l_milestone ("Core::ResolveCrossDeviceSymlinks: returns resolved: $resolved, path: $path");
+    $self->milestone("returns resolved: $resolved, path: $path");
     return $self->CanonicalPath($resolved);
 }
 
@@ -1964,7 +1871,7 @@ sub CanonicalPath($$) {
     while ($path =~ s#/[^/]+/\.\.(/|$)#$1#) { }
     while ($path =~ s#/\.(/|$)#$1#) { }
     while ($path =~ s#//#/#) { }
-    $self->l_milestone ("Core::CanonicalPath: ret path: $path");
+    $self->milestone("ret path: $path");
     return $path;
 }
 
@@ -1987,14 +1894,14 @@ sub RealFileName {
     my $ret = "";
     if ($self->{"resolve_symlinks"})
     {
-	$self->l_milestone ("Core::RealFileName: resolve_symlinks:" . $self->{"resolve_symlinks"});
+	$self->milestone("resolve_symlinks:" . $self->{"resolve_symlinks"});
 	$ret = $self->CanonicalPath($self->ResolveCrossDeviceSymlinks ($filename));
     }
     else
     {
 	$ret = $self->CanonicalPath($filename);
     }
-    $self->l_milestone ("Core::RealFileName: Filename $filename after resolving symlinks: $ret");
+    $self->milestone("Filename $filename after resolving symlinks: $ret");
     return $ret;
 }
 
