@@ -67,6 +67,8 @@ C<< $result = Bootloader::Library::DetectThinkpadMBR ($disk); >>
 
 C<< $result = Bootloader::Library::WriteThinkpadMBR ($disk); >>
 
+C<< $status = Bootloader::Library->SetSecureBoot ($enable); >>
+
 =head1 DESCRIPTION
 
 =over 2
@@ -80,8 +82,14 @@ use strict;
 
 use Bootloader::Core;
 use Bootloader::MBRTools;
-use Bootloader::Logger;
+use Bootloader::Path;
 
+use base qw ( Bootloader::MBRTools Bootloader::FileIO Bootloader::Logger );
+
+our $VERSION = "0.826";
+
+my $instances = 0;
+my $global_id;
 
 =item
 C<< $obj_ref = Bootloader::Library->new (); >>
@@ -89,18 +97,61 @@ C<< $obj_ref = Bootloader::Library->new (); >>
 Creates an instance of the Bootloader::Library class.
 
 =cut
-sub new {
-    my $self = shift;
+sub new
+{
+  my $self = shift;
 
-    my $lib = {};
-    bless ($lib);
-    return $lib;
-}
+  my $lib = {};
+  bless ($lib);
 
-sub GetLogRecords {
-    my $self = shift;
-  
-    return Bootloader::Logger::instance()->GetLogRecords();
+  my ($c0, $c1, $c2);
+
+  $c0 = (caller(0))[0];
+
+  my $idx = 0;
+  while($c1 = (caller($idx))[1]) { $c2 = $c1; $idx++ }
+
+  ($c1 = $c2) =~ s#.*/##;
+
+  my $name = 'xxx';
+
+  if($c1 eq 'Bootloader_API.pm') {
+    $name = 'yast';
+  }
+  elsif($c1 eq 'update-bootloader') {
+    $name = 'pbl';
+  }
+  elsif($c1 eq 'pbl-yaml') {
+    $name = 'pbl-yaml';
+  }
+  elsif($c0 eq 'Bootloader::Tools') {
+    $name = 'libpbl';
+  }
+
+  $global_id = $name . sprintf("-%04d.", int rand 10000) unless defined $global_id;
+  $lib->{session_id} = $global_id . ++$instances;
+
+  # find root device & detect if we are chroot-ed
+  my $r = "?";
+  my @r0 = stat "/";
+  my @r1 = stat "/proc/1/root";
+  if(@r0 && @r1) {
+    my $r0 = ($r0[0] >> 8) . ":" . ($r0[0] & 0xff);
+    $r = readlink "/dev/block/$r0";
+    $r =~ s#^..#/dev# if defined $r;
+    $r = $r0 unless defined $r;
+    if($r0[0] != $r1[0] || $r0[1] != $r1[1]) {
+      $r .= " (chroot)";
+    }
+  }
+
+  my $l = "$lib->{session_id} = $c2 (via $c0), version = $VERSION, root = $r";
+
+  $lib->StartLog();
+
+  $lib->milestone($l);
+
+  return $lib;
 }
 
 =item
@@ -120,73 +171,67 @@ EXAMPLE:
 
 =cut
 
-sub SetLoaderType {
-    my $self = shift;
-    my $bootloader = shift;
-    my $arch = shift;
+sub SetLoaderType
+{
+  my $self = shift;
+  my $bootloader = shift;
+  my $arch = shift;
 
-    my $loader = exists $self->{"loader"} ? $self->{"loader"} : undef;
+  my $loader = exists $self->{loader} ? $self->{loader} : undef;
 
-    if ($bootloader eq "grub")
-    {
-        require Bootloader::Core::GRUB;
-	$loader = Bootloader::Core::GRUB->new ($loader);
+  if($bootloader eq "grub") {
+    require Bootloader::Core::GRUB;
+    $loader = Bootloader::Core::GRUB->new($self, $loader);
+  }
+  elsif($bootloader eq "grub2") {
+    require Bootloader::Core::GRUB2;
+    $loader = Bootloader::Core::GRUB2->new($self, $loader);
+  }
+  elsif($bootloader eq "grub2-efi") {
+    require Bootloader::Core::GRUB2EFI;
+    $loader = Bootloader::Core::GRUB2EFI->new($self, $loader);
+  }
+  elsif($bootloader eq "lilo") {
+    require Bootloader::Core::LILO;
+    $loader = Bootloader::Core::LILO->new($self, $loader);
+  }
+  elsif($bootloader eq "elilo") {
+    require Bootloader::Core::ELILO;
+    unless (defined $arch) {
+      $self->warning("Missing arch for elilo, using ia64.");
+      $arch = "ia64";
     }
-    elsif ($bootloader eq "grub2")
-    {
-        require Bootloader::Core::GRUB2;
-	$loader = Bootloader::Core::GRUB2->new ($loader);
+    $loader = Bootloader::Core::ELILO->new($self, $loader, $arch);
+  }
+  elsif($bootloader eq "zipl") {
+    require Bootloader::Core::ZIPL;
+    $loader = Bootloader::Core::ZIPL->new($self, $loader);
+  }
+  elsif($bootloader eq "ppc") {
+    require Bootloader::Core::PowerLILO;
+    unless (defined $arch) {
+      $self->warning("Missing subarch for powerlilo, using chrp.");
+      $arch = "chrp";
     }
-    elsif ($bootloader eq "grub2-efi")
-    {
-        require Bootloader::Core::GRUB2EFI;
-        $loader = Bootloader::Core::GRUB2EFI->new ($loader);
+    $loader = Bootloader::Core::PowerLILO->new($self, $loader, $arch);
+  }
+  else {
+    $bootloader = "none" if $bootloader eq "";
+    if($bootloader ne "none") {
+      $self->error("Initializing for unknown bootloader $bootloader, fallback to none");
     }
-    elsif ($bootloader eq "lilo")
-    {
-        require Bootloader::Core::LILO;
-	$loader = Bootloader::Core::LILO->new ($loader);
-    }
-    elsif ($bootloader eq "elilo")
-    {
-        require Bootloader::Core::ELILO;
-        unless (defined $arch)
-        {
-          Bootloader::Logger::instance()->warning("Bootloader::Library::SetLoaderType: Missing arch for elilo.");
-          $arch = "ia64";
-        }
-        $loader = Bootloader::Core::ELILO->new ($loader,$arch);
-    }
-    elsif ($bootloader eq "zipl")
-    {
-        require Bootloader::Core::ZIPL;
-        $loader = Bootloader::Core::ZIPL->new ($loader);
-    }
-    elsif ($bootloader eq "ppc")
-    {
-        require Bootloader::Core::PowerLILO;
-        unless (defined $arch)
-        {
-          Bootloader::Logger::instance()->warning("Bootloader::Library::SetLoaderType: Missing subarch for powerlilo.");
-          $arch = "chrp";
-        }
-	$loader = Bootloader::Core::PowerLILO->new ($loader,$arch);
-    }
-    elsif ($bootloader eq "none")
-    {
-        require Bootloader::Core::NONE;
-	$loader = Bootloader::Core::NONE->new ($loader);
-    }
-    else
-    {
-        require Bootloader::Core::NONE;
-	$loader = Bootloader::Core::NONE->new ($loader);
-        Bootloader::Logger::instance()->error("Bootloader::Library::SetLoaderType: Initializing for unknown bootloader $bootloader, fallback to none");
+    else {
+      $self->warning("no bootloader type specified");
     }
 
-    $self->{"loader"} = $loader;
-    Bootloader::Logger::instance()->milestone ("Bootloader::Library::SetLoaderType: TRACE new $bootloader");
-    return 1;
+    require Bootloader::Core::NONE;
+    $loader = Bootloader::Core::NONE->new ($self, $loader);
+  }
+
+  $self->{loader} = $loader;
+  $self->milestone("loader = $bootloader");
+
+  return 1;
 }
 
 =item
@@ -208,26 +253,29 @@ EXAMPLE:
 
 =cut
 
-sub DefineMountPoints {
-    my $self = shift;
-    my $mountpoints_ref = shift;
+sub DefineMountPoints
+{
+  my $self = shift;
+  my $mountpoints_ref = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    while ((my $mp, my $dev) = each (%{$mountpoints_ref}))
-    {
-	Bootloader::Logger::instance()->milestone ("Library::DefineMountPoints: Mount point: $mp ; Device: $dev");
-    }
-    $loader->{"mountpoints"} = $mountpoints_ref;
-    return 1;
+  delete $loader->{cache};
+
+  $loader->{mountpoints} = $mountpoints_ref;
+
+  $self->milestone("mountpoints =", $loader->{mountpoints});
+
+  return 1;
 }
 
+
 sub GetMountPoints {
     my $self = shift;
 
     my $loader = $self->{"loader"};
-    Bootloader::Logger::instance()->milestone ("Library::GetMountPoints: TRACE");
+    $self->milestone ("TRACE");
     return $loader->{"mountpoints"};
 }
 
@@ -251,22 +299,21 @@ EXAMPLE:
 
 =cut
 
-sub DefinePartitions {
-    my $self = shift;
-    my $partitions_ref = shift;
+sub DefinePartitions
+{
+  my $self = shift;
+  my $partitions_ref = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    foreach my $part_ref (@{$partitions_ref})
-    {
-	my ($part, $disk, $num, @part_info ) = @{$part_ref};
-	Bootloader::Logger::instance()->milestone ("Library::DefinePartitions: Partition: $part ; " .
-			  "Disk: $disk ; Number: $num ; Info: " .
-			  join(", ", map { "$_"; } @part_info) );
-    }
-    $loader->{"partitions"} = $partitions_ref;
-    return 1;
+  delete $loader->{cache};
+
+  $loader->{partitions} = $partitions_ref;
+
+  $self->milestone("partitions [dev, disk, nr, fsid, fstype, part_type, start_cyl, end_cyl, label] =", $loader->{partitions});
+
+  return 1;
 }
 
 =item
@@ -292,20 +339,21 @@ EXAMPLE:
 
 =cut
 
-sub DefineMDArrays {
-    my $self = shift;
-    my $md_arrays_ref = shift;
+sub DefineMDArrays
+{
+  my $self = shift;
+  my $md_arrays_ref = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    while ((my $md, my $members_ref) = each (%{$md_arrays_ref}))
-    {
-	my $members = join ", ", @{$members_ref};
-	Bootloader::Logger::instance()->milestone ("Library::DefineMDArrays: MD Array: $md ; Members: $members");
-    }
-    $loader->{"md_arrays"} = $md_arrays_ref;
-    return 1;
+  delete $loader->{cache};
+
+  $loader->{md_arrays} = $md_arrays_ref;
+
+  $self->milestone("md_arrays =", $loader->{md_arrays});
+
+  return 1;
 }
 
 =item
@@ -328,23 +376,26 @@ EXAMPLE:
 
 =cut
 
-sub DefineMultipath {
-    my $self = shift;
-    my $mp_ref = shift;
+sub DefineMultipath
+{
+  my $self = shift;
+  my $mp_ref = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    while ((my $phys, my $mp) = each (%{$mp_ref}))
-    {
-	Bootloader::Logger::instance()->milestone ("Library::DefineMultipath: Real device: $phys ;  multipath $mp");
-    }
-    $loader->{"multipath"} = $mp_ref;
-    return 1;
+  delete $loader->{cache};
+
+  $loader->{multipath} = $mp_ref;
+
+  $self->milestone("multipath [real_dev, mp_dev] =", $loader->{multipath});
+
+  return 1;
 }
 
+
 =item
-C<< $status = Bootloader::Library->DefineMultipath (\%multipath); >>
+C<< $status = Bootloader::Library->DefineUdevMapping (\%udevmap); >>
 
 Define udev mapping of devices.
 We only need information for GRUB to translate udev device to kernel and then to grub device.
@@ -362,21 +413,51 @@ EXAMPLE:
 
 =cut
 
-sub DefineUdevMapping($) {
+sub DefineUdevMapping($)
+{
+  my $self = shift;
+  my $map_ref = shift;
+
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
+
+  delete $loader->{cache};
+
+  $loader->{udevmap} = $map_ref;
+
+  $self->milestone("udevmap =", $loader->{udevmap});
+
+  return 1;
+}
+
+=item
+C<< $status = Bootloader::Library->SetSecureBoot ($enable); >>
+
+Set the SecureBoot Setting
+
+=cut
+
+sub SetSecureBoot
+{
     my $self = shift;
-    my $map_ref = shift;
+    my $sb = shift;
 
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    while ((my $phys, my $mp) = each (%{$map_ref}))
+    delete $loader->{cache};
+
+    if (defined $sb)
     {
-	Bootloader::Logger::instance()->milestone ("Library::DefineUdevMapping: Udev device: ".($phys||"")." ;  kernel: ".($mp||"")."");
+        $loader->{"secure_boot"} = $sb;
+        $self->milestone("secure_boot =", $sb);
     }
 
-  $loader->{"udevmap"} = $map_ref;
-  return 1;
+    $self->milestone(" TRACE ");
+
+    return 1;
 }
+
 =item
 C<< $status = Bootloader::Library->ReadSettings (); >>
 
@@ -400,7 +481,7 @@ sub ReadSettings {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone( "Library::ReadSettings: TRACE" );
+    $self->milestone( "TRACE" );
     my $files_ref = $loader->ReadFiles ($loader->ListFiles ());
     if (! defined ($files_ref))
     {
@@ -428,21 +509,27 @@ EXAMPLE:
 
 =cut
 
-sub WriteSettings {
-    my $self = shift;
-    my $menu_only = shift;
+sub WriteSettings
+{
+  my $self = shift;
+  my $menu_only = shift || 0;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone(" Library::WriteSettings: TRACE menu_only:". ($menu_only || "undefined"));
-    $loader->{"resolve_symlinks"} = 1;
-    my $new_lines_ref = $loader->CreateLines ();
-    if (! defined ($new_lines_ref))
-    {
-	return undef;
-    }
-    return $loader->WriteFiles ($new_lines_ref, ".new", $menu_only);
+  $self->milestone("creating config files");
+
+  $loader->{resolve_symlinks} = 1;
+  my $new_lines_ref = $loader->CreateLines();
+
+  if(!defined $new_lines_ref) {
+    $self->warning("no config created - nothing written");
+    return undef;
+  }
+
+  $self->milestone("writing config files (menu_only = $menu_only)");
+
+  return $loader->WriteFiles($new_lines_ref, ".new", $menu_only);
 }
 
 =item
@@ -468,7 +555,7 @@ sub ReadSettingsTmp {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone(" Library::ReadSettingsTmp: TRACE tmp_dir $tmp_dir ");
+    $self->milestone("TRACE tmp_dir $tmp_dir ");
 
     my @files = @{$loader->ListFiles ()};
     my %filenames = ();
@@ -516,7 +603,7 @@ sub WriteSettingsTmp {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone(" Library::WriteSettingsTmp: TRACE tmp_dir $tmp_dir ");
+    $self->milestone("TRACE tmp_dir $tmp_dir ");
 
     my $new_lines_ref = $loader->CreateLines ();
     if (! defined ($new_lines_ref))
@@ -560,20 +647,20 @@ sub GetFilesContents {
     if (! defined $loader or $loader eq "none") {
 	return undef;
     }
-    my $logger = Bootloader::Logger::instance();
-    $logger->milestone(" Library::GetFilesContents TRACE ");
+    $self->milestone("TRACE ");
 
     $loader->{"resolve_symlinks"} = 0;
     my $new_lines_ref = $loader->CreateLines ();
     if (! defined ($new_lines_ref))
     {
-	$logger->error ("Library::GetFileContents: Error while getting files contents occurred");
+	$self->error ("Library::GetFileContents: Error while getting files contents occurred");
 	return undef;
     }
     my %files = ();
     while ((my $fn, my $lines_ref) = each (%{$new_lines_ref}))
     {
 	$files{$fn} = join "\n", @{$lines_ref};
+	$files{$fn} .= "\n";
     }
     return \%files;
 }
@@ -594,7 +681,7 @@ sub SetFilesContents {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone(" Library::SetFilesContents TRACE ");
+    $self->milestone("TRACE ");
 
     my %lines = ();
     while ((my $fn, my $contents) = each (%{$files_ref}))
@@ -625,18 +712,21 @@ EXAMPLE:
 
 =cut
 
-sub UpdateBootloader {
-    my $self = shift;
-    my $avoid_init = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+sub UpdateBootloader
+{
+  my $self = shift;
+  my $avoid_init = shift;
 
-    Bootloader::Logger::instance()->milestone("Library::UpdateBootloader: TRACE avoid_init ".($avoid_init||""));
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    return $loader->UpdateBootloader ($avoid_init);
+  $self->milestone("avoid_init = $avoid_init");
+
+  return $loader->UpdateBootloader($avoid_init);
 }
 
+
 =item
 C<< $status = Bootloader::Library->InitializeBootloader (); >>
 
@@ -659,7 +749,7 @@ sub InitializeBootloader {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone( "Library::InitializeBootloader: TRACE");
+    $self->milestone( "TRACE");
 
     return $loader->InitializeBootloader ();
 }
@@ -690,7 +780,7 @@ sub ListConfigurationFiles {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone( "Library::ListConfigurationFiles TRACE");
+    $self->milestone( "TRACE");
 
     return $loader->ListFiles ();
 }
@@ -707,16 +797,17 @@ EXAMPLE:
 
 =cut
 
-sub GetSettings {
-    my $self = shift;
+sub GetSettings
+{
+  my $self = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone( "Library::GetSettings TRACE");
-    return $loader->GetSettings ();
+  return $loader->GetSettings();
 }
 
+
 =item
 C<< $status = Bootloader::Library->SetSettings (); >>
 
@@ -729,16 +820,15 @@ EXAMPLE:
 
 =cut
 
-sub SetSettings {
-    my $self = shift;
-    my $settings_ref = shift;
+sub SetSettings
+{
+  my $self = shift;
+  my $settings_ref = shift;
 
-    my $loader = $self->{"loader"};
-    return undef unless defined $loader;
+  my $loader = $self->{loader};
+  return undef unless defined $loader;
 
-    Bootloader::Logger::instance()->milestone( "Library::SetSettings TRACE");
-
-    return $loader->SetSettings ($settings_ref);
+  return $loader->SetSettings($settings_ref);
 }
 
 # wrappers for easier use
@@ -764,15 +854,16 @@ EXAMPLE:
 
 =cut
 
+# return empty array if none were read, not undef
 sub GetSections {
     my $self = shift;
 
     my $settings_ref = $self->GetSettings ();
     if (! defined ($settings_ref))
     {
-	return undef;
+	return [];
     }
-    return $settings_ref->{"sections"};
+    return $settings_ref->{"sections"} || [];
 }
 
 =item
@@ -861,15 +952,14 @@ EXAMPLE:
 
 =cut
 
-sub SetSections {
-    my $self = shift;
-    my $sections_ref = shift;
+sub SetSections
+{
+  my $self = shift;
+  my $sections_ref = shift;
 
-    my %settings = (
-	"sections" => $sections_ref
-    );
-    return $self->SetSettings (\%settings)
+  $self->milestone("updating sections");
 
+  return $self->SetSettings({sections => $sections_ref});
 }
 
 =item
@@ -894,14 +984,14 @@ EXAMPLE:
   }
 
 =cut
-sub SetGlobalSettings {
-    my $self = shift;
-    my $global_ref = shift;
+sub SetGlobalSettings
+{
+  my $self = shift;
+  my $global_ref = shift;
 
-    my %settings = (
-	"global" => $global_ref
-    );
-    return $self->SetSettings (\%settings)
+  $self->milestone("updating global settings");
+
+  return $self->SetSettings({global => $global_ref});
 }
 
 =item
@@ -950,7 +1040,7 @@ sub GrubDev2UnixDev {
     my $grub_dev = shift;
     my $loader = $self->{loader} || return undef;
 
-    Bootloader::Logger::instance()->milestone( "Library::GrubDev2UnixDev grub_dev: $grub_dev" );
+    $self->milestone("grub_dev: $grub_dev");
 
     my $unix_dev = $loader->GrubDev2UnixDev ($grub_dev);
 
@@ -973,9 +1063,9 @@ sub SplitPath {
     my @ret = $loader->SplitDevPath ($opath);
 
     if (scalar (@ret) == 2){
-        Bootloader::Logger::instance()->milestone( "Library::SplitPath arg:: $opath result dev: ".($ret[0]||"")." result path: ".($ret[1]||"") );
+        $self->milestone( "arg:: $opath result dev: ".($ret[0]||"")." result path: ".($ret[1]||"") );
     }else{
-        Bootloader::Logger::instance()->milestone( "Library::SplitPath arg:: $opath result undef");
+        $self->milestone( "arg:: $opath result undef");
     }
 
     return @ret;
@@ -989,11 +1079,14 @@ Try detect on disk if contains ThinkpadMBR. Return true if detected.
 =cut
 
 #  DetectThinkpadMBR (string disk)
-sub DetectThinkpadMBR {
+sub DetectThinkpadMBR
+{
   my $self = shift;
   my $disk = shift;
-  my $res = Bootloader::MBRTools::IsThinkpadMBR($disk);
-  Bootloader::Logger::instance()->milestone("Library::DetectThinkpadMBR on $disk result $res" );
+  my $res = $self->IsThinkpadMBR($disk);
+
+  $self->milestone("on $disk result $res");
+
   return $res;
 }
 
@@ -1005,12 +1098,15 @@ Write generic mbr to disk on thinkpad. Return undef if fail.
 =cut
 
 #  WriteThinkpadMBR (string disk)
-sub WriteThinkpadMBR {
-   my $self = shift;
-   my $disk = shift;
-   my $res = Bootloader::MBRTools::PatchThinkpadMBR($disk);
-   Bootloader::Logger::instance()->milestone("Library::WriteThinkpadMBR on $disk result $res" );
-   return $res;
+sub WriteThinkpadMBR
+{
+  my $self = shift;
+  my $disk = shift;
+  my $res = $self->PatchThinkpadMBR($disk);
+
+  $self->milestone("on $disk result $res");
+
+  return $res;
 }
 
 =item
@@ -1030,11 +1126,12 @@ Possible string is:
 =cut
 
 #  ExamineMBR (string disk)
-sub ExamineMBR($){
+sub ExamineMBR()
+{
   my $self = shift;
   my $disk = shift;
-  my $res = Bootloader::MBRTools::examineMBR($disk);
-  Bootloader::Logger::instance()->milestone("Library::ExamineMBR on $disk result ".($res||"nil"));
+  my $res = $self->examineMBR($disk);
+  $self->milestone("on $disk result ".($res||"nil"));
   
   return $res;
 }
@@ -1046,7 +1143,7 @@ sub CountGRUBPassword{
   my $res = qx{echo "md5crypt \
   $pass" | grub --batch | grep Encrypted };
   $res =~ s/Encrypted:\s+(.*)$/$1/;
-  Bootloader::Logger::instance()->milestone("Library::CountGRUBPassword result $res" );
+  $self->milestone("result $res" );
   return undef unless $res =~ m/^\$1\$.*\$.*$/;
   return "--md5 $res";
 }
@@ -1064,7 +1161,7 @@ sub UpdateSerialConsole{
     $ret = "$append $console";
   }
 
-  Bootloader::Logger::instance()->milestone("Library::UpdateSerialConsole append $append console $console res $ret" );
+  $self->milestone("append $append console $console res $ret" );
 
   return $ret;
 }
