@@ -32,6 +32,7 @@ to \$3 (note that \$3 is appended to if given).
 Additional options:
   --without-gnome	do not find GNOME help files
   --without-kde		do not find KDE help files
+  --with-python         find Python translation files
   --with-qt		find Qt translation files
   --with-man		find localized man pages
   --all-name		match all package/domain names
@@ -56,6 +57,7 @@ shift
 
 GNOME=
 KDE=
+PYTHON=#
 QT=#
 MAN=#
 MO=
@@ -83,6 +85,10 @@ while test $# -gt 0 ; do
 		KDE=#
 		shift
 		;;
+	--with-python )
+	        PYTHON=
+	        shift
+                ;;
 	--with-qt )
 		QT=
 		shift
@@ -118,22 +124,31 @@ done
 if ! test -s $MO_NAME ; then
 	echo "%defattr (644, root, root, 755)" > $MO_NAME
 fi
-
 MO_NAME_NEW=$MO_NAME.tmp.$$
 rm -f $MO_NAME_NEW
 
 # remove languages we do not yet support - but give out statistics
-find $TOP_DIR/usr/share/locale/ -maxdepth 1 -type d | sed 's:'"$TOP_DIR"/usr/share/locale/'::; /^$/d' | while read dir; do
-  if ! rpm -ql filesystem | egrep -q "/usr/share/locale/$dir"$; then
-    find $TOP_DIR/usr/share/locale/$dir -name *.mo | sed 's:'"$TOP_DIR"'::' | while read file; do
+if [ -d "$TOP_DIR/usr/share/locale/" ] ; then
+    find "$TOP_DIR/usr/share/locale/" -maxdepth 1 -type d | sed 's:'"$TOP_DIR"/usr/share/locale/'::; /^$/d' | while read dir; do
+    if ! rpm -ql filesystem | egrep -q "/usr/share/locale/$dir"$; then
+        find $TOP_DIR/usr/share/locale/$dir -name *.mo | sed 's:'"$TOP_DIR"'::' | while read file; do
         echo -n "removing translation $file: "
-	msgunfmt "$TOP_DIR/$file" | msgfmt --statistics -o /dev/null -
+        msgunfmt "$TOP_DIR/$file" | msgfmt --statistics -o /dev/null -
+        done
+        rm -rf $TOP_DIR/usr/share/locale/$dir
+    fi
     done
-    rm -rf $TOP_DIR/usr/share/locale/$dir
-  fi
-done
+fi
+if [ -d "$TOP_DIR/usr/share/help/" ] ; then
+    find $TOP_DIR/usr/share/help/ -maxdepth 1 -type d | sed 's:'"$TOP_DIR"/usr/share/help/'::; /^$/d' | while read dir; do
+    if ! rpm -ql filesystem | egrep -q "/usr/share/help/$dir"$; then
+        echo "removing help translation /usr/share/help/$dir"
+        rm -rf $TOP_DIR/usr/share/help/$dir
+    fi
+    done
+fi
 
-find $TOP_DIR -type f -o -type l|sed '
+find "$TOP_DIR" -type f -o -type l|sed '
 s:'"$TOP_DIR"'::
 '"$ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\(.*\.mo$\):%lang(\2) \1\2\3:
 '"$NO_ALL_NAME$MO"'s:\(.*/locale/\)\([^/_]\+\)\(.*/'"$NAME"'\.mo$\):%lang(\2) \1\2\3:
@@ -141,9 +156,19 @@ s:^\([^%].*\)::
 '"$ONLY_C"'/%lang(C)/!d
 '"$NO_C"'/%lang(C)/d
 s:%lang(C) ::
+/^$/d' > $MO_NAME_NEW
+
+find "$TOP_DIR" -type d|sed '
+s:'"$TOP_DIR"'::
+'"$NO_ALL_NAME$GNOME"'s:\(.*/share/help/\)\([^/_]\+\)\([^/]*\)\(/'"$NAME"'\)$:%lang(\2) %doc \1\2\3\4/:
+'"$ALL_NAME$GNOME"'s:\(.*/share/help/\)\([^/_]\+\)\([^/]*\)\(/[a-zA-Z0-9.\_\-]\+\)$:%lang(\2) %doc \1\2\3\4/:
+s:^\([^%].*\)::
+'"$ONLY_C"'/%lang(C)/!d
+'"$NO_C"'/%lang(C)/d
+s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type d|sed '
+find "$TOP_DIR" -type d|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$GNOME"'s:\(.*/gnome/help/'"$NAME"'$\):%lang(C) %dir %doc \1:
 '"$NO_ALL_NAME$GNOME"'s:\(.*/gnome/help/'"$NAME"'/[a-zA-Z0-9.\_\-]/.\+\)::
@@ -158,15 +183,14 @@ s:^\([^%].*\)::
 s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type d|sed '
+find "$TOP_DIR" -type d|sed '
 s:'"$TOP_DIR"'::
-'"$NO_ALL_NAME$GNOME"'s:\(.*/omf/'"$NAME"'$\):%lang(C) %dir \1:
-'"$ALL_NAME$GNOME"'s:\(.*/omf/[a-zA-Z0-9.\_\-]\+$\):%lang(C) %dir \1:
+'"$NO_ALL_NAME$GNOME"'s:\(.*/omf/'"$NAME"'$\):%dir \1:
+'"$ALL_NAME$GNOME"'s:\(.*/omf/[a-zA-Z0-9.\_\-]\+$\):%dir \1:
 s:^\([^%].*\)::
-s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type f|sed '
+find "$TOP_DIR" -type f|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$GNOME"'s:\(.*/omf/'"$NAME"'/'"$NAME"'-\([^/.]\+\)\.omf\):%lang(\2) \1:
 '"$ALL_NAME$GNOME"'s:\(.*/omf/[a-zA-Z0-9.\_\-]\+/[a-zA-Z0-9.\_\-]\+-\([^/.]\+\)\.omf\):%lang(\2) \1:
@@ -176,9 +200,19 @@ s:^[^%].*::
 s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
+find "$TOP_DIR" -type f -o -type l|sed '
+s:'"$TOP_DIR"'::
+'"$NO_ALL_NAME$PYTHON"'s:\(/usr/lib.*/python.*/site-packages/'"$NAME"'$\):%dir \1:
+'"$ALL_NAME$PYTHON"'s:\(/usr/lib.*/python.*/site-packages/[a-zA-Z0-9.\_\-]\+$\):%dir \1:
+s:^[^%].*::
+'"$ONLY_C"'/%lang(C)/!d
+'"$NO_C"'/%lang(C)/d
+s:%lang(C) ::
+/^$/d' >> $MO_NAME_NEW
+
 KDE3_HTML=`kde-config --expandvars --install html 2>/dev/null`
 if [ x"$KDE3_HTML" != x -a -d "$TOP_DIR$KDE3_HTML" ]; then
-find $TOP_DIR$KDE3_HTML -type d|sed '
+find "$TOP_DIR$KDE3_HTML" -type d|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$KDE"'s:\(.*/HTML/\)\([^/_]\+\)\(.*/'"$NAME"'/\)::
 '"$NO_ALL_NAME$KDE"'s:\(.*/HTML/\)\([^/_]\+\)\(.*/'"$NAME"'\)$:%lang(\2) \1\2\3:
@@ -193,7 +227,7 @@ fi
 
 KDE4_HTML=`kde4-config --expandvars --install html 2>/dev/null`
 if [ x"$KDE4_HTML" != x -a -d "$TOP_DIR$KDE4_HTML" ]; then
-find $TOP_DIR$KDE4_HTML -type d|sed '
+find "$TOP_DIR$KDE4_HTML" -type d|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$KDE"'s:\(.*/HTML/\)\([^/_]\+\)\(.*/'"$NAME"'/\)::
 '"$NO_ALL_NAME$KDE"'s:\(.*/HTML/\)\([^/_]\+\)\(.*/'"$NAME"'\)$:%lang(\2) \1\2\3:
@@ -206,7 +240,7 @@ s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 fi
 
-find $TOP_DIR -type f -o -type l|sed '
+find "$TOP_DIR" -type f -o -type l|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$QT"'s:\(.*/'"$NAME"'_\([a-zA-Z]\{2\}\([_@].*\)\?\)\.qm$\):%lang(\2) \1:
 '"$ALL_NAME$QT"'s:\(.*/[^/_]\+_\([a-zA-Z]\{2\}[_@].*\)\.qm$\):%lang(\2) \1:
@@ -219,7 +253,7 @@ s:^[^%].*::
 s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type d|sed '
+find "$TOP_DIR" -type d|sed '
 s:'"$TOP_DIR"'::
 '"$ALL_NAME$MAN"'s:\(.*/man/\([^/_]\+\).*/man[a-z0-9]\+/\)::
 '"$ALL_NAME$MAN"'s:\(.*/man/\([^/_]\+\).*/man[a-z0-9]\+$\):%lang(\2) \1*:
@@ -229,7 +263,7 @@ s:^\([^%].*\)::
 s:%lang(C) ::
 /^$/d' >> $MO_NAME_NEW
 
-find $TOP_DIR -type f -o -type l|sed '
+find "$TOP_DIR" -type f -o -type l|sed '
 s:'"$TOP_DIR"'::
 '"$NO_ALL_NAME$MAN"'s:\(.*/man/\([^/_]\+\).*/man[a-z0-9]\+/'"$NAME"'\.[a-z0-9].*\):%lang(\2) \1*:
 s:^\([^%].*\)::
