@@ -114,18 +114,6 @@ def removeduppaths():
     sys.path[:] = L
     return known_paths
 
-# XXX This should not be part of site.py, since it is needed even when
-# using the -S option for Python.  See http://www.python.org/sf/586680
-def addbuilddir():
-    """Append ./build/lib.<platform> in case we're running in the build dir
-    (especially for Guido :-)"""
-    from sysconfig import get_platform
-    s = "build/lib.%s-%.3s" % (get_platform(), sys.version)
-    if hasattr(sys, 'gettotalrefcount'):
-        s += '-pydebug'
-    s = os.path.join(os.path.dirname(sys.path.pop()), s)
-    sys.path.append(s)
-
 
 def _init_pathinfo():
     """Return a set containing all existing directory entries from sys.path"""
@@ -243,29 +231,38 @@ def getuserbase():
     USER_BASE = get_config_var('userbase')
     return USER_BASE
 
-def getusersitepackages():
+def getusersitepackages(lib_kind = 'purelib'):
     """Returns the user-specific site-packages directory path.
 
     If the global variable ``USER_SITE`` is not initialized yet, this
     function will also set it.
     """
+
+    set_user_site = (lib_kind == 'purelib')
+
     global USER_SITE
     user_base = getuserbase() # this will also set USER_BASE
 
-    if USER_SITE is not None:
+    if USER_SITE is not None and set_user_site:
         return USER_SITE
 
     from sysconfig import get_path
     import os
 
+    user_site = None
+
     if sys.platform == 'darwin':
         from sysconfig import get_config_var
         if get_config_var('PYTHONFRAMEWORK'):
-            USER_SITE = get_path('purelib', 'osx_framework_user')
-            return USER_SITE
+            user_site = get_path(lib_kind, 'osx_framework_user')
 
-    USER_SITE = get_path('purelib', '%s_user' % os.name)
-    return USER_SITE
+    if user_site is None:
+        user_site = get_path(lib_kind, '%s_user' % os.name)
+
+    if set_user_site:
+        USER_SITE = user_site
+
+    return user_site
 
 def addusersitepackages(known_paths):
     """Add a per user site-package to sys.path
@@ -275,10 +272,12 @@ def addusersitepackages(known_paths):
     """
     # get the per user site-package path
     # this call will also make sure USER_BASE and USER_SITE are set
-    user_site = getusersitepackages()
+    for kind in ('purelib', 'platlib'):
+        user_site = getusersitepackages(kind)
+
+        if ENABLE_USER_SITE and os.path.isdir(user_site):
+            addsitedir(user_site, known_paths)
 
-    if ENABLE_USER_SITE and os.path.isdir(user_site):
-        addsitedir(user_site, known_paths)
     return known_paths
 
 def getsitepackages():
@@ -453,7 +452,7 @@ def setcopyright():
     for supporting Python development.  See www.python.org for more information.""")
     here = os.path.dirname(os.__file__)
     __builtin__.license = _Printer(
-        "license", "See http://www.python.org/%.3s/license.html" % sys.version,
+        "license", "See http://www.python.org/psf/license/",
         ["LICENSE.txt", "LICENSE"],
         [os.path.join(here, os.pardir), here, os.curdir])
 
@@ -542,9 +541,6 @@ def main():
 
     abs__file__()
     known_paths = removeduppaths()
-    if (os.name == "posix" and sys.path and
-        os.path.basename(sys.path[-1]) == "Modules"):
-        addbuilddir()
     if ENABLE_USER_SITE is None:
         ENABLE_USER_SITE = check_enableusersite()
     known_paths = addusersitepackages(known_paths)
