@@ -1,6 +1,6 @@
 # encoding: utf-8
 
-# Copyright (c) 2012 Novell, Inc.
+# Copyright (c) [2012-2014] Novell, Inc.
 #
 # All Rights Reserved.
 #
@@ -33,9 +33,10 @@
 module Yast
   class InstTargetPartClient < Client
     def main
-      Yast.import "UI"
+
       textdomain "storage"
 
+      Yast.import "UI"
       Yast.import "Mode"
       Yast.import "Popup"
       Yast.import "Storage"
@@ -159,7 +160,8 @@ module Yast
             @partitions,
             Ops.get_integer(@target, "cyl_size", 1)
           )
-          @vbox = Builtins.add(@vbox, StorageProposal.AddCommonWidgets)
+          @vbox = Builtins.add(@vbox, VSpacing(1.5))
+          @vbox = Builtins.add(@vbox, PushButton(Id(:settings), _("Edit Proposal Settings")))
           Builtins.y2milestone("can resize !")
         else
           # this is the normal case
@@ -171,12 +173,16 @@ module Yast
           )
           @vbox = Builtins.add(
             Ops.get_term(@tmp, "term", VBox()),
-            StorageProposal.AddCommonWidgets
+            VBox(
+              VSpacing(1.5),
+              PushButton(Id(:settings), _("Edit Proposal Settings"))
+            )
           )
         end
       else
         @vbox = create_whole_disk_dialog
-        @vbox = Builtins.add(@vbox, StorageProposal.AddCommonWidgets)
+        @vbox = Builtins.add(@vbox, VSpacing(1.5))
+        @vbox = Builtins.add(@vbox, PushButton(Id(:settings), _("Edit Proposal Settings")))
       end
 
       # Since resize case and normal case have different help texts we need
@@ -213,18 +219,6 @@ module Yast
         UI.ChangeWidget(Id(:full), :Enabled, false)
       end
 
-      UI.ChangeWidget(
-        Id(:encrypt),
-        :Enabled,
-        Convert.to_boolean(UI.QueryWidget(Id(:lvm), :Value))
-      )
-      @susp_enab = Ops.less_than(
-        Partitions.SwapSizeMb(0, false),
-        Partitions.SwapSizeMb(0, true)
-      )
-      UI.ChangeWidget(Id(:suspend), :Value, false) if !@susp_enab
-      UI.ChangeWidget(Id(:suspend), :Enabled, @susp_enab)
-
       # Event handling
 
       @ret = nil
@@ -237,8 +231,8 @@ module Yast
 
         if @ret == :abort && Popup.ReallyAbort(true)
           break
-        elsif Builtins.contains([:lvm, :home, :btrfs, :encrypt, :suspend], @ret)
-          StorageProposal.HandleCommonWidgets(@ret)
+        elsif @ret == :settings
+          StorageProposal.CommonWidgetsPopup()
         elsif @ret == :full
           # Set all checkboxes
           Builtins.foreach(@partitions) do |pentry|
@@ -426,13 +420,13 @@ module Yast
 
             @ok = create_partitions(@targetMap, @target, @partitions)
             if !@ok
-              @reason = _(
+              reason = _(
                 "Too few partitions are marked for removal or \n" +
                   "the disk is too small. \n" +
                   "To install Linux, select more partitions to \n" +
                   "remove or select a larger disk."
               )
-              display_error_box(@reason)
+              display_error_box(reason)
             end
             @tg = Storage.GetTargetMap
             @pl = Ops.get_list(@tg, [@target_is, "partitions"], [])
@@ -452,10 +446,10 @@ module Yast
                   Ops.get_string(p, "mount", "") == "/home"
                 end) == 0
               @ok = false
-              @reason = _(
+              reason = _(
                 "Not enough space available to propose separate /home."
               )
-              Popup.Error(@reason)
+              Popup.Error(reason)
             end
           end
         end
