@@ -28,6 +28,8 @@
 # $Id$
 module Yast
   class UpdateProposalClient < Client
+    include Yast::Logger
+
     def main
       Yast.import "Pkg"
       Yast.import "UI"
@@ -151,7 +153,7 @@ module Yast
           }
         end
 
-        @warning_message = nil
+        @warning_message = ""
 
         # when labels don't match
         if !Stage.initial &&
@@ -177,34 +179,9 @@ module Yast
           )
         end
 
+        products = Pkg.ResolvableProperties("", :product, "")
         # stores the proposal text output
-        @summary_text = ""
-
-        @products = Update.SelectedProducts
-        @already_printed = []
-
-        Builtins.foreach(@products) do |one_product|
-          # never print duplicates, bugzilla #331560
-          # 'toset' could be used but we want to keep sorting
-          if Builtins.contains(@already_printed, one_product)
-            next
-          else
-            @already_printed = Builtins.add(@already_printed, one_product)
-          end
-          # TRANSLATORS: proposal summary item, %1 is a product name
-          @summary_text = Ops.add(
-            Ops.add(
-              Ops.add(@summary_text, "<li><b>"),
-              Builtins.sformat(_("Update to %1"), one_product)
-            ),
-            "</b></li>\n"
-          )
-        end if @products != nil
-
-        #	if (Update::deleteOldPackages) {
-        #	    // Proposal for removing packages which are not maintained any more
-        #	    summary_text = summary_text + "<li>" + _("Delete unmaintained packages") + "</li>\n";
-        #	}
+        @summary_text = Packages.product_update_summary(products).map{|item| "<li>#{item}</li>"}.join
 
         if Update.onlyUpdateInstalled
           # Proposal for backup during update
@@ -267,9 +244,12 @@ module Yast
           "help"                  => @update_options_help
         }
 
-        if @warning_message != nil
-          Ops.set(@ret, "warning", @warning_message)
-          Ops.set(@ret, "warning_level", :warning)
+        product_warning = Packages.product_update_warning(products)
+        @warning_message << product_warning["warning"] if product_warning["warning"]
+
+        if !@warning_message.empty?
+          @ret["warning"] = @warning_message
+          @ret["warning_level"] = product_warning["warning_level"] || :warning
         end
       elsif @func == "AskUser"
         @has_next = Ops.get_boolean(@param, "has_next", false)
@@ -504,14 +484,10 @@ module Yast
         Builtins.foreach(restore) { |res| Pkg.ResolvableInstall(res, :product) }
         Update.SetDesktopPattern if !Update.onlyUpdateInstalled
 
-        if !Update.onlyUpdateInstalled && # just consider already installed packages
-            !ProductFeatures.GetBooleanFeature(
-              "software",
-              "only_update_installed"
-            )
-          Builtins.foreach(Product.patterns) do |pat|
-            Builtins.y2milestone("Pre-select pattern %1", pat)
-            Pkg.ResolvableInstall(pat, :pattern)
+        if !Update.OnlyUpdateInstalled
+          Packages.default_patterns.each do |pattern|
+            select_pattern_result = Pkg.ResolvableInstall(pattern, :pattern)
+            log.info "Pre-select pattern #{pattern}: #{select_pattern_result}"
           end
         end
 
@@ -522,18 +498,18 @@ module Yast
         update_sum = Pkg.PkgUpdateAll(GetUpdateConf())
         Builtins.y2milestone("Update summary: %1", update_sum)
         Update.unknown_packages = Ops.get(update_sum, :ProblemListSze, 0)
-
-        sys_patterns = Packages.ComputeSystemPatternList
-        Builtins.foreach(sys_patterns) do |pat|
-          Pkg.ResolvableInstall(pat, :pattern)
-        end
-
-        if Pkg.PkgSolve(!Update.onlyUpdateInstalled)
-          Update.solve_errors = 0
-        else
-          Update.solve_errors = Pkg.PkgSolveErrors
-        end
       end
+
+      # preselect system patterns (including PackagesProposal patterns)
+      sys_patterns = Packages.ComputeSystemPatternList
+      sys_patterns.each {|pat| Pkg.ResolvableInstall(pat, :pattern)}
+
+      if Pkg.PkgSolve(!Update.onlyUpdateInstalled)
+        Update.solve_errors = 0
+      else
+        Update.solve_errors = Pkg.PkgSolveErrors
+      end
+
       # check product compatibility
       if !(Update.ProductsCompatible || Update.products_incompatible) || update_not_possible
         if Popup.ContinueCancel(
