@@ -16,6 +16,8 @@
 #
 module Yast
   module AddOnAddOnWorkflowInclude
+    include Yast::Logger
+
     def initialize_add_on_add_on_workflow(include_target)
       Yast.import "UI"
       Yast.import "Pkg"
@@ -46,8 +48,6 @@ module Yast
       Yast.include include_target, "packager/repositories_include.rb"
       Yast.include include_target, "add-on/misc.rb"
 
-      @going_back_in_workflow = GetInstArgs.going_back
-
       # Used for adding sources
       @createResult = :again
 
@@ -87,7 +87,7 @@ module Yast
         if Ops.get_string(cmd_run, "stdout", "") != ""
           Builtins.y2error("Checking the network failed")
           ret = true
-        end 
+        end
         # some devices are listed
       elsif Ops.get_string(cmd_run, "stdout", "") != nil &&
           Ops.get_string(cmd_run, "stdout", "") != "" &&
@@ -172,12 +172,20 @@ module Yast
     # Run dialog for selecting the media
     # @return [Symbol] for wizard sequencer
     def MediaSelect
-      aliases = { "type" => lambda { TypeDialog() }, "edit" => lambda do
-        EditDialog()
-      end, "store" => lambda(
-      ) do
-        StoreSource()
-      end }
+      aliases = {
+        "type"  => lambda do
+          ret = TypeDialog()
+          log.debug "SourceDialogs.addon_enabled: #{SourceDialogs.addon_enabled}"
+          # explicitly check for false (nil means the checkbox was not displayed)
+          ret = :skip if ret == :next && SourceDialogs.addon_enabled == false
+          log.debug "TypeDialog result: #{ret}"
+          ret
+        end,
+        "edit"  => lambda { EditDialog() },
+        "store" => lambda do
+          StoreSource()
+        end
+      }
 
       sources_before = Pkg.SourceGetCurrent(false)
       Builtins.y2milestone("Sources before adding new one: %1", sources_before)
@@ -188,7 +196,8 @@ module Yast
           :next   => "edit",
           # bnc #392083
           :finish => "store",
-          :abort  => :abort
+          :abort  => :abort,
+          :skip   => :skip
         },
         "edit"     => {
           :next   => "store",
@@ -206,8 +215,9 @@ module Yast
 
       Builtins.y2milestone("Starting repository sequence")
       ret = Sequencer.Run(aliases, sequence)
+      log.info "Repository sequence result: #{ret}"
 
-      if ret != :abort
+      if ret == :next
         sources_after = Pkg.SourceGetCurrent(false)
         Builtins.y2milestone("Sources with new one added: %1", sources_after)
 
@@ -850,7 +860,8 @@ module Yast
         "media"           => {
           :abort  => :abort,
           :next   => "check_compliance",
-          :finish => "check_compliance"
+          :finish => "check_compliance",
+          :skip   => :skip
         },
         #	"catalog" : $[
         #	    `abort : `abort,
@@ -1059,12 +1070,10 @@ module Yast
       end
 
       # FATE #301928 - Saving one click
-      # Bugzilla #305809 if "going_back", do not save that click!
-      if no_addons && !@going_back_in_workflow
+      # Bugzilla #893103 be consistent, so always when there is no add-on skip
+      if no_addons
         Builtins.y2milestone("Skipping to media_select")
-        # only once
-        @going_back_in_workflow = false
-        ret = :first_time
+        ret = :skip_to_add
       end
 
       # Show Add-Ons table
@@ -1084,11 +1093,7 @@ module Yast
       some_addon_changed = false
       begin
         # FATE #301928 - Saving one click
-        if ret == :first_time
-          ret = :add
-        else
-          ret = Convert.to_symbol(UI.UserInput)
-        end
+        ret = Convert.to_symbol(UI.UserInput) unless ret == :skip_to_add
 
         # aborting
         if ret == :abort || ret == :cancel
@@ -1099,11 +1104,11 @@ module Yast
               break
             else
               ret = nil
-            end 
+            end
             # Running system
           else
             break
-          end 
+          end
 
           # removing add-on
         elsif ret == :delete
@@ -1134,10 +1139,15 @@ module Yast
             back_button,
             next_button,
             abort_button
-          ) 
+          )
 
           # adding new add-on
-        elsif ret == :add
+        elsif ret == :add || ret == :skip_to_add
+          # show checkbox only first time in installation when there is no
+          # other addons, so allow to quickly skip adding addons, otherwise
+          # it make no sense as user explicitelly want add addon
+          SourceDialogs.display_addon_checkbox = ret == :skip_to_add
+
           # bugzilla #293428
           # Release all sources before adding a new one
           # because of CD/DVD + url cd://
@@ -1151,6 +1161,8 @@ module Yast
           ret2 = RunWizard()
           Wizard.CloseDialog
 
+          log.info "Subworkflow result: ret2: #{ret2}"
+
           if ret2 == :next
             # Add-On product has been added, integrate it (change workflow, use y2update)
             AddOnProduct.Integrate(AddOnProduct.src_id)
@@ -1158,6 +1170,8 @@ module Yast
             # check whether it requests registration (FATE #301312)
             AddOnProduct.PrepareForRegistration(AddOnProduct.src_id)
             some_addon_changed = true
+            # do not keep first_time, otherwise summary won't be shown during installation
+            ret = nil if ret == :skip_to_add
           elsif ret2 == :abort || ret2 == :cancel
             Builtins.y2milestone("Add-on sequence aborted")
 
@@ -1177,6 +1191,12 @@ module Yast
                   AddOnProduct.src_id
               end
             end
+            # properly return abort in installation
+            ret = :abort if ret == :skip_to_add
+          # extra handling for the global enable checkbox
+          elsif ret == :skip_to_add
+            ret = :back if ret2 == :back
+            ret = :next if ret2 == :skip
           end
 
           Redraw(
@@ -1193,7 +1213,7 @@ module Yast
           # because of CD/DVD + url cd://
           Pkg.SourceReleaseAll
         end
-      end until ret == :next || ret == :back
+      end until [:next, :back, :abort].include?(ret)
 
       Builtins.y2milestone(
         "Ret: %1, Some Add-on Added/Removed: %2",
@@ -1906,13 +1926,13 @@ module Yast
         if userret == :abort || userret == :cancel
           Builtins.y2warning("Aborting...")
           ret = :abort
-          break 
+          break
 
           # Closing
         elsif userret == :next || userret == :finish
           Builtins.y2milestone("Finishing...")
           ret = :next
-          break 
+          break
 
           # Addin new product
         elsif userret == :add
@@ -1928,7 +1948,7 @@ module Yast
           end
 
           CreateAddOnsOverviewDialog()
-          RedrawAddOnsOverviewTable() 
+          RedrawAddOnsOverviewTable()
 
           # Removing product
         elsif userret == :delete
@@ -1942,7 +1962,7 @@ module Yast
             Builtins.y2milestone(
               "User decided not to remove the selected product"
             )
-            next 
+            next
 
             # false == user decided not confirm the add-on removal
             # libzypp has been already changed
@@ -1956,7 +1976,7 @@ module Yast
             NeutralizeAllResolvables()
             Pkg.SourceFinishAll
 
-            LoadLibzyppNow() 
+            LoadLibzyppNow()
 
             # true == packages and sources have been removed
           else
@@ -1965,11 +1985,11 @@ module Yast
           end
 
           CreateAddOnsOverviewDialog()
-          RedrawAddOnsOverviewTable() 
+          RedrawAddOnsOverviewTable()
 
           # Redrawing info widget
         elsif userret == "list_of_addons"
-          AdjustInfoWidget() 
+          AdjustInfoWidget()
 
           # Calling packager directly
         elsif userret == :packager
@@ -1977,7 +1997,7 @@ module Yast
           RunPackageSelector()
 
           CreateAddOnsOverviewDialog()
-          RedrawAddOnsOverviewTable() 
+          RedrawAddOnsOverviewTable()
 
           # Everything else
         else
