@@ -18,46 +18,27 @@
 #
 # $Id: BootGRUB.ycp 63508 2011-03-04 12:53:27Z jreidinger $
 #
+
+require "bootloader/boot_record_backup"
+
 module Yast
   module BootloaderGrub2MiscInclude
     def initialize_bootloader_grub2_misc(include_target)
       textdomain "bootloader"
+      Yast.import "Arch"
+      Yast.import "BootCommon"
+      Yast.import "BootStorage"
+      Yast.import "Map"
+      Yast.import "Mode"
+      Yast.import "PackageSystem"
+      Yast.import "Partitions"
       Yast.import "Storage"
       Yast.import "StorageDevices"
-      Yast.import "Mode"
-      Yast.import "BootCommon"
-      Yast.import "PackageSystem"
-      Yast.import "Map"
     end
 
     # --------------------------------------------------------------
     # --------------------------------------------------------------
-    # updateMBR and related stuff, plus InstallingToFloppy() (taken from
-    # routines/misc.ycp)
-
-    # Check if installation to floppy is performed
-    # @return true if installing bootloader to floppy
-    def grub_InstallingToFloppy
-      ret = false
-      # there is no boot_floppy flag, the installation to floppy devices needs
-      # to be specified in the boot_custom flag
-      # (FIXME: which is freely editable, as soon as the generic 'selectdevice'
-      # widget allows this; also need perl-Bootloader to put the floppy device
-      # in the list of the boot_custom widget)
-      if Ops.get(BootCommon.globals, "boot_custom") == nil
-        ret = false
-      elsif Ops.get(BootCommon.globals, "boot_custom") ==
-          StorageDevices.FloppyDevice
-        ret = true
-      elsif Builtins.contains(
-          BootStorage.getFloppyDevices,
-          Ops.get(BootCommon.globals, "boot_custom")
-        )
-        ret = true
-      end
-      Builtins.y2milestone("Installing to floppy: %1", ret)
-      ret
-    end
+    # updateMBR and related stuff
 
     # Given a device name to which we install the bootloader (loader_device),
     # get the name of the partition which should be activated.
@@ -88,7 +69,9 @@ module Yast
       # value, and code on the caller side that evaluates this.
       if Builtins.substring(loader_device, 0, 7) == "/dev/md"
         md = BootCommon.Md2Partitions(loader_device)
-        min = 256 # max. is 255; 256 means "no bios_id found"
+        # max. is 255; 256 means "no bios_id found", so to have at least one
+        # underlaying device use higher
+        min = 257
         device = ""
         Builtins.foreach(md) do |d, id|
           if Ops.less_than(id, min)
@@ -102,57 +85,27 @@ module Yast
           mbr_dev = Ops.get_string(p_dev2, "disk", "")
         end
       end
-      # If loader_device is a disk device ("/dev/sda"), that means that we
-      # install the bootloader to the MBR. In this case, activate /boot
-      # partition.
-      # (partial fix of #20637)
-      # FIXME: necessity and purpose are unclear: if we install the
-      # bootloader to the MBR, then why do we need to activate the /boot
-      # partition? Stage1 of a GRUB has the first block of the stage2
-      # hard-coded inside.
-      # This code was added because a /boot partition on a /dev/cciss device
-      # was not activated in bug #20637. Anyway, it probably never worked,
-      # since the bootloader was not installed to the MBR in that bug (and
-      # thus this code is not triggered).
-      # The real problem may have been that Storage::GetDiskPartition() did
-      # not know how to parse /dev/cciss/c0d0p1, so that the default case at
-      # the beginning of this function did not set up correct values. These
-      # days, Storage::GetDiskPartition() looks OK with /dev/cciss.
-      # Deactivated this code, so that "/boot" does not get activated
-      # unecessarily when GRUB stage1 is installed to the MBR anyway (this
-      # would unecessarily have broken drive C: detection on older MS
-      # operating systems).
-      #	else if (num == 0)
-      #	{
-      #	    p_dev = Storage::GetDiskPartition (boot_partition);
-      #	    num = BootCommon::myToInteger( p_dev["nr"]:nil );
-      #	    mbr_dev = p_dev["disk"]:"";
-      #
-      #	    if (size (BootCommon::Md2Partitions (boot_partition)) > 1)
-      #	    {
-      #		foreach (string k, integer v, BootCommon::Md2Partitions (boot_partition),{
-      #		    if (search (k, loader_device) == 0)
-      #		    {
-      #			p_dev = Storage::GetDiskPartition (k);
-      #			num = BootCommon::myToInteger( p_dev["nr"]:nil );
-      #			mbr_dev = p_dev["disk"]:"";
-      #		    }
-      #		});
-      #	    }
-      #	}
 
+      tm = Storage.GetTargetMap
+      partitions = Ops.get_list(tm, [mbr_dev, "partitions"], [])
+      # do not select swap and do not select BIOS grub partition
+      # as it clear its special flags (bnc#894040)
+      partitions.select! { |p| p["used_fs"] != :swap && p["fsid"] != Partitions.fsid_bios_grub }
       # (bnc # 337742) - Unable to boot the openSUSE (32 and 64 bits) after installation
-      # if loader_device is disk device activate BootStorage::BootPartitionDevice
+      # if loader_device is disk Choose any partition which is not swap to
+      # satisfy such bios (bnc#893449)
       if num == 0
-        Builtins.y2milestone("loader_device is disk device")
-        p_dev = Storage.GetDiskPartition(BootStorage.BootPartitionDevice)
-        num = BootCommon.myToInteger(Ops.get(p_dev, "nr"))
+        # strange, no partitions on our mbr device, we probably won't boot
+        if partitions.empty?
+          Builtins.y2warning("no non-swap partitions for mbr device #{mbr_dev}")
+          return {}
+        end
+        num = partitions.first["nr"]
+        Builtins.y2milestone("loader_device is disk device, so use its #{num} partition")
       end
 
       if Ops.greater_than(num, 4)
-        Builtins.y2milestone("Bootloader partition type is logical")
-        tm = Storage.GetTargetMap
-        partitions = Ops.get_list(tm, [mbr_dev, "partitions"], [])
+        Builtins.y2milestone("Bootloader partition type can be logical")
         Builtins.foreach(partitions) do |p|
           if Ops.get(p, "type") == :extended
             num = Ops.get_integer(p, "nr", num)
@@ -210,6 +163,8 @@ module Yast
       ret = Builtins.maplist(bootloader_base_devices) do |partition|
         grub_getPartitionToActivate(partition)
       end
+      ret.delete({})
+
       Builtins.toset(ret)
     end
 
@@ -271,113 +226,6 @@ module Yast
       Builtins.toset(ret)
     end
 
-    # Get last change time of file
-    # @param [String] filename string name of file
-    # @return [String] last change date as YYYY-MM-DD-HH-MM-SS
-    def grub_getFileChangeDate(filename)
-      stat = Convert.to_map(SCR.Read(path(".target.stat"), filename))
-      ctime = Ops.get_integer(stat, "ctime", 0)
-      command = Builtins.sformat(
-        "date --date='1970-01-01 00:00:00 %1 seconds' +\"%%Y-%%m-%%d-%%H-%%M-%%S\"",
-        ctime
-      )
-      out = Convert.to_map(SCR.Execute(path(".target.bash_output"), command))
-      c_time = Ops.get_string(out, "stdout", "")
-      Builtins.y2debug("File %1: last change %2", filename, c_time)
-      c_time
-    end
-
-    # Save current MBR to /boot/backup_mbr
-    # Also save to /var/lib/YaST2/backup_boot_sectors/%device, if some
-    # existing, rename it
-    # @param [String] device string name of device
-    def grub_saveMBR(device)
-      device_file = Builtins.mergestring(Builtins.splitstring(device, "/"), "_")
-      device_file_path = Ops.add(
-        "/var/lib/YaST2/backup_boot_sectors/",
-        device_file
-      )
-      device_file_path_to_logs = Ops.add("/var/log/YaST2/", device_file)
-      SCR.Execute(
-        path(".target.bash"),
-        "test -d /var/lib/YaST2/backup_boot_sectors || mkdir /var/lib/YaST2/backup_boot_sectors"
-      )
-      if Ops.greater_than(SCR.Read(path(".target.size"), device_file_path), 0)
-        contents = Convert.convert(
-          SCR.Read(path(".target.dir"), "/var/lib/YaST2/backup_boot_sectors"),
-          :from => "any",
-          :to   => "list <string>"
-        )
-        contents = Builtins.filter(contents) do |c|
-          Builtins.regexpmatch(
-            c,
-            Builtins.sformat("%1-.*-.*-.*-.*-.*-.*", device_file)
-          )
-        end
-        contents = Builtins.sort(contents)
-        index = 0
-        siz = Builtins.size(contents)
-        while Ops.less_than(Ops.add(index, 10), siz)
-          SCR.Execute(
-            path(".target.remove"),
-            Builtins.sformat(
-              "/var/lib/YaST2/backup_boot_sectors/%1",
-              Ops.get(contents, index, "")
-            )
-          )
-          index = Ops.add(index, 1)
-        end
-        change_date = grub_getFileChangeDate(device_file_path)
-        SCR.Execute(
-          path(".target.bash"),
-          Builtins.sformat("/bin/mv %1 %1-%2", device_file_path, change_date)
-        )
-      end
-      SCR.Execute(
-        path(".target.bash"),
-        Builtins.sformat(
-          "/bin/dd if=%1 of=%2 bs=512 count=1 2>&1",
-          device,
-          device_file_path
-        )
-      )
-      # save MBR to yast2 log directory
-      SCR.Execute(
-        path(".target.bash"),
-        Builtins.sformat(
-          "/bin/dd if=%1 of=%2 bs=512 count=1 2>&1",
-          device,
-          device_file_path_to_logs
-        )
-      )
-      if device == BootCommon.mbrDisk
-        SCR.Execute(
-          path(".target.bash"),
-          Builtins.sformat(
-            "/bin/dd if=%1 of=%2 bs=512 count=1 2>&1",
-            device,
-            "/boot/backup_mbr"
-          )
-        )
-
-        # save thinkpad MBR
-        if BootCommon.ThinkPadMBR(device)
-          device_file_path_thinkpad = Ops.add(device_file_path, "thinkpadMBR")
-          Builtins.y2milestone("Backup thinkpad MBR")
-          SCR.Execute(
-            path(".target.bash"),
-            Builtins.sformat(
-              "cp %1 %2 2>&1",
-              device_file_path,
-              device_file_path_thinkpad
-            )
-          )
-        end
-      end
-
-      nil
-    end
-
     # Update contents of MBR (active partition and booting code)
     # FIXME move tis function to lilolike.ycp
     # @return [Boolean] true on success
@@ -419,7 +267,10 @@ module Yast
           "Creating backup of boot sectors of %1",
           disks_to_rewrite
         )
-        Builtins.foreach(disks_to_rewrite) { |d| grub_saveMBR(d) }
+        backups = disks_to_rewrite.map do |d|
+          ::Bootloader::BootRecordBackup.new(d)
+        end
+        backups.each(&:write)
       end
       ret = true
       # if the bootloader stage 1 is not installed in the MBR, but
@@ -469,50 +320,50 @@ module Yast
       Builtins.foreach(grub_getPartitionsToActivate) do |m_activate|
         num = Ops.get_integer(m_activate, "num", 0)
         mbr_dev = Ops.get_string(m_activate, "mbr", "")
-        if num != 0 && mbr_dev != ""
-          # if primary partition
-          if !Ops.is_integer?(num) || Ops.less_or_equal(num, 4)
-            Builtins.y2milestone("Activating partition %1 on %2", num, mbr_dev)
-            # FIXME: this is the most rotten code since molded sliced bread
-            # move to bootloader/Core/GRUB.pm or similar
-            # TESTME: make sure that parted does not destroy BSD
-            # slices (#suse24740): cf. section 5.1 of "info parted":
-            #   Parted only supports the BSD disk label system.
-            #   Parted is unlikely to support the partition slice
-            #   system in the future because the semantics are rather
-            #   strange, and don't work like "normal" partition tables
-            #   do.
-            # FIXED: investigate proper handling of the activate flag
-            # (kernel ioctls in parted etc.) and fix parted
+        raise "INTERNAL ERROR: Data for partition to activate is invalid." if num == 0 || mbr_dev.empty?
 
-            # this is needed only on gpt disks but we run it always
-            # anyway; parted just fails, then
-            command = Builtins.sformat(
-              "/usr/sbin/parted -s %1 set %2 legacy_boot on",
-              mbr_dev,
-              num
-            )
-            Builtins.y2milestone("Running command %1", command)
-            out = Convert.to_map(
-              SCR.Execute(path(".target.bash_output"), command)
-            )
-            Builtins.y2milestone("Command output: %1", out)
+        gpt_disk = Storage.GetDisk(Storage.GetTargetMap, BootCommon.mbrDisk)["label"] == "gpt"
+        # if primary partition on old DOS MBR table, GPT do not have such limit
 
-            command = Builtins.sformat(
-              "/usr/sbin/parted -s %1 set %2 boot on",
-              mbr_dev,
-              num
-            )
-            Builtins.y2milestone("Running command %1", command)
-            out = Convert.to_map(
-              SCR.Execute(path(".target.bash_output"), command)
-            )
-            exit = Ops.get_integer(out, "exit", 0)
-            Builtins.y2milestone("Command output: %1", out)
-            ret = ret && 0 == exit
-          end
-        else
-          Builtins.y2error("Cannot activate %1", m_activate)
+        if !(Arch.ppc && gpt_disk) && (gpt_disk || num <= 4)
+          Builtins.y2milestone("Activating partition %1 on %2", num, mbr_dev)
+          # FIXME: this is the most rotten code since molded sliced bread
+          # move to bootloader/Core/GRUB.pm or similar
+          # TESTME: make sure that parted does not destroy BSD
+          # slices (#suse24740): cf. section 5.1 of "info parted":
+          #   Parted only supports the BSD disk label system.
+          #   Parted is unlikely to support the partition slice
+          #   system in the future because the semantics are rather
+          #   strange, and don't work like "normal" partition tables
+          #   do.
+          # FIXED: investigate proper handling of the activate flag
+          # (kernel ioctls in parted etc.) and fix parted
+
+          # this is needed only on gpt disks but we run it always
+          # anyway; parted just fails, then
+          command = Builtins.sformat(
+            "/usr/sbin/parted -s %1 set %2 legacy_boot on",
+            mbr_dev,
+            num
+          )
+          Builtins.y2milestone("Running command %1", command)
+          out = Convert.to_map(
+            WFM.Execute(path(".local.bash_output"), command)
+          )
+          Builtins.y2milestone("Command output: %1", out)
+
+          command = Builtins.sformat(
+            "/usr/sbin/parted -s %1 set %2 boot on",
+            mbr_dev,
+            num
+          )
+          Builtins.y2milestone("Running command %1", command)
+          out = Convert.to_map(
+            WFM.Execute(path(".local.bash_output"), command)
+          )
+          exit = Ops.get_integer(out, "exit", 0)
+          Builtins.y2milestone("Command output: %1", out)
+          ret = ret && 0 == exit
         end
       end if activate
       ret
@@ -551,6 +402,8 @@ module Yast
         Ops.set(BootCommon.globals, "boot_boot", "true")
       elsif selected_location == :mbr
         Ops.set(BootCommon.globals, "boot_mbr", "true")
+        # Disable generic MBR as we want grub2 there
+        Ops.set(BootCommon.globals, "generic_mbr", "false")
       elsif selected_location == :extended
         Ops.set(BootCommon.globals, "boot_extended", "true")
       end
@@ -668,11 +521,6 @@ module Yast
       )
       Builtins.y2milestone("The extended partition: %1", extended)
 
-      # keep_mbr, if the MBR contains special code that needs to be kept,
-      #           like Thinkpad boot code (and ATM only Thinkpad boot code
-      #           is recognized)
-      keep_mbr = BootCommon.KeepMBR(BootCommon.mbrDisk)
-
       # if is primary, store bootloader there
 
       exit = 0
@@ -705,7 +553,7 @@ module Yast
         Ops.set(
           BootCommon.globals,
           "generic_mbr",
-          out != "vista" && !keep_mbr ? "true" : "false"
+          out != "vista" ? "true" : "false"
         )
         if out == "vista"
           Builtins.y2milestone("Vista MBR...")
@@ -725,25 +573,18 @@ module Yast
         selected_location = :mbr
       end
 
-      if keep_mbr
-        if is_logical && extended != nil
-          selected_location = :extended
-        else
-          selected_location = BootStorage.BootPartitionDevice !=
-            BootStorage.RootPartitionDevice ? :boot : :root
-        end
-      end
-
       if is_logical_and_btrfs
-        if keep_mbr
-          Builtins.y2milestone("force to use mbr even if keep_mbr is suggested")
-        end
         Builtins.y2milestone(
           "/boot is on logical parititon and uses btrfs, mbr is favored in this situration"
         )
         selected_location = :mbr
       end
 
+      if !BootStorage.can_boot_from_partition
+        Builtins.y2milestone("/boot cannot be used to install stage1")
+        selected_location = :mbr
+      end
+
       SetBootloaderDevice(selected_location)
       if !Builtins.contains(
           BootStorage.getPartitionList(:boot, "grub"),
@@ -789,9 +630,22 @@ module Yast
         SetBootloaderDevice(selected_location)
       end
 
+      # for GPT remove protective MBR flag otherwise some systems won't boot
+      if gpt_boot_disk?
+        BootCommon.pmbr_action = :remove
+      end
+
+      Builtins.y2milestone("location configured. Resulting globals #{BootCommon.globals}")
+
       selected_location
     end
 
+    def gpt_boot_disk?
+      targets = BootCommon.GetBootloaderDevices
+      boot_discs = targets.map {|d| Storage.GetDisk(Storage.GetTargetMap, d)}
+      boot_discs.any? {|d| d["label"] == "gpt" }
+    end
+
     # Find extended partition device (if it exists) on the same device where the
     # BootPartitionDevice is located
     #
@@ -1018,6 +872,7 @@ module Yast
     def grub_LocationProposal
       Builtins.y2milestone("globals: %1", BootCommon.globals)
       Builtins.y2milestone("Mode::autoinst: %1", Mode.autoinst)
+      Builtins.y2milestone("Mode::autoupg: %1", Mode.autoupgrade)
       Builtins.y2milestone(
         "haskey( BootCommon::globals, boot_boot ): %1",
         Builtins.haskey(BootCommon.globals, "boot_boot")
@@ -1034,14 +889,13 @@ module Yast
           # "false".
           # FIXME: add to LILO, ELILO; POWERLILO already should have this
           # (check again)
-          Mode.autoinst && !Builtins.haskey(BootCommon.globals, "boot_boot") &&
+          (Mode.autoinst || Mode.autoupgrade) && !Builtins.haskey(BootCommon.globals, "boot_boot") &&
             !Builtins.haskey(BootCommon.globals, "boot_root") &&
             !Builtins.haskey(BootCommon.globals, "boot_mbr") &&
             !Builtins.haskey(BootCommon.globals, "boot_extended") &&
             !#	    ! haskey( BootCommon::globals, "boot_mbr_md" ) &&
             Builtins.haskey(BootCommon.globals, "boot_custom")
         grub_DetectDisks
-        BootCommon.del_parts = BootStorage.getPartitionList(:deleted, "grub")
         # check whether edd is loaded; if not: load it
         lsmod_command = "lsmod | grep edd"
         Builtins.y2milestone("Running command %1", lsmod_command)
@@ -1069,15 +923,15 @@ module Yast
           BootCommon.cached_settings_base_data_change_time !=
             Storage.GetTargetChangeTime &&
             # bnc#585824 - Bootloader doesn't use defined device map from autoyast
-            !(Mode.autoinst &&
+            !((Mode.autoinst || Mode.autoupgrade) &&
               BootCommon.cached_settings_base_data_change_time == nil)
         BootStorage.ProposeDeviceMap
         md_mbr = BootStorage.addMDSettingsToGlobals
         Ops.set(BootCommon.globals, "boot_md_mbr", md_mbr) if md_mbr != ""
-        BootCommon.InitializeLibrary(true, "grub")
+        BootCommon.InitializeLibrary(true, "grub2")
       end
 
-      if !Mode.autoinst
+      if !Mode.autoinst && !Mode.autoupgrade
         changed = grub_DisksChanged
         if Ops.get_boolean(changed, "changed", false)
           if BootCommon.askLocationResetPopup(
@@ -1097,90 +951,6 @@ module Yast
     # --------------------------------------------------------------
     # other stuff
 
-
-    # FATE #301994 - Correct device mapping in case windows is installed on the second HD
-    # Check if chainloader section with windows is on the first disk
-    #
-    # @param [Hash{String => Object}] section from  BootCommon::sections
-    # @return [Boolean] true if it is necessary remap section
-    def isWidnowsOnBootDisk(section)
-      section = deep_copy(section)
-      # check if it is windows chainloader
-      if Builtins.search(
-          Builtins.tolower(Ops.get_string(section, "name", "")),
-          "windows"
-        ) != nil ||
-          Builtins.search(
-            Builtins.tolower(Ops.get_string(section, "original_name", "")),
-            "windows"
-          ) != nil
-        p_dev = Storage.GetDiskPartition(
-          Ops.get_string(section, "chainloader", "")
-        )
-
-        disk_dev = Ops.get_string(p_dev, "disk", "")
-        if disk_dev == ""
-          Builtins.y2error("trying find disk for windows chainloader failed")
-          return false
-        end
-        # find grub id in device map for chainloader device
-        grub_id = Ops.get(BootStorage.device_mapping, disk_dev, "")
-        Builtins.y2milestone(
-          "Disk from windows chainloader: %1 grub id from device map: %2",
-          disk_dev,
-          grub_id
-        )
-
-        # check if disk is the first in order...
-        return true if grub_id != "hd0"
-      end
-      false
-    end
-
-    # FATE #301994 - Correct device mapping in case windows is installed on the second HD
-    # Remap and make active windows chainloader section
-    # if it is not on the boot (the first) disk
-    # @param list of sections
-    # @return [Array] of sections
-
-    def checkWindowsSection(sections)
-      sections = deep_copy(sections)
-      # list of idexes from sections where is chainloader
-      # and where is necessary add remapping and makeactive
-      list_index = []
-      # counter
-      index = -1
-      # check all sections...
-      Builtins.foreach(sections) do |section|
-        index = Ops.add(index, 1)
-        if Builtins.haskey(section, "chainloader")
-          Builtins.y2debug("chainloader section: %1", section)
-          # add only indexes for update
-          if isWidnowsOnBootDisk(section)
-            list_index = Builtins.add(list_index, index)
-          end
-        end
-      end
-
-      if Ops.greater_than(Builtins.size(list_index), 0)
-        Builtins.foreach(list_index) do |idx|
-          Ops.set(sections, [idx, "remap"], "true")
-          Ops.set(sections, [idx, "makeactive"], "true")
-          Builtins.y2milestone(
-            "Added remap and makeactive for section: %1",
-            Ops.get(sections, idx, {})
-          )
-        end
-      end
-
-      Builtins.y2debug(
-        "Checking sections for windows chainloader: %1",
-        sections
-      )
-      deep_copy(sections)
-    end
-
-
     # FATE #303548 - Grub: limit device.map to devices detected by BIOS Int 13
     # The function reduces records (devices) in device.map
     # Grub doesn't support more than 8 devices in device.map
@@ -1242,60 +1012,5 @@ module Yast
       end
       result
     end
-
-
-    # FATE #303548 - Grub: limit device.map to devices detected by BIOS Int 13
-    # The function check if boot device is in device.map
-    # Grub doesn't support more than 8 devices in device.map
-    # @param string boot device
-    # @param string boot device with name by mountby
-    # @return [Boolean] true if there is missing boot device
-    def checkBootDeviceInDeviceMap(boot_dev, boot_dev_mountby)
-      result = false
-
-      if Ops.greater_than(Builtins.size(BootStorage.device_mapping), 8)
-        result = false
-        bios_order = Convert.convert(
-          Map.Values(BootStorage.device_mapping),
-          :from => "list",
-          :to   => "list <string>"
-        )
-        #delete all grub devices with order more than 9
-        bios_order = Builtins.filter(bios_order) do |key|
-          Ops.less_than(Builtins.size(key), 4)
-        end
-        bios_order = Builtins.lsort(bios_order)
-        Builtins.y2debug("ordered values (grub devices): %1", bios_order)
-        inverse_device_map = {}
-        Builtins.foreach(BootStorage.device_mapping) do |key, value|
-          Ops.set(inverse_device_map, value, key)
-        end
-
-        Builtins.y2debug("inverse_device_map: %1", inverse_device_map)
-        index = 0
-        boot_device_added = false
-        Builtins.foreach(bios_order) do |key|
-          device_name = Ops.get(inverse_device_map, key, "")
-          if Ops.less_than(index, 8)
-            if device_name == boot_dev || device_name == boot_dev_mountby
-              boot_device_added = true
-            end
-            index = Ops.add(index, 1)
-          else
-            if boot_device_added
-              Builtins.y2milestone("Device map includes boot disk")
-              raise Break
-            else
-              Builtins.y2error("Device map doesn't include boot disk")
-              result = true
-              raise Break
-            end
-          end
-        end
-      else
-        Builtins.y2milestone("Device map includes less than 9 devices.")
-      end
-      result
-    end
   end
 end
