@@ -397,7 +397,7 @@ module Yast
         VBox(
           WJ_MakeWidget(:outgoing_mail_server),
           # TLS
-          Label(_("The server uses &TLS.")),
+          Label(_("TLS encryption")),
           RadioButtonGroup(
             Id(:TLS),
             HBox(
@@ -520,7 +520,7 @@ module Yast
               ComboBox(
                 Id(:fm_start),
                 _("Start &fetchmail"),
-                ["manual", "daemon"]
+                [ Item(Id("manual"),_("manual")), Item(Id("daemon"),_("daemon"))]
               )
             )
           )
