@@ -25,6 +25,11 @@
 # Authors:     Arvin Schnell <aschnell@suse.de>
 module Yast
   module PartitioningCustomPartCheckGeneratedInclude
+
+
+    include Yast::Logger
+
+
     def initialize_partitioning_custom_part_check_generated(include_target)
       Yast.import "Arch"
       Yast.import "Storage"
@@ -41,6 +46,7 @@ module Yast
       textdomain "storage"
     end
 
+
     #---------------------------------------------------------------------
     # Checks the generated partition table.
     #---------------------------------------------------------------------
@@ -82,6 +88,8 @@ module Yast
       fat_system_mount = false
       fat_system_boot = false
       raid_type = ""
+      rootdlabel = ""
+      root_subvols_shadowed = false
 
       Builtins.foreach(targetMap) do |disk, diskinfo|
         part_info = Ops.get_list(diskinfo, "partitions", [])
@@ -117,6 +125,33 @@ module Yast
             end
             raid_type = Ops.get_string(part, "raid_type", "") if !boot_raid
             root_lvm = true if Ops.get_symbol(part, "type", :unknown) == :lvm
+            if diskinfo.fetch( "type", :CT_UNKNOWN ) == :CT_DISK 
+               rootdlabel = diskinfo.fetch( "label", "" )
+            end
+
+            # search for shadowed subvolumes of root filesystem
+            subvols = part.fetch("subvol", [])
+            subvols.each do |subvol|
+
+              if FileSystems.default_subvol.empty?
+                tmp = "/" + subvol.fetch("name")
+              else
+                tmp = subvol.fetch("name")[FileSystems.default_subvol.size..-1]
+              end
+
+              targetMap.each do |dev, disk|
+                parts = disk.fetch("partitions", [])
+                parts.each do |part|
+                  if part.has_key?("mount")
+                    mp = part["mount"]
+                    if (tmp == mp) || (tmp.start_with?(mp) && tmp[mp.size] == "/")
+                      root_subvols_shadowed = true
+                    end
+                  end
+                end
+              end
+            end
+
           elsif mountpoint == Partitions.BootMount
             if (Partitions.EfiBoot || Arch.ia64) &&
                 Ops.get_string(diskinfo, "label", "gpt") != "gpt"
@@ -135,20 +170,21 @@ module Yast
             end
             raid_type = Ops.get_string(part, "raid_type", "")
           elsif mountpoint == ""
+            dlabel = diskinfo["label"]
             if Partitions.PrepBoot &&
-                (fsid == Partitions.fsid_prep_chrp_boot || fsid == 6)
+                (fsid == Partitions.FsidBoot(dlabel) || fsid == 6)
               boot_found = true
               boot_end = Region.End(Ops.get_list(part, "region", []))
               boot_fs = Ops.get_symbol(part, "used_fs", :unknown)
               boot_size_k = Ops.get_integer(part, "size_k", 0)
-              boot_fsid = Partitions.fsid_prep_chrp_boot
+              boot_fsid = Partitions.FsidBoot(dlabel)
             elsif Arch.board_mac &&
                 Ops.get_symbol(part, "used_fs", :unknown) == :hfs
               boot_found = true
               boot_end = Region.End(Ops.get_list(part, "region", []))
               boot_fs = Ops.get_symbol(part, "used_fs", :unknown)
               boot_size_k = Ops.get_integer(part, "size_k", 0)
-            elsif fsid == Partitions.fsid_bios_grub
+            elsif !Partitions.EfiBoot() && fsid == Partitions.fsid_bios_grub
               boot_found = true
               boot_end = Region.End(Ops.get_list(part, "region", []))
               boot_fs = :none
@@ -189,22 +225,19 @@ module Yast
           end
         end
       end
+      if rootdlabel.empty?
+        targetMap.values do |diskinfo|
+          if diskinfo.fetch( "type", :CT_UNKNOWN ) == :CT_DISK &&
+             rootdlabel.empty?
+            rootdlabel = diskinfo.fetch( "label", "" )
+          end
+        end
+      end
 
-      Builtins.y2milestone("diskless:%1", diskless)
-      Builtins.y2milestone("root_found:%1 root_fs:%2", root_found, root_fs)
-      Builtins.y2milestone(
-        "boot_found:%1 boot_fs:%2 boot_fsid:%3",
-        boot_found,
-        boot_fs,
-        boot_fsid
-      )
-      Builtins.y2milestone(
-        "root_dmraid:%1 root_raid:%2 boot_raid:%3 raid_type:%4",
-        root_dmraid,
-        root_raid,
-        boot_raid,
-        raid_type
-      )
+      log.info("diskless:#{diskless}")
+      log.info("root_found:#{root_found} root_fs:#{root_fs} rootdlabel:#{rootdlabel}")
+      log.info("boot_found:#{boot_found} boot_fs:#{boot_fs} boot_fsid:#{boot_fsid}")
+      log.info("root_dmraid:#{root_dmraid} root_raid:#{root_raid} boot_raid:#{boot_raid} raid_type:#{raid_type}")
 
       ok = true
 
@@ -261,7 +294,7 @@ module Yast
         ok = false if !Popup.YesNo(message)
       end
 
-      if boot_found && installation || show_all_popups
+      if boot_found && boot_fsid!=Partitions.fsid_bios_grub && installation || show_all_popups
         if Ops.greater_or_equal(boot_end, Partitions.BootCyl) || show_all_popups
           # popup text, %1 is a number
           message = Builtins.sformat(
@@ -300,6 +333,19 @@ module Yast
       end
 
       #/////////////////////////// NO BOOT ///////////////////////////
+      if (!boot_found && installation && 
+          !Partitions.EfiBoot && rootdlabel=="gpt") || show_all_popups
+        message = _(
+          "Warning: There is no partition of type bios_grub present.\n" +
+          "To boot from a GPT disk using grub2 such a partition is needed.\n" +
+          "\n" +
+          "Really use this setup?\n"
+          )
+
+        ok = false if !Popup.YesNo(message)
+        # set it to true to avoid further possible boot warnings
+        boot_found = true
+      end
 
       if !boot_found && installation || show_all_popups
         # iSeries does not really need a boot partition
@@ -345,6 +391,18 @@ module Yast
 
           ok = false if !Popup.YesNo(message)
         end
+
+      end
+
+      if root_subvols_shadowed || show_all_popups
+        message = _(
+          "Warning: Some subvolumes of the root filesystem are shadowed by\n" +
+          "mount points of other filesystem. This could lead to problems.\n" +
+          "\n" +
+          "Really use this setup?\n"
+        )
+
+        ok = false if !Popup.YesNo(message)
       end
 
       # iSeries has no problems with this configuration
@@ -368,30 +426,6 @@ module Yast
         ok = false if !Popup.YesNo(message)
       end
 
-      # iSeries has no problems with this configuration
-      # an initrd will be created and you can boot from a kernel slot
-      if installation && !Arch.board_iseries &&
-          (root_lvm && !boot_found || show_all_popups) &&
-          AutoinstData.BootLVMWarning
-        # popup text
-        message = Builtins.sformat(
-          _(
-            "Warning: With your current setup, your %1 installation\n" +
-              "will encounter problems when booting, because you have no \"boot\"\n" +
-              "partition and your \"root\" partition is an LVM logical volume.\n" +
-              "This does not work.\n" +
-              "\n" +
-              "If you do not know exactly what you are doing, use a normal\n" +
-              "partition for your files below /boot.\n" +
-              "\n" +
-              "Really use this setup?\n"
-          ),
-          Product.name
-        )
-
-        ok = false if !Popup.YesNo(message)
-      end
-
       if (Partitions.EfiBoot || Arch.ia64) && installation &&
           (!boot_found || boot_fs != :vfat) || show_all_popups
         # popup text
@@ -496,6 +530,8 @@ module Yast
 
       ok
     end
+
+
     def check_devices_used(partitions, not_cr)
       partitions = deep_copy(partitions)
       ret = :UB_NONE
@@ -786,5 +822,6 @@ module Yast
       end
       ret
     end
+
   end
 end
