@@ -1,6 +1,6 @@
 # encoding: utf-8
 
-# Copyright (c) 2012 Novell, Inc.
+# Copyright (c) [2012-2014] Novell, Inc.
 #
 # All Rights Reserved.
 #
@@ -39,6 +39,7 @@
 #  $Id$
 module Yast
   module PartitioningCustomPartDialogsInclude
+
     def initialize_partitioning_custom_part_dialogs(include_target)
       Yast.import "UI"
       textdomain "storage"
@@ -512,7 +513,7 @@ module Yast
                       RadioButton(
                         Id(:uuid),
                         # label text
-                        "U&UID"
+                        _("&UUID")
                       )
                     )
                   ),
@@ -1396,60 +1397,6 @@ module Yast
     end
 
 
-    #FIXME: y2-repair uses this, need to find
-    #a better place for it
-    def ReallyInstPrepdisk
-      ret = :none
-
-      doto = Storage.ChangeText
-      Builtins.y2milestone("ReallyInstPrepdisk doto:%1", doto)
-
-      if Builtins.size(doto) == 0
-        # popup text
-        Popup.Message(_("No unsaved changes exist."))
-        ret = :back
-      else
-        dlg = VBox(
-          VSpacing(1),
-          HSpacing(60),
-          # label text
-          Left(Heading(_("Changes:"))),
-          RichText(doto)
-        )
-
-        UI.OpenDialog(
-          Opt(:decorated, :warncolor),
-          HBox(
-            HSpacing(1),
-            VBox(
-              dlg,
-              VSpacing(1),
-              # popup text
-              Heading(_(" Do you really want to execute these changes?")),
-              VSpacing(1),
-              HBox(
-                PushButton(Id(:back), Label.CancelButton),
-                HStretch(),
-                # button text
-                PushButton(Id(:apply), _("&Apply")),
-                PushButton(Id(:finish), Label.FinishButton)
-              ),
-              VSpacing(0.2)
-            ),
-            HSpacing(1)
-          )
-        )
-
-        ret = Convert.to_symbol(UI.UserInput)
-        UI.CloseDialog
-      end
-
-      Builtins.y2milestone("ReallyInstPrepdisk ret=%1", ret)
-
-      ret
-    end
-
-
     # Delete all partition in targetMap from the device "del_dev" and return
     # a new targetMap.
     # Check if LVM partition exists on the device.
@@ -1588,20 +1535,27 @@ module Yast
       deep_copy(items)
     end
 
+
     # Dialog: Subvolume handling
     # @parm old map with original partition
     # @parm new map with changes filled in
     def SubvolHandling(old, new)
       old = deep_copy(old)
       new = deep_copy(new)
+
       # help text, richtext format
       helptext = _(
-        "<p>\n" +
-          "Create and remove subvolumes \n" +
-          "from a Btrfs filesystem.</p>\n"
+        "<p>Create and remove subvolumes from a Btrfs filesystem.</p>\n"
       )
 
+      if Mode.installation()
+        helptext += _(
+          "<p>Enable automatic snapshots for a Btrfs filesystem with snapper.</p>"
+        )
+      end
+
       old_subvol = Ops.get_list(new, "subvol", [])
+      old_userdata = Ops.get_map(new, "userdata", {})
 
       items = SubvolNames(new)
 
@@ -1632,6 +1586,19 @@ module Yast
         )
       )
 
+      if Mode.installation()
+        contents = Builtins.add(contents, VSpacing(0.5))
+        contents = Builtins.add(contents,
+          Left(
+            CheckBox(
+              Id(:snapshots),
+              # TRANSLATOR: checkbox text
+              _("Enable Snapshots")
+            )
+          )
+        )
+      end
+
       UI.OpenDialog(
         Opt(:decorated),
         VBox(
@@ -1651,6 +1618,8 @@ module Yast
         )
       )
 
+      UI.ChangeWidget(Id(:snapshots), :Value, old_userdata["/"] == "snapshots")
+
       UI.ChangeWidget(:help, :HelpText, helptext)
 
       ret = :ok
@@ -1658,7 +1627,10 @@ module Yast
       begin
         ret = UI.UserInput
         Builtins.y2milestone("SubvolHandling ret %1", ret)
-        if ret == :remove
+
+        case ret
+
+        when :remove
           pth = Convert.to_string(UI.QueryWidget(Id(:subvol), :CurrentItem))
           Builtins.y2milestone("SubvolHandling remove path:%1", pth)
           Builtins.y2milestone(
@@ -1684,8 +1656,8 @@ module Yast
           Builtins.y2milestone("SubvolHandling remove items:%1", items)
           changed = true
           UI.ChangeWidget(Id(:subvol), :Items, items)
-        end
-        if ret == :add
+
+        when :add
           pth = Convert.to_string(UI.QueryWidget(Id(:new_path), :Value))
           svtmp = Ops.add(FileSystems.default_subvol, "/")
           Builtins.y2milestone(
@@ -1705,6 +1677,7 @@ module Yast
               svtmp
             )
             Popup.Message(tmp)
+            pth = svtmp + pth
           end
           if Builtins.contains(SubvolNames(new), pth)
             Popup.Message(
@@ -1724,8 +1697,17 @@ module Yast
           items = SubvolNames(new)
           UI.ChangeWidget(Id(:subvol), :Items, items)
           UI.ChangeWidget(Id(:new_path), :Value, "")
-        end
-        if ret == :cancel
+
+        when :ok
+          val = UI.QueryWidget(Id(:snapshots), :Value)
+          if val
+            old_userdata["/"] = "snapshots"
+          else
+            old_userdata.delete("/")
+          end
+          Ops.set(new, "userdata", old_userdata)
+
+        when :cancel
           if changed
             if Popup.YesNo(
                 _("Modifications done so far in this dialog will be lost.")
@@ -1735,15 +1717,20 @@ module Yast
               ret = :again
             end
           end
+
         end
+
       end until ret == :ok || ret == :cancel
 
       UI.CloseDialog
+
       Builtins.y2milestone(
-        "SubvolHandling subvol %1",
-        Ops.get_list(new, "subvol", [])
+        "SubvolHandling subvol:%1 userdata:%2",
+        Ops.get_list(new, "subvol", []),
+        Ops.get_map(new, "userdata", {})
       )
       deep_copy(new)
     end
+
   end
 end
