@@ -279,6 +279,8 @@ module Yast
       elsif !Ops.get_boolean(part, "format", false) &&
           Ops.get_symbol(part, "detected_fs", :none) != :swap
         allowed = false
+        # error popup text
+        Popup.Error(_("It is not allowed to assign the mount point swap\nto a device without a swap file system."));
       end
 
       allowed = CheckFstabOptions(part) if allowed
@@ -422,6 +424,7 @@ module Yast
       Greasemonkey.Transform(subvol)
     end
 
+
     def HandleSubvol(data)
       data = deep_copy(data)
       ret = deep_copy(data)
@@ -431,8 +434,9 @@ module Yast
           Ops.get_symbol(ret, "used_fs", :unknown)
         )
         Builtins.y2milestone(
-          "before HandleSubvol subvol:%1",
-          Ops.get_list(ret, "subvol", [])
+          "before HandleSubvol subvol:%1 userdata:%2",
+          Ops.get_list(ret, "subvol", []),
+          Ops.get_map(ret, "userdata", {})
         )
         if Ops.get_symbol(ret, "used_fs", :unknown) == :btrfs
           if Ops.get_boolean(ret, "format", false)
@@ -441,9 +445,11 @@ module Yast
               :from => "map",
               :to   => "map <string, any>"
             )
+            ret["userdata"] = { "/" => "snapshots" }
             Builtins.y2milestone(
-              "HandleSubvol AddSubvolRoot subvol:%1",
-              Ops.get_list(ret, "subvol", [])
+              "HandleSubvol AddSubvolRoot subvol:%1 userdata:%2",
+              Ops.get_list(ret, "subvol", []),
+              Ops.get_map(ret, "userdata", {})
             )
           else
             Ops.set(
@@ -459,8 +465,9 @@ module Yast
           Ops.set(ret, "subvol", [])
         end
         Builtins.y2milestone(
-          "after  HandleSubvol subvol:%1",
-          Ops.get_list(ret, "subvol", [])
+          "after HandleSubvol subvol:%1 userdata:%2",
+          Ops.get_list(ret, "subvol", []),
+          Ops.get_map(ret, "userdata", {})
         )
       else
         Ops.set(ret, "subvol", [])
@@ -646,9 +653,6 @@ module Yast
     end
 
 
-
-
-
     def HandlePartWidgetChanges(init, ret, file_systems, old, new)
       ret = deep_copy(ret)
       file_systems = deep_copy(file_systems)
@@ -690,6 +694,12 @@ module Yast
           UI.ChangeWidget(Id(:fstab_options), :Enabled, !Builtins.isempty(mp))
         end
       end
+
+      # set btrfs subvolumes (bnc#872210)
+      if init && new.fetch("mount", "") == "/"
+        new = HandleSubvol(new)
+      end
+
       if init && UI.WidgetExists(Id(:format)) || ret == :do_format ||
           ret == :do_not_format
         format = UI.QueryWidget(Id(:format), :Value) == :do_format
@@ -835,7 +845,8 @@ module Yast
               Partitions.fsid_raid,
               Partitions.fsid_hibernation,
               Partitions.fsid_bios_grub,
-              Partitions.fsid_prep_chrp_boot
+              Partitions.fsid_prep_chrp_boot,
+              Partitions.fsid_gpt_prep
             ],
             fs_int
           )
@@ -918,13 +929,7 @@ module Yast
           FileSystemOptions(Ops.get_map(new, "fs_options", {}), selected_fs)
         )
       end
-      if Mode.repair
-        UI.ChangeWidget(Id(:do_mount), :Enabled, false)
-        UI.ChangeWidget(Id(:do_not_mount), :Enabled, false)
-        UI.ChangeWidget(Id(:do_mount_attachment), :Enabled, false)
-        UI.ChangeWidget(Id(:fstab_options), :Enabled, false)
-        UI.ChangeWidget(Id(:crypt_fs), :Enabled, false)
-      end
+
       Builtins.y2milestone("HandlePartWidgetChanges old:%1", old)
       Builtins.y2milestone("HandlePartWidgetChanges new:%1", new)
       deep_copy(new)
