@@ -62,6 +62,8 @@ module Yast
 
       @inst = []
       @all_xpatterns = []
+      @packagesAvailable = []
+      @patternsAvailable = []
 
       @instsource = ""
       @isolinuxcfg = ""
@@ -89,8 +91,8 @@ module Yast
     def Import(settings)
       settings = deep_copy(settings)
       @Software = deep_copy(settings)
-      @patterns = Ops.get_list(settings, "patterns", [])
-      @instsource = Ops.get_string(settings, "instsource", "")
+      @patterns = settings.fetch("patterns",[])
+      @instsource = settings.fetch("instsource","")
 
       notFound = ""
 
@@ -98,17 +100,14 @@ module Yast
       # Packages::Init(true);
       # Packages::InitializeAddOnProducts();
 
-      packagesAvailable = Pkg.GetPackages(:available, true)
-      patternsAvailable = []
+      @packagesAvailable = Pkg.GetPackages(:available, true)
+      @patternsAvailable = []
       allPatterns = Pkg.ResolvableDependencies("", :pattern, "")
       allPatterns = Builtins.filter(allPatterns) do |m|
-        if Ops.get_boolean(m, "user_visible", false)
-          patternsAvailable = Builtins.add(
-            patternsAvailable,
-            Ops.get_string(m, "name", "")
-          )
+        if m.fetch("user_visible",false)
+          @patternsAvailable.push( m.fetch("name","") )
         end
-        Ops.get_boolean(m, "user_visible", false)
+        m.fetch("user_visible",false)
       end
 
       regexFound = []
@@ -118,7 +117,7 @@ module Yast
         Builtins.filter(Ops.get_list(settings, "packages", [])) do |want_pack|
           next true if !Builtins.issubstring(want_pack, "/")
           want_pack = Builtins.deletechars(want_pack, "/")
-          Builtins.foreach(packagesAvailable) do |pack|
+          Builtins.foreach(@packagesAvailable) do |pack|
             Builtins.y2milestone("matching %1 against %2", pack, want_pack)
             if Builtins.regexpmatch(pack, want_pack)
               regexFound = Builtins.add(regexFound, pack)
@@ -175,11 +174,11 @@ module Yast
         )
       end
 
-      PackageAI.toinstall = Ops.get_list(settings, "packages", [])
-      @kernel = Ops.get_string(settings, "kernel", "")
-      AutoinstData.post_packages = Ops.get_list(settings, "post-packages", [])
-      AutoinstData.post_patterns = Ops.get_list(settings, "post-patterns", [])
-      PackageAI.toremove = Ops.get_list(settings, "remove-packages", [])
+      PackageAI.toinstall = settings.fetch("packages",[])
+      @kernel = settings.fetch("kernel","")
+      AutoinstData.post_packages = settings.fetch("post-packages", [])
+      AutoinstData.post_patterns = settings.fetch("post-patterns", [])
+      PackageAI.toremove = settings.fetch("remove-packages", [])
 
       # Imaging
       # map<string, any> image = settings["system_images"]:$[];
@@ -189,15 +188,38 @@ module Yast
       #     modified = false;
       # else
       #     modified = true;
-      @image = Ops.get_map(settings, "image", {})
-      if Ops.get_string(@image, "image_location", "") != "" &&
-          Ops.get_string(@image, "image_name", "") != ""
+      @image = settings.fetch("image",{})
+
+      # image_location and image_name are not mandatory for
+      # extracting an image because it can be defined in the
+      # script too. So it will not be checked here.
+      if @image["script_location"] && !@image["script_location"].empty?
         @imaging = true
       end
-
       true
     end
 
+    def AddYdepsFromProfile( entries )
+      Builtins.y2milestone("AddYdepsFromProfile entries %1", entries)
+      ign = [ "software", "partitioning", "general", "report", "scripts", "suse_register", 
+              "files", "bootloader", "add-on", "dasd", "zfcp", "timezone" ]
+      map = { "networking" => "yast2-network" }
+      entries.reject! { |e| ign.include?(e) }
+      Builtins.y2milestone("AddYdepsFromProfile entries %1", entries)
+      pkglist = []
+      entries.each do |e|
+        name = map.has_key?(e) ? map[e] : "yast2-"+e
+        Builtins.y2milestone("AddYdepsFromProfile name %1 from %2", name, e)
+        pkglist.push(name) if !pkglist.include?(name)
+      end
+      Builtins.y2milestone("AddYdepsFromProfile pkglist %1", pkglist)
+      pkglist.each do |p|
+        if( !PackageAI.toinstall.include?(p) && @packagesAvailable.include?(p) )
+          PackageAI.toinstall.push(p)
+        end
+      end
+    end
+
     # Constructer
     def AutoinstSoftware
       if Stage.cont && Mode.autoinst
@@ -847,6 +869,7 @@ module Yast
 
       computed_packages = Packages.ComputeSystemPackageList
       Builtins.y2debug("Computed list of packages: %1", computed_packages)
+      Pkg.DoProvide(computed_packages)
 
       Builtins.foreach(computed_packages) do |pack2|
         if Ops.greater_than(Builtins.size(@kernel), 0) && pack2 != @kernel &&
@@ -919,23 +942,57 @@ module Yast
       nil
     end
 
+    def locked_packages
+      packages = Pkg.ResolvableProperties("", :package, "").select do |package|
+        # hard AND soft locks
+        package["transact_by"] == :user && (package["locked"] || package["status"] == :available)
+      end
+      packages.map! {|p| p["name"] }
+    end
+
+    def install_packages
+      # user selected packages which have not been already installed
+      packages = Pkg.FilterPackages(
+        solver_selected = false,
+        app_selected = true,
+        user_selected = true,
+        name_only = true)
+
+      # user selected packages which have already been installed
+      installed_by_user = Pkg.GetPackages(:installed, true).select{ |pkg_name|
+        Pkg.PkgPropertiesAll(pkg_name).any? { |package| package["on_system_by_user"] }
+      }
+
+      # Filter out kernel and pattern packages
+      kernel_packages = Pkg.PkgQueryProvides("kernel").collect { |package|
+        package[0]
+      }.compact.uniq
+      pattern_packages = Pkg.PkgQueryProvides("pattern()").collect { |package|
+        package[0]
+      }.compact.uniq
+
+      (packages + installed_by_user).uniq.select{ |pkg_name|
+        !kernel_packages.include?(pkg_name) &&
+        !pattern_packages.include?(pkg_name)
+      }
+    end
+
     # Return list of software packages of calling client
+    # in the installed environment
     # @return [Hash] map of installed software package
     #		"patterns" -> list<string> addon selections
     #		"packages" -> list<string> user selected packages
     #      "remove-packages" -> list<string> packages to remove
     def ReadHelper
-      ret = Pkg.TargetInit("/", false)
-      #        Pkg::TargetInitialize ("/");
+      Pkg.TargetInit("/", false)
       Pkg.TargetLoad
       Pkg.SourceStartManager(true)
       Pkg.PkgSolve(false)
 
-      @inst = Pkg.GetPackages(:installed, true)
       all_patterns = Pkg.ResolvableProperties("", :pattern, "")
       @all_xpatterns = Pkg.ResolvableDependencies("", :pattern, "")
+      to_install_packages = install_packages
       patterns = []
-      visible_patterns = []
 
       patternsFullData = Builtins.filter(all_patterns) do |p|
         ret2 = false
@@ -946,12 +1003,6 @@ module Yast
             Ops.get_string(p, "name", "no name")
           )
           ret2 = true
-          if Ops.get_boolean(p, "user_visible", true) == true
-            visible_patterns = Builtins.add(
-              visible_patterns,
-              Ops.get_string(p, "name", "no name")
-            )
-          end
         end
         ret2
       end
@@ -963,11 +1014,7 @@ module Yast
       Builtins.y2debug("SourceStartCache: %1", Pkg.SourceStartCache(false))
 
       Pkg.SourceStartManager(true)
-
-      userpackages = Pkg.FilterPackages(false, false, true, true)
       Pkg.TargetFinish
-      # Remove kernel packages
-      removepackages = []
 
       patternPackages = []
       new_p = []
@@ -982,10 +1029,6 @@ module Yast
           if Ops.get_string(d, "res_kind", "") == "package" &&
               (Ops.get_string(d, "dep_kind", "") == "requires" ||
                 Ops.get_string(d, "dep_kind", "") == "recommends")
-            patternPackages = Builtins.add(
-              patternPackages,
-              Ops.get_string(d, "name", "")
-            )
             req = true
           end
         end
@@ -996,67 +1039,48 @@ module Yast
       end
       patterns = deep_copy(new_p)
 
-      patternPackagesTemp = deep_copy(patternPackages)
-      run = false
-      emergency_break = 0
-      begin
-        run = false
-        emergency_break = Ops.add(emergency_break, 1)
-        # remove all packages that are pulled in by the resolver anyway
-        tmp = []
-        patternPackagesTemp = Builtins.toset(patternPackagesTemp)
-        Builtins.foreach(patternPackagesTemp) do |ppackage|
-          Builtins.foreach(Pkg.ResolvableDependencies(ppackage, :package, "")) do |d|
-            Builtins.foreach(Ops.get_list(d, "dependencies", [])) do |dd|
-              if Ops.get_string(dd, "res_kind", "") == "package" &&
-                  (Ops.get_string(dd, "dep_kind", "") == "requires" ||
-                    Ops.get_string(dd, "dep_kind", "") == "recommends") &&
-                  !Builtins.contains(
-                    patternPackages,
-                    Ops.get_string(dd, "name", "")
-                  )
-                patternPackages = Builtins.add(
-                  patternPackages,
-                  Ops.get_string(dd, "name", "")
-                )
-                tmp = Builtins.add(tmp, Ops.get_string(dd, "name", ""))
-                run = true
-              end
-            end
-          end
-        end
-        patternPackagesTemp = deep_copy(tmp)
-        Builtins.y2milestone("temp package list = %1", tmp)
-      end while run == true && Ops.less_than(emergency_break, 20)
-
       software = {}
-      if Ops.greater_than(Builtins.size(patterns), 0)
-        Builtins.foreach(@inst) do |p|
-          if !Builtins.contains(patternPackages, p)
-            userpackages = Builtins.add(userpackages, p)
-          end
-        end
-        Builtins.foreach(patternPackages) do |p|
-          if !Builtins.contains(@inst, p)
-            removepackages = Builtins.add(removepackages, p)
-          end
+
+      Ops.set(software, "patterns", Builtins.sort(patterns))
+      # Currently we do not have any information about user deleted packages in
+      # the installed system.
+      # In order to prevent a reinstallation we can take the locked packages at least.
+      # (bnc#888296)
+      software["remove-packages"] = locked_packages
+
+      software["packages"] = to_install_packages
+
+      deep_copy(software)
+    end
+
+    # Return list of software packages, patterns which have been selected
+    # by the user and have to be installed or removed.
+    # The evaluation will be called while the yast installation workflow.
+    # @return [Hash] map of to be installed/removed packages/patterns
+    #		"patterns" -> list<string> of selected patterns
+    #		"packages" -> list<string> user selected packages
+    #           "remove-packages" -> list<string> packages to remove
+    def read_initial_stage
+      install_patterns = Pkg.ResolvableProperties("", :pattern, "").collect do |pattern|
+        # Do not take care about if the pattern has been selected by the user or the product
+        # definition, cause we need a base selection here for the future
+        # autoyast installation. (bnc#882886)
+        if pattern["user_visible"] &&
+          (pattern["status"] == :selected || pattern["status"] == :installed)
+          pattern["name"]
         end
       end
 
-      Ops.set(
-        software,
-        "packages",
-        Builtins.sort(Builtins.filter(userpackages) do |pkg|
-          !Builtins.regexpmatch(pkg, "kernel-.*") || pkg == "kernel-uml"
-        end)
-      )
-      Ops.set(software, "patterns", Builtins.sort(visible_patterns))
-      Ops.set(software, "remove-packages", Builtins.toset(removepackages))
+      software = {}
+      software["packages"] = install_packages
+      software["patterns"] = install_patterns.compact
+      software["remove-packages"] = locked_packages
+      Builtins.y2milestone("autoyast software selection: %1", software)
       deep_copy(software)
     end
 
     def Read
-      Import(ReadHelper())
+      Import((Stage.initial ? read_initial_stage() : ReadHelper()))
     end
 
     publish :variable => :Software, :type => "map"
@@ -1080,6 +1104,7 @@ module Yast
     publish :function => :createISO, :type => "void ()"
     publish :function => :Export, :type => "map ()"
     publish :function => :AddModulePackages, :type => "void (list <string>)"
+    publish :function => :AddYdepsFromProfile, :type => "void (list <string>)"
     publish :function => :RemoveModulePackages, :type => "void (list <string>)"
     publish :function => :Summary, :type => "string ()"
     publish :function => :autoinstPackages, :type => "list <string> ()"
