@@ -34,6 +34,7 @@ YaST::YCP::Import ("NetworkService");
 YaST::YCP::Import ("Hostname");
 YaST::YCP::Import ("FileUtils");
 YaST::YCP::Import ("DnsServerHelperFunctions");
+YaST::YCP::Import ("String");
 
 use DnsZones;
 use DnsTsigKeys;
@@ -44,14 +45,19 @@ use DnsData qw(@tsig_keys $start_service $chroot @allowed_interfaces
 @zones @options @logging $ddns_file_name
 $modified $save_all @files_to_delete %current_zone $current_zone_index
 $write_only @new_includes @deleted_includes
-@zones_update_actions $firewall_support @new_includes_tsig @deleted_includes_tsig);
+@zones_update_actions $firewall_support @new_includes_tsig @deleted_includes_tsig
+$local_forwarder);
 use DnsRoutines;
 
 my $reverse_zones_connections = 'yast2-dns-server_reverse-zones';
 
 my %reverse_zones_connections_data = ();
 
-my $forwarders_include = '/etc/named.d/forwarders.conf';
+my $includes_dir = '/etc/named.d/';
+
+my $forwarders_include = $includes_dir.'forwarders.conf';
+
+my $data_file = Directory->vardir."/dns_server";
 
 # include of forwarders
 my $include_defined_in_conf = 0;
@@ -66,7 +72,7 @@ my %yapi_conf = ();
 
 #my $modify_resolv_conf_dynamically = 0;
 
-my $netconfig_dns_policy = 0;
+my $netconfig_dns_policy = "";
 
 my @acl = ();
 
@@ -105,6 +111,21 @@ sub contains {
     $found;
 }
 
+# System zones are not allowed to be edited in YaST DNS Server
+#
+# @param [String] zone name
+# @return [Boolean] whether zone is a system one (included in bind package)
+sub is_system_zone {
+    my $zone_name = shift;
+
+    return (
+        $zone_name eq "localhost" ||
+        $zone_name eq "0.0.127.in-addr.arpa" ||
+        $zone_name =~ /^(0\.)+ip6.arpa$/ ||
+        $zone_name eq "."
+    );
+}
+
 ##------------------------------------
 # Routines for reading/writing configuration
 
@@ -120,9 +141,10 @@ sub ZoneWrite {
 	return 0;
     }
 
-    if ($zone_name eq "localhost" || $zone_name eq "0.0.127.in-addr.arpa")
+    # Do not write system zones to LDAP (bnc#746401)
+    if ($use_ldap && is_system_zone($zone_name))
     {
-	y2milestone ("Skipping system zone $zone_name");
+	y2milestone ("Using LDAP, skipping system zone $zone_name");
 	return 1;
     }
 
@@ -384,16 +406,23 @@ sub SaveGlobals {
     my @del_zones = grep {
 	! $self->contains (\@current_zones, $_);
     } @old_zones;
+
+    # Do not remove system zones
     @del_zones = grep {
-	$_ ne "zone \".\" in" && $_ ne "zone \"localhost\" in"
-	    && $_ ne "zone \"0.0.127.in-addr.arpa\" in"
+        $_ =~ /^zone[ \t]+\"([^ \t]+)\".*/;
+        my $zone = $1;
+        !is_system_zone($zone)
     } @del_zones;
-    y2milestone ("Deleting zones @del_zones");
-    foreach my $z (@del_zones) {
-	$z =~ /^zone[ \t]+\"([^ \t]+)\".*/;
-	$z = $1;
-	$z = "zone \"$z\" in";
-	SCR->Write (".dns.named.section.\"\Q$z\E\"", undef);
+
+    if (@del_zones > 0) {
+        y2milestone ("Deleting zones @del_zones");
+        foreach my $z (@del_zones) {
+            $z =~ /^zone[ \t]+\"([^ \t]+)\".*/;
+            $z = $1;
+            y2milestone("Deleting zone: ".$z);
+            $z = "zone \"$z\" in";
+            SCR->Write (".dns.named.section.\"\Q$z\E\"", undef);
+        }
     }
 
     if ($use_ldap)
@@ -806,56 +835,36 @@ sub SetLoggingOptions {
 
 BEGIN{$TYPEINFO{StopDnsService} = ["function", "boolean"];}
 sub StopDnsService {
-    my $self = shift;
-
-    my $ret = SCR->Execute (".target.bash", "/etc/init.d/named stop");
-    if ($ret == 0)
+    if (Service->Stop("named"))
     {
 	return 1;
     }
+
     y2error ("Stopping DNS daemon failed");
     return 0;
 }
 
 BEGIN{$TYPEINFO{GetDnsServiceStatus} = ["function", "boolean"];}
 sub GetDnsServiceStatus {
-    my $self = shift;
-
-    my $ret = SCR->Execute (".target.bash", "/etc/init.d/named status");
-    if ($ret == 0)
+    if (Service->Status("named") == 0)
     {
 	return 1;
     }
+
     return 0;
 }
 
 BEGIN{$TYPEINFO{StartDnsService} = ["function", "boolean"];}
 sub StartDnsService { 
-    my $self = shift;
-
-    my $ret = SCR->Execute (".target.bash", "/etc/init.d/named restart");
-    if ($ret == 0)
+    if (Service->Restart("named"))
     {
         return 1;
     }
+
     y2error ("Starting DNS daemon failed");
     return 0;
 }
 
-#BEGIN{$TYPEINFO{GetModifyNamedConfDynamically} = ["function","boolean"];}
-#sub GetModifyNamedConfDynamically {
-#    my $self = shift;
-#
-#    return $modify_named_conf_dynamically;
-#}
-
-#BEGIN{$TYPEINFO{SetModifyNamedConfDynamically} = ["function","void","boolean"];}
-#sub SetModifyNamedConfDynamically {
-#    my $self = shift;
-#    $modify_named_conf_dynamically = shift;
-#    $self->SetModified ();
-#}
-
 BEGIN{$TYPEINFO{GetNetconfigDNSPolicy} = ["function","string"];}
 sub GetNetconfigDNSPolicy{
     my $self = shift;
@@ -866,23 +875,34 @@ sub GetNetconfigDNSPolicy{
 BEGIN{$TYPEINFO{SetNetconfigDNSPolicy} = ["function","void","string"];}
 sub SetNetconfigDNSPolicy{
     my $self = shift;
-    $netconfig_dns_policy= shift;
+    $netconfig_dns_policy = shift;
     $self->SetModified ();
 }
 
-#BEGIN{$TYPEINFO{GetModifyResolvConfDynamically} = ["function","boolean"];}
-#sub GetModifyResolvConfDynamically {
-#    my $self = shift;
-#
-#    return $modify_resolv_conf_dynamically;
-#}
-#
-#BEGIN{$TYPEINFO{SetModifyResolvConfDynamically} = ["function","void","boolean"];}
-#sub SetModifyResolvConfDynamically {
-#    my $self = shift;
-#    $modify_resolv_conf_dynamically = shift;
-#    $self->SetModified ();
-#}
+BEGIN{$TYPEINFO{GetLocalForwarder} = ["function","string"];}
+sub GetLocalForwarder {
+    my $self = shift;
+
+    return "resolver" if (not defined $local_forwarder or $local_forwarder eq "");
+    return $local_forwarder;
+}
+
+BEGIN{$TYPEINFO{SetLocalForwarder} = ["function","boolean","string"];}
+sub SetLocalForwarder {
+    my $self = shift;
+    my $new_local_forwarder = shift;
+
+    if (not defined $new_local_forwarder) {
+        y2error("New local forwarder must be defined");
+        return 0;
+    } elsif (not defined $local_forwarder or $local_forwarder ne $new_local_forwarder) {
+        $local_forwarder = $new_local_forwarder;
+        y2milestone("New local forwarder: ".$local_forwarder);
+        $self->SetModified();
+    }
+
+    return 1;
+}
 
 BEGIN{$TYPEINFO{GetAcl} = ["function",["list","string"]];}
 sub GetAcl {
@@ -1015,21 +1035,12 @@ sub Read {
 	    : 0;
     y2milestone ("Chroot: $chroot");
 
-#    $modify_named_conf_dynamically = SCR->Read (
-#	".sysconfig.network.config.MODIFY_NAMED_CONF_DYNAMICALLY") || "no";
-#    $modify_named_conf_dynamically = $modify_named_conf_dynamically eq "yes"
-#	    ? 1
-#	    : 0;
-#
-#    $modify_resolv_conf_dynamically = SCR->Read (
-#	".sysconfig.network.config.MODIFY_RESOLV_CONF_DYNAMICALLY") || "no";
-#    $modify_resolv_conf_dynamically = $modify_resolv_conf_dynamically eq "yes"
-#	    ? 1
-#	    : 0;
-
     $netconfig_dns_policy = SCR->Read(".sysconfig.network.config.NETCONFIG_DNS_POLICY") || "";
     y2milestone ("NETCONFIG_DNS_POLICY: $netconfig_dns_policy");
-    
+
+    $local_forwarder = SCR->Read(".sysconfig.network.config.NETCONFIG_DNS_FORWARDER") || "resolver";
+    y2milestone ("NETCONFIG_DNS_FORWARDER: $local_forwarder");
+
     my @zone_headers = @{SCR->Dir (".dns.named.section") || []};
     @zone_headers = grep (/^zone/, @zone_headers);
     y2milestone ("Read zone headers @zone_headers");
@@ -1202,9 +1213,16 @@ sub Read {
 	}
 	\%zd;
     } @zone_headers;
+
     @zones = grep {
 	scalar (keys (%{$_})) > 0
     } @zones;
+
+    # System zones cannot be edited in Yast
+    @zones = grep {
+        ! is_system_zone($_->{"zone"})
+    } @zones;
+
     $modified = 0;
 
     Progress->NextStage ();
@@ -1233,6 +1251,80 @@ sub GetWhichZonesAreConnectedWith {
     return \@ret;
 }
 
+# Writes forwarding settings and updates the system using netconfig.
+# This also automatically updates /etc/named.d/forwarders.conf
+sub write_local_forwarder {
+    my $self = shift;
+
+    y2milestone("Current dns forwarder: ".GetLocalForwarder());
+    SCR->Write (".sysconfig.network.config.NETCONFIG_DNS_FORWARDER", GetLocalForwarder());
+    SCR->Write (".sysconfig.network.config", undef);
+
+    y2milestone("Updating forwarders by netconfig");
+    my $ret = SCR->Execute (".target.bash_output", "/sbin/netconfig update -m dns");
+    if ($ret->{'exit'} != 0) {
+        Report->Error (__("Error occurred while calling netconfig.\nError: ".$ret->{'stdout'}));
+    }
+}
+
+sub update_forwarding {
+    # Netconfig updates /etc/named.d/forwarders.conf only if 'bind' is selected
+    # as resolver. Manual writing of forwarders.conf is otherwise requested to be
+    # done by Yast.
+    #
+    # Cheating netconfig by using local 'bind' as resolver temporarily to generate
+    # correct /etc/named.d/forwarders.conf and then returning back to user-defined
+    # resolver.
+    #
+    # This behavior including requested manual changes is described in FATE#309036
+
+    my $self = shift;
+    my $current_forwarder = $self->GetLocalForwarder();
+
+    if ($current_forwarder ne 'bind') {
+        y2milestone(
+            "User-defined forwarder: ".$current_forwarder.", using 'bind' for a while to update forwarders.conf"
+        );
+        $self->SetLocalForwarder('bind');
+
+        $self->write_local_forwarder();
+
+        y2milestone("Returning back to user-defined forwarder: ".$current_forwarder);
+        $self->SetLocalForwarder($current_forwarder);
+    }
+
+    $self->write_local_forwarder();
+}
+
+# Server package should be installed already, but we have to check, e.g.,
+# when applying configuration in AutoYast config module
+sub check_and_install_package {
+    my $self = shift;
+    return 1 if (PackageSystem->Installed("bind"));
+
+    my $installed = 0;
+
+    # Try to install the required package
+    if (Mode->autoinst()) {
+        # Non-interactively, as we can't ask user in this case
+        $installed = PackageSystem->CheckAndInstallPackages(["bind"]);
+    } else {
+        # Package cannot be installed in some modes, changing the mode temporarily
+        my $previous_mode = Mode->mode();
+        Mode->SetMode("normal");
+        $installed = PackageSystem->CheckAndInstallPackagesInteractive(["bind"]);
+
+        # Reread the configuration stat if it has changed
+        $configuration_timestamp = $self->GetConfigurationStat() if $installed;
+        Mode->SetMode($previous_mode);
+    }
+
+    return 1 if $installed;
+
+    y2error("Server package cannot be installed, cannot write configuration");
+    return 0;
+}
+
 BEGIN { $TYPEINFO{Write} = ["function", "boolean"]; }
 sub Write {
     my $self = shift;
@@ -1277,10 +1369,10 @@ sub Write {
     ""
     );
 
-    my $sl = 0;
-
     Progress->NextStage ();
 
+    return 0 unless $self->check_and_install_package();
+
     my $ok = 1;
 
     foreach my $z (@zones) {
@@ -1310,6 +1402,9 @@ sub Write {
 	}
     }
 
+    # Make sure the includes dir really exists
+    SCR->Execute(".target.bash", "mkdir -pv '".String->Quote($includes_dir)."'");
+
     foreach my $z (@zones) {
 
 	if (defined $z->{"connected_with"} && $z->{"connected_with"} ne "") {
@@ -1363,18 +1458,10 @@ sub Write {
     #ensure that if there is an include file, named.conf.include gets recreated
     $ok = $self->EnsureNamedConfIncludeIsRecreated () && $ok;
 
-    #be sure the named.conf file is saved
-    SCR->Write (".dns.named", undef);
-    
     #set daemon starting
     SCR->Write (".sysconfig.named.NAMED_RUN_CHROOTED", $chroot ? "yes" : "no");
     SCR->Write (".sysconfig.named", undef);
 
-#    SCR->Write (".sysconfig.network.config.MODIFY_NAMED_CONF_DYNAMICALLY",
-#	$modify_named_conf_dynamically ? "yes" : "no");
-#    SCR->Write (".sysconfig.network.config.MODIFY_RESOLV_CONF_DYNAMICALLY",
-#	$modify_resolv_conf_dynamically ? "yes" : "no");
-
     # Store the NETCONFIG_DNS_POLICY 
     # Note: NETCONFIG_DNS_STATIC_SERVERS is stored in SaveGlobals();
     SCR->Write (".sysconfig.network.config.NETCONFIG_DNS_POLICY", $netconfig_dns_policy);
@@ -1392,12 +1479,16 @@ sub Write {
 	$ok = $self->ZoneWrite ($z) && $ok;
     }
 
-    my $ret = 0;
+    # Flush the cache after writing zones, but before re/starting service
+    # (otherwise new zones aren't written before closing Yast)
+    SCR->Write (".dns.named", undef);
+
+    my $ret = 1;
     if (scalar (@zones_update_actions) > 0)
     {
 	# named is running
-	if (Service->Status("named")==0) {
-	    $ret = SCR->Execute (".target.bash", "/etc/init.d/named reload");
+	if (Service->Status("named") == 0) {
+	    $ret = Service->Reload("named");
 	}
     }
 
@@ -1405,7 +1496,7 @@ sub Write {
 
     if (scalar (@zones_update_actions) > 0)
     {
-	if ($ret != 0)
+	if (! $ret)
 	{
 	    $ok = 0;
 	}
@@ -1417,51 +1508,38 @@ sub Write {
 
     Progress->NextStage ();
 
-    # set and write forwarding
-    my $forwarder = "bind";
     $ret = {};
 
-    y2milestone("Setting dns forwarder: $forwarder");
-    SCR->Write (".sysconfig.network.config.NETCONFIG_DNS_FORWARDER",$forwarder);
-    SCR->Write (".sysconfig.network.config", undef);
+    my $user_defined_forwarder = GetLocalForwarder();
 
-    # update forwarders.conf
-    y2milestone("Calling netconfig");
-    $ret->{'exit'} = 0;
-    $ret = SCR->Execute (".target.bash_output", "/sbin/netconfig update");
-    if ($ret->{'exit'} != 0)
-    {
-	Report->Error (__("Error occurred while calling netconfig.\nError: ".$ret->{'stdout'}));
-    }
-
-    my $last_forwarder = $forwarder;
+    # Write forwarding settings before starting 'named'
+    $self->update_forwarding();
 
     $ret = {};
     # named has to be started
     if ($start_service)
     {
-	$ret->{'exit'} = 0;
+	my $success = 1;
 	if (! $write_only)
 	{
 	    # named is running
-	    if (Service->Status("named")==0) {
+	    if (Service->Status("named") == 0) {
 		y2milestone("Reloading service 'named'");
-		$ret = SCR->Execute (".target.bash_output", "/etc/init.d/named reload");
+		$success = Service->Reload("named")
 	    } else {
 		y2milestone("Restarting service 'named'");
-		$ret = SCR->Execute (".target.bash_output", "/etc/init.d/named restart");
+		$success = Service->Restart("named")
 	    }
-	    # 'named' is running. Set dns forwarder to 'bind'.
-	    $forwarder="bind";
 	}
 	Service->Enable ("named");
-	if ($ret->{'exit'} != 0)
+	if (! $success)
 	{
 	    # Cannot start service 'named', because of error that follows Error:.  Do not translate named.
-	    Report->Error (__("Error occurred while starting service named.\nError: ".$ret->{'stdout'}));
+	    Report->Error (__("Error occurred while starting service named.\n\n"));
 	    $ok = 0;
-	    # There's no 'named' running. Reset dns forwarder again
-	    $forwarder = "resolver";
+	    # There's no 'named' running -> prevent from blocking DNS queries
+	    $self->SetLocalForwarder("resolver") if GetLocalForwarder() eq "bind";
+	    y2warning("Local forwarder set to: ".GetLocalForwarder());
 	}
     }
     # named has to be stopped
@@ -1470,35 +1548,27 @@ sub Write {
 	if (! $write_only)
 	{
 	    y2milestone("Stopping service 'named'");
-	    SCR->Execute (".target.bash", "/etc/init.d/named stop");
+	    Service->Stop("named");
 	    # There's no 'named' running. Reset dns forwarder again
-	    $forwarder = "resolver";
+	    $self->SetLocalForwarder("resolver") if GetLocalForwarder() eq "bind";
+	    y2warning("Local forwarder set to: ".GetLocalForwarder());
 	}
 	Service->Disable ("named");
     }
 
-    if ($ok)
+    # First run finished
+    if ($ok and first_run())
     {
-	# FIXME when YaST settings are needed
-	SCR->Write (".target.ycp", Directory->vardir() . "/dns_server", {});
+	SCR->Write (".target.string", $data_file, "");
     }
     
     Progress->NextStage ();
 
-    # if $forwarder has changed
-    if ($last_forwarder ne $forwarder) {
-	y2milestone ("NETCONFIG_DNS_FORWARDER has been changed from ".$last_forwarder." to ".$forwarder);
-
-	y2milestone("Setting dns forwarder: $forwarder");
-	SCR->Write (".sysconfig.network.config.NETCONFIG_DNS_FORWARDER",$forwarder);
-	SCR->Write (".sysconfig.network.config", undef);
-
-	y2milestone("Calling netconfig");
-	$ret->{'exit'} = 0;
-	$ret = SCR->Execute (".target.bash_output", "/sbin/netconfig update");
-	if ($ret->{'exit'} != 0) {
-	    Report->Error (__("Error occurred while calling netconfig.\nError: ".$ret->{'stdout'}));
-	}
+    # local forwarder has been changed because 'named' was unable to start
+    # or it was disabled by user
+    if ($user_defined_forwarder ne GetLocalForwarder()) {
+        y2milestone ("NETCONFIG_DNS_FORWARDER has been changed from ".$user_defined_forwarder." to ".GetLocalForwarder());
+        $self->write_local_forwarder();
     }
 
     Progress->NextStage ();
@@ -1509,7 +1579,6 @@ sub Write {
     Progress->set ($progress_orig);
 
     Progress->NextStage ();
-    sleep ($sl);
 
     return $ok;
 }
@@ -1541,11 +1610,24 @@ sub Import {
     my $self = shift;
     my %settings = %{+shift};
 
+    # Cache the timestamp as done in Read() otherwise the named.conf
+    # is re-created from scratch in Write() as is pretends to be changed
+    # while Yast was running.
+    $configuration_timestamp = $self->GetConfigurationStat();
+
     $start_service = $settings{"start_service"} || 0;
     $chroot = $settings{"chroot"} || 1;
     $use_ldap = $settings{"use_ldap"} || 0;
     @allowed_interfaces = @{$settings{"allowed_interfaces"} || []};
-    @zones = @{$settings{"zones"} || []}; 
+
+    @zones = @{$settings{"zones"} || []};
+    for my $zone (@zones) {
+      $zone->{"modified"} = 1;
+      # Local zones are already part of the 'bind' package
+      $zone->{"is_new"} = 1 unless is_system_zone($zone->{"zone"});
+      y2milestone("Imported zone: ".$zone->{"zone"});
+    }
+
     @options = @{$settings{"options"} || []};
     @logging = @{$settings{"logging"} || []};
 
@@ -1598,8 +1680,7 @@ sub Summary {
     }
 
     my @zones_descr = map {
-	my $zone_ref = $_;
-	my %zone_map = %{$zone_ref};	
+	my %zone_map = %{$_};
 	my $zone_name = $zone_map{"zone"} || "";
 	my $zone_type = $zone_map{"type"} || "";
 	$zone_type = $zone_types{$zone_type} || $zone_type;
@@ -1621,7 +1702,7 @@ sub Summary {
 	$_ ne "";
     } @zones_descr;
 
-    my $zones_list = join (", ", @zones_descr);
+    my $zones_list = join (",<br>\n", @zones_descr);
     #  summary string, %s is list of DNS zones (their names), coma separated
     push (@ret, sprintf (__("Configured Zones: %s"), $zones_list));
     return \@ret;
@@ -2098,6 +2179,11 @@ sub ExpertUI () {
     return $expert_ui;
 }
 
+BEGIN { $TYPEINFO{first_run} = ["function", "boolean"]; };
+sub first_run () {
+    return ! FileUtils->Exists($data_file);
+}
+
 1;
 
 # EOF
