@@ -63,6 +63,8 @@ module Yast
           ::Storage::NFS      => :nfs,
           ::Storage::NFS4     => :nfs4,
           ::Storage::TMPFS    => :tmpfs,
+          ::Storage::ISO9660  => :iso9660,
+          ::Storage::UDF      => :udf,
           ::Storage::FSNONE   => :none
         }
       }
@@ -258,6 +260,7 @@ module Yast
         :ntfs       => true,
         :xxefi      => false,
         :xbootdisk  => false,
+        :xxbootdisk => false,
         :xbootfat   => false,
         :xhibernate => true,
         :raid       => true,
@@ -355,10 +358,17 @@ module Yast
           :fsid_item       => "0xFD Linux RAID "
         },
         :xbootdisk  => {
-          :name            => "PPCBOOT",
+          :name            => "PReP",
           :fsid            => Partitions.fsid_prep_chrp_boot,
           :supports_format => false,
-          :fsid_item       => "0x41 PPC PReP Boot"
+          :fsid_item       => "0x41 PReP Boot"
+        },
+        :xxbootdisk  => {
+          :name            => "GPT PReP",
+          :fsid            => Partitions.fsid_gpt_prep,
+          :supports_format => false,
+          :label           => "gpt",
+          :fsid_item       => "0x00 GPT PReP Boot"
         },
         :xbootfat   => {
           :name            => "FATBOOT",
@@ -448,15 +458,16 @@ module Yast
               Ops.get(order_m_mpoints, b, 99)
             )
         end
-        Builtins.y2milestone("SuggestMPoints init:%1", @suggest_m_points)
+        Builtins.y2milestone("SuggestMPoints ret:%1", @suggest_m_points)
       end
       deep_copy(@suggest_m_points)
     end
 
-    def SuggesTmpfsMPoints
+
+    def SuggestTmpfsMPoints
       if Builtins.size(@suggest_tmp_points) == 0
         @suggest_tmp_points = ["/run", "/var/run", "/tmp", "/var/lock"]
-        Builtins.y2milestone("SuggesTmpfsMPoints init:%1", @suggest_tmp_points)
+        Builtins.y2milestone("SuggestTmpfsMPoints ret:%1", @suggest_tmp_points)
       end
       deep_copy(@suggest_tmp_points)
     end
@@ -497,7 +508,7 @@ module Yast
         {
           # button text
           :widget    => Left(
-            CheckBox(Id("opt_user"), _("Mountable by &User"), false)
+            CheckBox(Id("opt_user"), _("Mountable by User"), false)
           ),
           :query_key => "opt_user",
           # help text, richtext format
@@ -1288,10 +1299,30 @@ module Yast
         },
         :tmpfs   => {
           :name         => "TmpFS",
-          :mountpoints  => SuggesTmpfsMPoints(),
+          :mountpoints  => SuggestTmpfsMPoints(),
           :mount_string => "tmpfs",
           :mount_option => "-t tmpfs",
           :fst_options  => @tmpfs_fst_options
+        },
+        :iso9660 => {
+          :name            => "ISO9660",
+          :real_fs         => true,
+          :supports_format => false,
+          :crypt           => false,
+          :mountpoints     => [],
+          :mount_string    => "iso9660",
+          :mount_option    => "-t iso9660",
+          :options         => []
+        },
+        :udf => {
+          :name            => "UDF",
+          :real_fs         => true,
+          :supports_format => false,
+          :crypt           => false,
+          :mountpoints     => [],
+          :mount_string    => "udf",
+          :mount_option    => "-t udf",
+          :options         => []
         }
       }
 
@@ -1359,6 +1390,7 @@ module Yast
       deep_copy(ret)
     end
 
+
     def FindFsid(fs_item)
       ret = nil
       fs = Convert.convert(
@@ -1379,11 +1411,13 @@ module Yast
       ret
     end
 
+
     def FileSystems
       Ops.set(@support, :vfat, false) if Arch.sparc64 || Arch.sparc32
       if Arch.ppc
         Ops.set(@support, :vfat, Arch.board_chrp)
         Ops.set(@support, :xbootdisk, true)
+        Ops.set(@support, :xxbootdisk, true)
         Ops.set(@support, :xbootfat, Arch.board_chrp)
       end
       Ops.set(@support, :vfat, false) if Arch.s390
@@ -1405,12 +1439,7 @@ module Yast
     def InitSlib(value)
       @sint = value
       if @sint != nil
-        ret = @sint.getDefaultSubvolName
-        Builtins.y2milestone("InitSlib libstorage default_subvol:\"%1\"", ret)
-        ret = ""
-        @sint.setDefaultSubvolName(ret)
-        ret = @sint.getDefaultSubvolName
-        @default_subvol = ret
+        @default_subvol = @sint.getDefaultSubvolName()
         Builtins.y2milestone(
           "InitSlib used default_subvol:\"%1\"",
           @default_subvol
@@ -1420,6 +1449,7 @@ module Yast
       nil
     end
 
+
     def assertInit
       if @sint == nil
         @sint = StorageInit.CreateInterface(false)
@@ -1466,7 +1496,7 @@ module Yast
 
     def GetSupportFormat(used_fs)
       fsmap = GetFsMap(used_fs)
-      Ops.get_boolean(fsmap, :supports_format)
+      Ops.get_boolean(fsmap, :supports_format, false)
     end
 
     def GetFsidItem(used_fs)
@@ -2009,7 +2039,7 @@ module Yast
     publish :variable => :default_subvol, :type => "string"
     publish :variable => :nchars, :type => "string"
     publish :function => :SuggestMPoints, :type => "list <string> ()"
-    publish :function => :SuggesTmpfsMPoints, :type => "list <string> ()"
+    publish :function => :SuggestTmpfsMPoints, :type => "list <string> ()"
     publish :function => :GetGeneralFstabOptions, :type => "list <map <symbol, any>> ()"
     publish :function => :GetJournalFstabOptions, :type => "list <map <symbol, any>> ()"
     publish :function => :GetAclFstabOptions, :type => "list <map <symbol, any>> ()"
