@@ -36,6 +36,8 @@ require "yast"
 
 module Yast
   class ImageInstallationClass < Module
+    include Yast::Logger
+
     def main
       Yast.import "UI"
       Yast.import "Pkg"
@@ -139,6 +141,9 @@ module Yast
           "steps_reserved" => 10
         }
       }
+
+      # Images selected by FindImageSet()
+      @selected_images = {}
     end
 
     # Set the repository to get images from
@@ -472,6 +477,31 @@ module Yast
       # FIXME error checking
     end
 
+    def DeployDiskImage(id, target)
+      InitRepo()
+
+      file = Ops.get_string(@_images, [id, "file"], "")
+      Builtins.y2milestone("Deploying disk image %1 (%2) on %3", id, file, target)
+      file = Builtins.sformat("%1/%2", @_image_path, file)
+      # BNC #409927
+      # Checking files for signatures
+      image = Pkg.SourceProvideDigestedFile(@_repo, 1, file, false)
+
+      if image.nil?
+        Builtins.y2error("File %1 not found on media", file)
+        return false
+      end
+
+      Builtins.y2milestone("Copying the image")
+      cmd = Builtins.sformat("dd bs=1048576 if=%1 of=%2", image, target) #1MB of block size
+      out = SCR.Execute(path(".target.bash_output"), cmd)
+      Builtins.y2milestone("Executing %1 returned %2", cmd, out)
+
+      RemoveTemporaryImage(image)
+
+      out["exit"] == 0
+    end
+
     # Mount an image of the filesystem type
     # Does not integrate to the system, mounts on target
     # @param [String] id string the id of the image
@@ -579,6 +609,8 @@ module Yast
         return temporary ? MountFsImage(id, target) : DeployFsImage(id, target)
       elsif type == "tar"
         return DeployTarImage(id, target)
+      elsif type == "raw"
+        return DeployDiskImage(id, target)
       end
 
       Builtins.y2error("Unknown type of image: %1", type)
@@ -768,6 +800,13 @@ module Yast
       Ops.greater_or_equal(matching_patterns, patterns_in_imagesets)
     end
 
+    def PrepareOEMImage(path)
+      AddImage(
+        "OEM", path, "raw"
+      )
+      @_image_order = [ path ]
+    end
+
     # Find a set of images which suites selected patterns
     # @param [Array<String>] patterns a list of patterns which are selected
     # @return [Boolean] true on success or when media does not contain any images
@@ -852,7 +891,7 @@ module Yast
 
       # trying to find all matching patterns
       Builtins.foreach(image_sets) do |image|
-        pattern = Ops.get_string(image, "patterns", "")
+        pattern = image["patterns"]
         imageset_patterns = Builtins.splitstring(pattern, ", ")
         Ops.set(
           patterns_in_imagesets,
@@ -883,11 +922,7 @@ module Yast
         end
       end
 
-      Builtins.y2debug(
-        "Matching patterns: %1, sizes: %2",
-        possible_patterns,
-        matching_patterns
-      )
+      log.info "Matching patterns: #{possible_patterns}, sizes: #{matching_patterns}"
 
       # selecting the best imageset
       last_pattern = ""
@@ -923,6 +958,7 @@ module Yast
       end
 
       Builtins.y2milestone("Result: %1/%2", last_pattern, result)
+      @selected_images = result
 
       # No matching pattern
       if result == {}
@@ -1452,10 +1488,16 @@ module Yast
       @_image_order = []
       @images_details = {}
       @_mounted_images = []
+      @selected_images = {}
 
       nil
     end
 
+    # Only for checking in tests now
+    def selected_images
+      @selected_images
+    end
+
     publish :function => :SetRepo, :type => "void (integer)"
     publish :variable => :last_patterns_selected, :type => "list <string>"
     publish :variable => :changed_by_user, :type => "boolean"
@@ -1482,6 +1524,7 @@ module Yast
     publish :function => :StoreAllChanges, :type => "void ()"
     publish :function => :RestoreAllChanges, :type => "boolean ()"
     publish :function => :FreeInternalVariables, :type => "void ()"
+    publish :function => :PrepareOEMImage, :type => "void ()"
   end
 
   ImageInstallation = ImageInstallationClass.new
