@@ -30,6 +30,7 @@
 # Representation of the configuration of network cards.
 # Input and output routines.
 require "yast"
+require "network/confirm_virt_proposal"
 
 module Yast
   class LanClass < Module
@@ -41,7 +42,6 @@ module Yast
       Yast.import "DNS"
       Yast.import "NetHwDetection"
       Yast.import "Host"
-      Yast.import "Hostname"
       Yast.import "IP"
       Yast.import "Map"
       Yast.import "Mode"
@@ -52,21 +52,19 @@ module Yast
       Yast.import "ProductFeatures"
       Yast.import "Routing"
       Yast.import "Progress"
-      Yast.import "Service"
       Yast.import "String"
-      Yast.import "Summary"
       Yast.import "SuSEFirewall4Network"
       Yast.import "FileUtils"
       Yast.import "PackageSystem"
       Yast.import "LanItems"
       Yast.import "ModuleLoading"
       Yast.import "Linuxrc"
-      Yast.import "Stage"
       Yast.import "LanUdevAuto"
-      Yast.import "Label"
+      Yast.import "Report"
 
       Yast.include self, "network/complex.rb"
       Yast.include self, "network/runtime.rb"
+      Yast.include self, "network/lan/bridge.rb"
 
       #-------------
       # GLOBAL DATA
@@ -76,21 +74,6 @@ module Yast
 
       @write_only = false
 
-      # Current module information
-      # FIXME: MOD global map Module = $[];
-
-      # propose configuration for virtual networks (bridged) ?
-      @virt_net_proposal = nil
-
-      # autoinstallation: if true, write_only is disabled and the network settings
-      # are applied at once, like during the normal installation. #128810, #168806
-      # boolean start_immediately = false;
-
-      # boolean if we do automatic installation in second stage
-
-      @automatic_configuration = false
-
-
       # ipv6 module
       @ipv6 = true
 
@@ -550,11 +533,6 @@ module Yast
       end
       # Progress stage 10
       step_labels = Builtins.add(step_labels, _("Update configuration"))
-      if !NetworkService.IsManaged &&
-          !@write_only #(boolean) SCR::Read(.init.scripts.exists, "smpppd") &&
-        # Progress stage 11
-        step_labels = Builtins.add(step_labels, _("Set up smpppd"))
-      end
 
       Progress.New(
         caption,
@@ -574,17 +552,7 @@ module Yast
       return false if Abort()
       # Progress step 3 - multiple devices may be present, really plural
       ProgressNextStage(_("Writing device configuration..."))
-      if !Mode.autoinst && LanUdevAuto.AllowUdevModify
-        LanItems.WriteUdevRules
-        # wait so that ifcfgs written in NetworkInterfaces are newer
-        # (1-second-wise) than netcontrol status files,
-        # and rcnetwork reload actually works (bnc#749365)
-        SCR.Execute(path(".target.bash"), "udevadm settle")
-        Builtins.sleep(1000)
-      end
-      # hack: no "netcard" filter as biosdevname names it diferently (bnc#712232)
-      NetworkInterfaces.Write("")
-      # WriteDevices();
+      LanItems.write
       Builtins.sleep(sl)
 
       return false if Abort()
@@ -617,7 +585,6 @@ module Yast
       return false if Abort()
       # Progress step 7
       ProgressNextStage(_("Setting up network services..."))
-      NetworkService.EnableDisable
       writeIPv6
       Builtins.sleep(sl)
 
@@ -637,7 +604,7 @@ module Yast
         # Progress step 9
         ProgressNextStage(_("Activating network services..."))
         # during installation export sysconfig settings into NetworkManager (bnc#433084)
-        if Mode.installation && NetworkService.IsManaged
+        if Mode.installation && NetworkService.is_network_manager
           Builtins.y2internal(
             "Export sysconfig settings into NetworkManager %1",
             SCR.Execute(
@@ -647,105 +614,18 @@ module Yast
           )
         end
 
-        Builtins.y2internal("virt_net_proposal %1", @virt_net_proposal)
-        if Stage.cont && @virt_net_proposal == true &&
-            (Linuxrc.usessh || Linuxrc.vnc || Linuxrc.display_ip)
-          UI.OpenDialog(
-            Opt(:decorated),
-            HBox(
-              HSpacing(1),
-              HCenter(
-                HSquash(
-                  VBox(
-                    HCenter(
-                      HSquash(
-                        VBox(
-                          # This is the heading of the popup box
-                          Left(Heading(_("Confirm Network Restart"))),
-                          VSpacing(0.5),
-                          # This is in information message. Next come the
-                          # hardware class name (network cards).
-                          HVCenter(
-                            Label(
-                              _(
-                                "Because of the bridged network, YaST2 needs to restart the network to apply the settings."
-                              )
-                            )
-                          ),
-                          VSpacing(0.5)
-                        )
-                      )
-                    ),
-                    ButtonBox(
-                      HWeight(
-                        1,
-                        PushButton(
-                          Id(:ok),
-                          Opt(:default, :okButton),
-                          Label.OKButton
-                        )
-                      ),
-                      # PushButton label
-                      HWeight(
-                        1,
-                        PushButton(
-                          Id(:cancel),
-                          Opt(:cancelButton),
-                          Label.CancelButton
-                        )
-                      )
-                    ),
-                    VSpacing(0.2)
-                  )
-                )
-              ),
-              HSpacing(1)
-            )
-          )
+        activate_network_service
 
-          UI.SetFocus(Id(:ok))
-
-          # for autoinstallation popup has timeout 10 seconds (#192181)
-          # timeout for every case (bnc#429562)
-          ret = UI.TimeoutUserInput(10 * 1000)
-          if ret == :ok
-            Builtins.y2internal(
-              "Restarting network because of bridged proposal"
-            )
-            NetworkService.Restart
-          end
-          UI.CloseDialog
-        # For ssh/vnc installation don't reload/restart network because possibility of IP change (bnc#347482)
-        elsif Stage.cont &&
-            (Linuxrc.usessh || Linuxrc.vnc || Linuxrc.display_ip)
-          Builtins.y2milestone(
-            "For ssh or vnc installation don't reload/restart network during installation."
-          )
-        elsif LanItems.force_restart
-          NetworkService.Restart
-        else
-          NetworkService.ReloadOrRestart
-        end
         Builtins.sleep(sl)
       end
 
       return false if Abort()
       # Progress step 10
       ProgressNextStage(_("Updating configuration..."))
-      RunSuSEconfig() if !@write_only
+      update_mta_config if !@write_only
       Builtins.sleep(sl)
 
-      if !NetworkService.IsManaged && #&& (boolean) SCR::Read(.init.scripts.exists, "smpppd")
-          !@write_only
-        return false if Abort()
-        # Progress step 11
-        ProgressNextStage(_("Setting up smpppd(8)..."))
-        # takes care of autoinst by itself
-        SetupSMPPPD(false)
-        Builtins.sleep(sl)
-      end
-
-      if NetworkService.IsManaged
+      if NetworkService.is_network_manager
         network = false
         timeout = 15
         while Ops.greater_than(timeout, 0)
@@ -757,13 +637,8 @@ module Yast
           Builtins.sleep(1000)
           timeout = Ops.subtract(timeout, 1)
         end
-        if !network
-          if @automatic_configuration
-            Builtins.y2error("No network running")
-          else
-            Popup.Error(_("No network running"))
-          end
-        end
+
+        Popup.Error(_("No network running")) unless network
       end
 
       # Final progress step
@@ -817,7 +692,17 @@ module Yast
       NetworkConfig.Import(Ops.get_map(settings, "config", {}))
       DNS.Import(Builtins.eval(Ops.get_map(settings, "dns", {})))
       Routing.Import(Builtins.eval(Ops.get_map(settings, "routing", {})))
-      NetworkService.SetManaged(Ops.get_boolean(settings, "managed", false))
+
+      if Ops.get_boolean(settings, "managed", false)
+        if NetworkService.is_backend_available(:network_manager)
+          NetworkService.use_network_manager
+        else
+          Report.Warning(_("AutoYaST setting networking/managed: NetworkManager is not available, Wicked will be used."))
+          NetworkService.use_wicked
+        end
+      else
+        NetworkService.use_wicked
+      end
       if Builtins.haskey(settings, "ipv6")
         @ipv6 = Ops.get_boolean(settings, "ipv6", true)
       end
@@ -844,7 +729,7 @@ module Yast
         "devices"              => devices,
         "ipv6"                 => @ipv6,
         "routing"              => Routing.Export,
-        "managed"              => NetworkService.IsManaged,
+        "managed"              => NetworkService.is_network_manager,
         "start_immediately"    => Ops.get_boolean(
           LanItems.autoinstall_settings,
           "start_immediately",
@@ -900,7 +785,7 @@ module Yast
       link_virt_net = nil
       header_nm = _("Network Mode")
 
-      if NetworkService.IsManaged
+      if NetworkService.is_network_manager
         href_nm = "lan--nm-disable"
         # network mode: the interfaces are controlled by the user
         status_nm = _("Interfaces controlled by NetworkManager")
@@ -912,9 +797,7 @@ module Yast
         status_nm = _("Traditional network setup with NetControl - ifup")
         # enable NetworkManager applet
         # for virtual network proposal (bridged) don't show hyperlink to enable networkmanager
-        link_nm = @virt_net_proposal ?
-          "..." :
-          Hyperlink(href_nm, _("Enable NetworkManager"))
+        link_nm = Hyperlink(href_nm, _("Enable NetworkManager"))
       end
 
       if @ipv6
@@ -930,28 +813,6 @@ module Yast
         # enable ipv6 support
         link_v6 = Hyperlink(href_v6, _("Enable IPv6"))
       end
-      # no exception needed for virtualbox* (bnc#648044) http://www.virtualbox.org/manual/ch06.html
-      if PackageSystem.Installed("xen") && !Arch.is_xenU ||
-          PackageSystem.Installed("kvm") ||
-          PackageSystem.Installed("qemu")
-        if @virt_net_proposal
-          href_virt_net = "virtual-revert"
-          status_virt_net = _(
-            "Proposed bridged configuration for virtual machine network"
-          )
-          link_virt_net = Hyperlink(
-            href_virt_net,
-            _("Use non-bridged configuration")
-          )
-        else
-          href_virt_net = "virtual-enable"
-          status_virt_net = _("Proposed non-bridged network configuration")
-          link_virt_net = Hyperlink(
-            href_virt_net,
-            _("Use bridged configuration")
-          )
-        end
-      end
       descr = Builtins.sformat(
         "<ul><li>%1: %2 (%3)</li></ul> \n\t\t\t     <ul><li>%4 (%5)</li></ul>",
         header_nm,
@@ -984,16 +845,6 @@ module Yast
       true
     end
 
-    # Edit the given device
-    # @param [String] name device to edit
-    # @return true if success
-    def Edit(name)
-      LanItems.operation = nil
-      return false if LanItems.Select(name) != true
-      NetworkInterfaces.Edit(name)
-      LanItems.operation = :edit
-      true
-    end
     # Delete the given device
     # @param name device to delete
     # @return true if success
@@ -1036,29 +887,6 @@ module Yast
       nm_default && nm_installed
     end
 
-    # Create minimal ifcfgs for the case when NetworkManager is used:
-    # NM does not need them but yast2-firewall and SuSEfirewall2 do
-    # Avoid existing ifcfg from network installation
-    def ProposeNMInterfaces
-      Builtins.y2milestone("Minimal ifcfgs for NM")
-      Builtins.foreach(LanItems.Items) do |number, lanitem|
-        if IsNotEmpty(
-            Ops.get_string(Convert.to_map(lanitem), ["hwinfo", "dev_name"], "")
-          )
-          LanItems.current = number
-          if !LanItems.IsCurrentConfigured
-            Builtins.y2milestone(
-              "Nothing already configured start proposing %1 (NM)",
-              LanItems.getCurrentItem
-            )
-            LanItems.ProposeItem
-          end
-        end
-      end
-
-      nil
-    end
-
     def IfcfgsToSkipVirtualizedProposal
       skipped = []
       Builtins.foreach(LanItems.Items) do |current, config|
@@ -1194,28 +1022,8 @@ module Yast
             "ETHTOOLS_OPTIONS"
           )
           if NetworkInterfaces.Commit
-            NetworkInterfaces.Add
-            NetworkInterfaces.Edit(ifcfg)
-            Ops.set(old_config, "BOOTPROTO", "static")
-            Ops.set(old_config, "IPADDR", "0.0.0.0/32")
-            # remove all aliases (bnc#590167)
-            Builtins.foreach(
-              Ops.get_map(NetworkInterfaces.Current, "_aliases", {})
-            ) do |a, v|
-              if v != nil
-                NetworkInterfaces.DeleteAlias(NetworkInterfaces.Name, a)
-              end
-            end
-            #take out PREFIXLEN from old configuration (BNC#735109)
-            Ops.set(old_config, "PREFIXLEN", "")
-            Ops.set(old_config, "_aliases", {})
-            Builtins.y2milestone(
-              "Old Config with apllied changes %1\n%2",
-              ifcfg,
-              old_config
-            )
-            NetworkInterfaces.Current = deep_copy(old_config)
-            NetworkInterfaces.Commit
+            # reconfigure existing device as newly created bridge's port
+            configure_as_bridge_port(ifcfg)
 
             Ops.set(LanItems.Items, [current, "ifcfg"], new_ifcfg)
             LanItems.modified = true
@@ -1232,217 +1040,8 @@ module Yast
       nil
     end
 
-    # Propose interface configuration
-    # @return true if something was proposed
-    def ProposeInterfaces
-      Builtins.y2milestone("Hardware=%1", LanItems.Hardware)
-
-      Builtins.y2milestone("NetworkConfig::Config=%1", NetworkConfig.Config)
-      Builtins.y2milestone("NetworkConfig::DHCP=%1", NetworkConfig.DHCP)
-
-      # test if we have any virtualization installed
-      if @virt_net_proposal
-        Builtins.y2milestone(
-          "Virtualization [xen|kvm|qemu] detected - will propose virtualization network"
-        )
-        ProposeVirtualized()
-      else
-        if !LanItems.nm_proposal_valid
-          NetworkService.SetManaged(UseNetworkManager())
-          LanItems.nm_proposal_valid = true
-        end
-
-        if NetworkService.IsManaged
-          ProposeNMInterfaces()
-
-          LanItems.modified = true # #144139 workaround
-          Builtins.y2milestone("NM proposal")
-          return true
-        end
-      end
-      # Something is already configured -> do nothing
-      configured = false
-      Builtins.foreach(LanItems.Items) do |number, lanitem|
-        LanItems.current = number
-        if LanItems.IsCurrentConfigured
-          Builtins.y2milestone("Something already configured: don't propose.")
-          configured = true
-          raise Break
-        end
-      end
-      return false if configured
-
-
-      Builtins.foreach(LanItems.Items) do |number, lanitem|
-        if IsNotEmpty(
-            Ops.get_string(Convert.to_map(lanitem), ["hwinfo", "dev_name"], "")
-          )
-          LanItems.current = number
-          link = Ops.get_boolean(
-            LanItems.getCurrentItem,
-            ["hwinfo", "link"],
-            false
-          )
-          if Ops.get_string(LanItems.getCurrentItem, ["hwinfo", "type"], "") == "wlan"
-            Builtins.y2warning("Will not propose wlan interfaces")
-          else
-            if !link
-              Builtins.y2warning(
-                "item number %1 has link:false detected",
-                number
-              )
-            elsif !LanItems.IsCurrentConfigured && link
-              Builtins.y2milestone(
-                "Nothing already configured - start proposing"
-              )
-              LanItems.ProposeItem
-              raise Break
-            end
-          end
-        end
-      end
-
-      Builtins.y2milestone("NetworkConfig::Config=%1", NetworkConfig.Config)
-      Builtins.y2milestone("NetworkConfig::DHCP=%1", NetworkConfig.DHCP)
-
-      true
-    end
-
-    # Propose the hostname
-    # See also DNS::Read
-    # @return true if something was proposed
-    def ProposeHostname
-      if DNS.proposal_valid
-        # the standalone hostname dialog did the job already
-        return false
-      end
-
-      true
-    end
-
-    # Propose configuration for routing and resolver
-    # @return true if something was proposed
-    def ProposeRoutesAndResolver
-      if LanItems.bootproto == "static" && LanItems.ipaddr != "" &&
-          LanItems.ipaddr != nil
-        ProposeHostname()
-      end
-      true
-    end
-
-    # Propose a configuration
-    # @return true if something was proposed
-    def Propose
-      NetworkInterfaces.CleanCacheRead
-      LanItems.Read
-      ProposeInterfaces() && ProposeRoutesAndResolver()
-    end
-
     # Create a configuration for autoyast
     # @return true if something was proposed
-    def Autoinstall
-      Builtins.y2milestone("Hardware=%1", LanItems.Hardware)
-      tosel = nil
-
-      # Some HW found -> use it for proposal
-      if Ops.greater_than(Builtins.size(LanItems.Hardware), 0) &&
-          Ops.greater_than(
-            Builtins.size(
-              Ops.get_list(LanItems.autoinstall_settings, "interfaces", [])
-            ),
-            0
-          )
-        Builtins.foreach(
-          Ops.get_list(LanItems.autoinstall_settings, "interfaces", [])
-        ) do |interface|
-          devs = NetworkInterfaces.List("")
-          Builtins.y2milestone("devs: %1", devs)
-          tosel = nil
-          Add()
-          tosel = LanItems.FindMatchingDevice(interface)
-          Builtins.y2milestone("tosel=%1", tosel)
-          # Read module data from autoyast
-          aymodule = LanItems.GetModuleForInterface(
-            Ops.get(interface, "device", ""),
-            Ops.get_list(LanItems.autoinstall_settings, "modules", [])
-          )
-          if tosel != nil
-            Ops.set(
-              tosel,
-              "module",
-              Ops.get_string(aymodule, "module", "") != "" ?
-                Ops.get_string(aymodule, "module", "") :
-                Ops.get_string(tosel, "module", "")
-            )
-            Ops.set(
-              tosel,
-              "options",
-              Ops.get_string(aymodule, "options", "") != "" ?
-                Ops.get_string(aymodule, "options", "") :
-                Ops.get_string(tosel, "options", "")
-            )
-
-            LanItems.SelectHWMap(tosel)
-          else
-            Builtins.y2milestone(
-              "No hardware, no install.inf -> no autoinstallation possible."
-            )
-            next false
-          end
-          # The uppercasing is also done in lan_auto::FromAY
-          # but the output goes to "devices" whereas here
-          # we use "interfaces". FIXME.
-          newk = nil
-          interface = Builtins.mapmap(interface) do |k, v|
-            newk = Builtins.toupper(k)
-            { newk => v }
-          end
-          defaults = Builtins.union(
-            LanItems.SysconfigDefaults,
-            LanItems.GetDefaultsForHW
-          )
-          # Set interface variables
-          LanItems.SetDeviceVars(interface, defaults)
-          Builtins.y2debug(
-            "ipaddr,bootproto=%1,%2",
-            LanItems.ipaddr,
-            LanItems.bootproto
-          )
-          if LanItems.bootproto == "static" && LanItems.ipaddr != "" &&
-              LanItems.ipaddr != nil
-            Builtins.y2milestone("static configuration")
-
-            if LanItems.netmask == nil || LanItems.netmask == ""
-              LanItems.netmask = "255.255.255.0"
-            end
-          end
-          LanItems.Commit
-        end
-      else
-        Builtins.y2milestone(
-          "no interface configuration, taking it from install.inf"
-        )
-        ProposeInterfaces()
-      end
-
-      # #153426 - using ProposeInterfaces instead of Propose omitted these
-      # if they are nonempty, Import has already taken care of them.
-      if Ops.get_list(LanItems.autoinstall_settings, ["routing", "routes"], []) == []
-        Builtins.y2milestone("gateway from install.inf") 
-        #	Routing::ReadFromGateway (InstallInf["gateway"]:"");
-      end
-      if Ops.get_list(LanItems.autoinstall_settings, ["dns", "nameservers"], []) == []
-        Builtins.y2milestone("nameserver from install.inf") 
-        #	DNS::ReadNameserver (InstallInf["nameserver"]:"");
-      end
-      if Ops.get_string(LanItems.autoinstall_settings, ["dns", "hostname"], "") == ""
-        ProposeHostname()
-      end
-
-      true
-    end
-
-
     # Check if any device  is configured with DHCP.
     # @return true if any DHCP device is configured
     def AnyDHCPDevice
@@ -1464,90 +1063,52 @@ module Yast
       )
     end
 
-
-    def PrepareForAutoinst
-      #    ReadInstallInf();
-      LanItems.ReadHw
-      deep_copy(LanItems.Hardware)
-    end
-
     # @return [Array] of packages needed when writing the config
     def Packages
-      pkgs = []
-      required = {
-        "types"   => {
-          #for wlan require iw instead of wireless-tools (bnc#539669)
-          "wlan" => "iw",
-          "vlan" => "vlan",
-          "br"   => "bridge-utils",
-          "tun"  => "tunctl",
-          "tap"  => "tunctl"
-        },
-        "options" => {
-          "STARTMODE"          => { "ifplugd" => "ifplugd" },
-          "WIRELESS_AUTH_MODE" => {
-            "psk" => "wpa_supplicant",
-            "eap" => "wpa_supplicant"
-          }
+      # various device types require some special packages ...
+      type_requires =  {
+        # for wlan require iw instead of wireless-tools (bnc#539669)
+        "wlan" => "iw",
+        "vlan" => "vlan",
+        "br"   => "bridge-utils",
+        "tun"  => "tunctl",
+        "tap"  => "tunctl"
+      }
+      # ... and some options require special packages as well
+      option_requires =  {
+        "WIRELESS_AUTH_MODE" => {
+          "psk" => "wpa_supplicant",
+          "eap" => "wpa_supplicant"
         }
       }
 
-      Builtins.foreach(
-        Convert.convert(
-          Map.Keys(Ops.get_map(required, "types", {})),
-          :from => "list",
-          :to   => "list <string>"
-        )
-      ) do |type|
-        package = Ops.get_string(required, ["types", type], "")
-        if Ops.greater_than(Builtins.size(NetworkInterfaces.List(type)), 0)
+      pkgs = []
+      type_requires.each do |type, package|
+        ifaces = NetworkInterfaces.List(type)
+        if !ifaces.empty?
           Builtins.y2milestone(
-            "Network interface type %1 requires package %2",
-            type,
-            package
+            "Network interface type #{type} requires package #{package}"
           )
-          if !PackageSystem.Installed(package)
-            pkgs = Builtins.add(pkgs, package)
-          end
+          pkgs << package if !PackageSystem.Installed(package)
         end
       end
 
-
-      Builtins.foreach(
-        Convert.convert(
-          Map.Keys(Ops.get_map(required, "options", {})),
-          :from => "list",
-          :to   => "list <string>"
-        )
-      ) do |type|
-        Builtins.foreach(
-          Convert.convert(
-            Map.Keys(Ops.get_map(required, ["options", type], {})),
-            :from => "list",
-            :to   => "list <string>"
-          )
-        ) do |option|
-          package = Ops.get_string(required, ["options", type, option], "")
-          if NetworkInterfaces.Locate(type, option) != []
+      option_requires.each do |option, option_values|
+        option_values.each do |value, package|
+          if NetworkInterfaces.Locate(option, value) != []
             Builtins.y2milestone(
-              "Network interface with options %1, %2 requires package %3",
-              type,
-              option,
-              package
+              "Network interface with option #{option}=#{value} requires package #{package}",
             )
-            if !PackageSystem.Installed(package)
-              pkgs = Builtins.add(pkgs, package)
-            end
+            pkgs << package if !PackageSystem.Installed(package)
           end
         end
       end
 
-      if NetworkService.IsManaged
-        if !PackageSystem.Installed("NetworkManager")
-          pkgs = Builtins.add(pkgs, "NetworkManager")
-        end
+      if NetworkService.is_network_manager
+        pkgs << "NetworkManager" if !PackageSystem.Installed("NetworkManager")
       end
-      deep_copy(pkgs)
+
+      pkgs
     end
 
     # @return [Array] of packages needed when writing the config in autoinst
@@ -1565,8 +1126,6 @@ module Yast
       have_br
     end
 
-    publish :variable => :virt_net_proposal, :type => "boolean"
-    publish :variable => :automatic_configuration, :type => "boolean"
     publish :variable => :ipv6, :type => "boolean"
     publish :variable => :AbortFunction, :type => "block <boolean>"
     publish :variable => :bond_autoconf_slaves, :type => "list <string>"
@@ -1583,17 +1142,29 @@ module Yast
     publish :function => :Summary, :type => "list (string)"
     publish :function => :SummaryGeneral, :type => "list ()"
     publish :function => :Add, :type => "boolean ()"
-    publish :function => :Edit, :type => "boolean (string)"
     publish :function => :Delete, :type => "boolean ()"
-    publish :function => :ProposeInterfaces, :type => "boolean ()"
-    publish :function => :ProposeRoutesAndResolver, :type => "boolean ()"
-    publish :function => :Propose, :type => "boolean ()"
-    publish :function => :Autoinstall, :type => "boolean ()"
     publish :function => :AnyDHCPDevice, :type => "boolean ()"
-    publish :function => :PrepareForAutoinst, :type => "list <map> ()"
     publish :function => :Packages, :type => "list <string> ()"
     publish :function => :AutoPackages, :type => "map ()"
     publish :function => :HaveXenBridge, :type => "boolean ()"
+
+  private
+    def activate_network_service
+      if LanItems.force_restart
+        log.info("Network service activation forced")
+        NetworkService.Restart
+      else
+        log.info(
+          ("Attempting to reload network service, normal stage %s, ssh: %s") %
+          [Stage.normal, Linuxrc.usessh]
+        )
+        # If the second installation stage has been called by yast.ssh via
+        # ssh, we should not restart network cause systemctl
+        # hangs in that case. (bnc#885640)
+        NetworkService.ReloadOrRestart if Stage.normal || !Linuxrc.usessh
+      end
+    end
+
   end
 
   Lan = LanClass.new
