@@ -11,6 +11,21 @@ require "yast"
 
 module Yast
   class PackageSlideShowClass < Module
+    include Yast::Logger
+
+    # seconds to cut off predicted time
+    MAX_TIME_PER_CD = 7200
+
+    # minimum time displayed per CD if there is something to install
+    MIN_TIME_PER_CD = 5
+
+    # Column index for refreshing statistics: remaining size
+    SIZE_COLUMN_POSITION = 1
+    # Column index for refreshing statistics: remaining number of packages
+    PKG_COUNT_COLUMN_POSITION = 2
+    # Column index for refreshing statistics: remaining time
+    TIME_COLUMN_POSITION = 3
+
     def main
       Yast.import "UI"
       Yast.import "Pkg"
@@ -38,11 +53,7 @@ module Yast
       @total_count_to_download = 0
       @total_count_downloaded = 0
       @downloading_pct = 0
-      @min_time_per_cd = 10 # const - minimum time displayed per CD if there is something to install
-      @max_time_per_cd = 7200 # const - seconds to cut off predicted time (it's bogus anyway)
-      @size_column = 1 # const - column number for remaining size per CD
-      @pkg_count_column = 2 # const - column number for remaining number of packages per CD
-      @time_column = 3 # const - column number for remaining time per CD
+
       @current_src_no = -1 # 1..n
       @current_cd_no = -1 # 1..n
       @next_src_no = -1
@@ -115,50 +126,6 @@ module Yast
     #**************  Formatting functions and helpers **************************
     #***************************************************************************
 
-    # Get version info for a package (without build no.)
-    #
-    # @param [String] pkg_name name of the package without path and ".rpm" extension
-    # @return version string
-    #
-    def StripReleaseNo(pkg_name)
-      build_no_pos = Builtins.findlastof(pkg_name, "-") # find trailing build no.
-
-      if build_no_pos != nil && Ops.greater_than(build_no_pos, 0)
-        # cut off trailing build no.
-        pkg_name = Builtins.substring(pkg_name, 0, build_no_pos)
-      end
-
-      pkg_name
-    end
-
-    # Get package file name from path
-    #
-    # @param [String] pkg_name location of the package
-    # @return [String] package file name
-    #
-    def StripPath(pkg_name)
-      return nil if pkg_name == nil
-
-      file_pos = Builtins.findlastof(pkg_name, "/")
-
-      if file_pos != nil && Ops.greater_than(file_pos, 0)
-        # return just the file name
-        pkg_name = Builtins.substring(pkg_name, Ops.add(file_pos, 1))
-      end
-
-      pkg_name
-    end
-
-
-    # set media type "CD" or "DVD"
-    def SetMediaType(new_media_type)
-      Builtins.y2warning(
-        "PackageSlideShow::SetMediaType() is obsoled, do not use!"
-      )
-
-      nil
-    end
-
     # Sum up all list items
     #
     def ListSum(sizes)
@@ -206,7 +173,7 @@ module Yast
     def TotalRemainingTime
       ListSumCutOff(
         Builtins.flatten(@remaining_times_per_cd_per_src),
-        @max_time_per_cd
+        MAX_TIME_PER_CD
       )
     end
 
@@ -400,6 +367,9 @@ module Yast
           seconds = Ops.divide(remaining, @bytes_per_second)
         end
 
+        seconds = MIN_TIME_PER_CD if seconds < MIN_TIME_PER_CD
+        log.debug "Updating remaining time for source #{@current_src_no} " \
+          "(medium #{@current_cd_no}): #{seconds}"
         Ops.set(
           @remaining_times_per_cd_per_src,
           [Ops.subtract(@current_src_no, 1), Ops.subtract(@current_cd_no, 1)],
@@ -447,7 +417,7 @@ module Yast
             total = 0
             Builtins.foreach(media_mapping) do |count|
               total = Ops.add(total, count)
-            end 
+            end
 
 
             Builtins.y2milestone(
@@ -459,7 +429,7 @@ module Yast
           end
         end
         i = Ops.add(i, 1)
-      end 
+      end
 
 
       Builtins.y2milestone("Total number of packages to download: %1", ret)
@@ -556,7 +526,7 @@ module Yast
       Builtins.y2milestone(
         "PackageSlideShow::InitPkgData(): pkg: %1",
         @total_pkg_count_per_cd_per_src
-      ) 
+      )
 
       # RebuildDialog(true);
 
@@ -656,22 +626,15 @@ module Yast
     # @return true if recalculated, false if not
     #
     def RecalcRemainingTimes(force_recalc)
-      if !force_recalc &&
-          Ops.less_than(Builtins.time, SlideShow.next_recalc_time)
+      if !force_recalc && ::Time.now.to_i < SlideShow.next_recalc_time
         # Nothing to do (yet) - simply return
         return false
       end
 
-
-      # Actually do recalculation
-
       elapsed = SlideShow.total_time_elapsed
 
-      if Ops.greater_or_equal(SlideShow.start_time, 0)
-        elapsed = Ops.subtract(
-          Ops.add(elapsed, Builtins.time),
-          SlideShow.start_time
-        )
+      if SlideShow.start_time >= 0
+        elapsed += ::Time.now.to_i - SlideShow.start_time
       end
 
       if elapsed == 0
@@ -684,7 +647,7 @@ module Yast
 
       # This is the real thing.
 
-      real_bytes_per_second = Ops.divide(@total_size_installed, elapsed)
+      real_bytes_per_second = @total_size_installed.to_f / elapsed
 
       # But this turns out to be way to optimistic - RPM gets slower and
       # slower while installing. So let's add some safety margin to make
@@ -700,26 +663,11 @@ module Yast
 
       pessimistic_factor = 1.0
 
-      if Ops.greater_than(@total_size_to_install, 0)
-        pessimistic_factor = Ops.subtract(
-          1.7,
-          Ops.divide(
-            Builtins.tofloat(@total_size_installed),
-            Builtins.tofloat(@total_size_to_install)
-          )
-        )
+      if @total_size_to_install > 0
+        pessimistic_factor = 1.7 - @total_size_installed.to_f / @total_size_to_install
       end
-      @bytes_per_second = Builtins.tointeger(
-        Ops.add(
-          Ops.divide(
-            Builtins.tofloat(real_bytes_per_second),
-            pessimistic_factor
-          ),
-          0.5
-        )
-      )
 
-      @bytes_per_second = 1 if Ops.less_than(@bytes_per_second, 1)
+      @bytes_per_second = (real_bytes_per_second / pessimistic_factor + 1).floor
 
       @remaining_times_per_cd_per_src = []
 
@@ -728,105 +676,39 @@ module Yast
       Builtins.foreach(@remaining_sizes_per_cd_per_src) do |remaining_sizes_list|
         remaining_times_list = []
         remaining_time = -1
-        Builtins.foreach(remaining_sizes_list) do |remaining_size|
-          remaining_time = remaining_size
-          if Ops.greater_than(remaining_size, 0)
-            remaining_time = Ops.divide(remaining_size, @bytes_per_second)
 
-            if Ops.less_than(remaining_time, @min_time_per_cd)
+        remaining_sizes_list.each do |remaining_size|
+          remaining_time = remaining_size
+
+          if remaining_size > 0
+            remaining_time = remaining_size.to_f / @bytes_per_second
+
+            if remaining_time < MIN_TIME_PER_CD
               # It takes at least this long for the CD drive to spin up and
               # for RPM to do _anything_. Times below this values are
               # ridiculously unrealistic.
-              remaining_time = @min_time_per_cd
-            elsif Ops.greater_than(remaining_time, @max_time_per_cd) # clip off at 2 hours
+              remaining_time = MIN_TIME_PER_CD
+            elsif remaining_time > MAX_TIME_PER_CD # clip off at 2 hours
               # When data throughput goes downhill (stalled network connection etc.),
               # cut off the predicted time at a reasonable maximum.
-              remaining_time = @max_time_per_cd
+              remaining_time = MAX_TIME_PER_CD
             end
           end
-          remaining_times_list = Builtins.add(
-            remaining_times_list,
-            remaining_time
-          )
-        end
-        @remaining_times_per_cd_per_src = Builtins.add(
-          @remaining_times_per_cd_per_src,
-          remaining_times_list
-        )
-      end
 
-
-      # Recalculate slide interval
-
-      if Slides.HaveSlides
-        slides_remaining = Ops.subtract(
-          Ops.subtract(Builtins.size(Slides.slides), SlideShow.current_slide_no),
-          1
-        )
-
-        if Ops.greater_than(slides_remaining, 0)
-          # The remaining time for the rest of the slides depends on the
-          # remaining time for the current CD only: This is where the
-          # slide images and texts reside. Normally, only CD1 has slides
-          # at all, i.e. the slide show must be finished when CD1 is
-          # done.
-          #
-          # In addition to that, take elapsed time for current slide
-          # into account so all slides get about the same time.
-
-          time_remaining = Ops.subtract(
-            Ops.add(
-              Ops.get(
-                @remaining_times_per_cd_per_src,
-                [
-                  Ops.subtract(@current_src_no, 1),
-                  Ops.subtract(@current_cd_no, 1)
-                ],
-                1
-              ),
-              Builtins.time
-            ),
-            SlideShow.slide_start_time
-          )
-          SlideShow.slide_interval = Ops.divide(
-            time_remaining,
-            slides_remaining
-          )
-          Builtins.y2debug(
-            "New slide interval: %1 - slides remaining: %2 - remaining time: %3",
-            SlideShow.slide_interval,
-            slides_remaining,
-            time_remaining
-          )
-
-          if Ops.less_than(
-              SlideShow.slide_interval,
-              SlideShow.slide_min_interval
-            )
-            SlideShow.slide_interval = SlideShow.slide_min_interval
-            Builtins.y2debug(
-              "Resetting slide interval to min slide interval: %1",
-              SlideShow.slide_interval
-            )
+          if remaining_time.is_a?(Float)
+            log.warn "Float time appeared: #{remaining_time}"
+            remaining_time = remaining_time.round
+            log.warn "Converted to integer: #{remaining_time}"
           end
 
-          if Ops.greater_than(
-              SlideShow.slide_interval,
-              SlideShow.slide_max_interval
-            )
-            SlideShow.slide_interval = SlideShow.slide_max_interval
-            Builtins.y2debug(
-              "Resetting slide interval to max slide interval: %1",
-              SlideShow.slide_interval
-            )
-          end
+          remaining_times_list << remaining_time
         end
+
+        @remaining_times_per_cd_per_src << remaining_times_list
+        log.debug "Recalculated remaining time: #{@remaining_times_per_cd_per_src}"
       end
 
-      SlideShow.next_recalc_time = Ops.add(
-        Builtins.time,
-        SlideShow.recalc_interval
-      )
+      SlideShow.next_recalc_time = ::Time.now.to_i + SlideShow.recalc_interval
 
       true
     end
@@ -837,7 +719,7 @@ module Yast
     def SwitchToSecondsIfNecessary
       if @unit_is_seconds ||
           Ops.less_than(
-            Builtins.time,
+            ::Time.now.to_i,
             Ops.add(SlideShow.start_time, SlideShow.initial_recalc_delay)
           )
         return false # no need to switch
@@ -883,7 +765,7 @@ module Yast
             Ops.subtract(@current_src_no, 1),
             Ops.subtract(@current_cd_no, 1)
           ),
-          @size_column
+          SIZE_COLUMN_POSITION
         ),
         FormatRemainingSize(remaining)
       )
@@ -897,7 +779,7 @@ module Yast
             Ops.subtract(@current_src_no, 1),
             Ops.subtract(@current_cd_no, 1)
           ),
-          @pkg_count_column
+          PKG_COUNT_COLUMN_POSITION
         ),
         FormatRemainingCount(
           Ops.get(
@@ -915,10 +797,10 @@ module Yast
 
         remaining = 0 if Ops.less_or_equal(remaining, 0)
 
-        if Ops.greater_than(remaining, @max_time_per_cd) # clip off at 2 hours
+        if Ops.greater_than(remaining, MAX_TIME_PER_CD) # clip off at 2 hours
           # When data throughput goes downhill (stalled network connection etc.),
           # cut off the predicted time at a reasonable maximum.
-          remaining = Ops.unary_minus(@max_time_per_cd)
+          remaining = Ops.unary_minus(MAX_TIME_PER_CD)
         end
 
         UI.ChangeWidget(
@@ -930,7 +812,7 @@ module Yast
               Ops.subtract(@current_src_no, 1),
               Ops.subtract(@current_cd_no, 1)
             ),
-            @time_column
+            TIME_COLUMN_POSITION
           ),
           FormatTimeShowOverflow(remaining)
         )
@@ -943,20 +825,20 @@ module Yast
 
       UI.ChangeWidget(
         Id(:cdStatisticsTable),
-        term(:Item, "total", @size_column),
+        term(:Item, "total", SIZE_COLUMN_POSITION),
         FormatRemainingSize(TotalRemainingSize())
       )
 
       UI.ChangeWidget(
         Id(:cdStatisticsTable),
-        term(:Item, "total", @pkg_count_column),
+        term(:Item, "total", PKG_COUNT_COLUMN_POSITION),
         FormatRemainingCount(TotalRemainingPkgCount())
       )
 
       if @unit_is_seconds
         UI.ChangeWidget(
           Id(:cdStatisticsTable),
-          term(:Item, "total", @time_column),
+          term(:Item, "total", TIME_COLUMN_POSITION),
           FormatTimeShowOverflow(TotalRemainingTime())
         )
       end
@@ -1097,14 +979,15 @@ module Yast
 
               if @unit_is_seconds && Ops.greater_than(@bytes_per_second, 0)
                 remaining = Ops.divide(remaining, @bytes_per_second)
+                remaining = MIN_TIME_PER_CD if remaining < MIN_TIME_PER_CD
                 rem_time = String.FormatTime(remaining) # column #2
 
-                if Ops.greater_than(remaining, @max_time_per_cd) # clip off at 2 hours
+                if Ops.greater_than(remaining, MAX_TIME_PER_CD) # clip off at 2 hours
                   # When data throughput goes downhill (stalled network connection etc.),
                   # cut off the predicted time at a reasonable maximum.
                   # "%1" is a predefined maximum time.
                   rem_time = FormatTimeShowOverflow(
-                    Ops.unary_minus(@max_time_per_cd)
+                    Ops.unary_minus(MAX_TIME_PER_CD)
                   )
                 end
               end
@@ -1326,24 +1209,22 @@ module Yast
     end
 
 
-
-
-
-
-
     # package start display update
     # - this is called at the beginning of a new package
     #
     # @param [String] pkg_name		package name
+    # @param [String] pkg_location	full path to a package
     # @param [String] pkg_summary	package summary (short description)
+    # @param [Integer] pkg_size		package size in bytes
     # @param [Boolean] deleting		Flag: deleting (true) or installing (false) package?
     #
     def SlideDisplayStart(pkg_name, pkg_location, pkg_summary, pkg_size, deleting)
       return if !SanityCheck(false)
 
       # remove path
-      pkg_filename = StripPath(pkg_location)
-      Builtins.y2internal("pkg_name: %1", pkg_name)
+      pkg_location ||= ""
+      pkg_filename = File.basename(pkg_location)
+      log.info "pkg_name: #{pkg_name}"
 
       if deleting
         pkg_size = -1
@@ -1358,10 +1239,11 @@ module Yast
         # Note: This will begin to fail when some day packages are deleted in the middle of the
         # installaton process.
 
+        # FIXME: SlideShow.PauseTimer
         SlideShow.ResetTimer
       end
 
-      pkg_summary = "" if pkg_summary == nil
+      pkg_summary ||= ""
 
       msg = ""
 
@@ -1506,9 +1388,6 @@ module Yast
     publish :variable => :bytes_per_second, :type => "integer"
     publish :variable => :init_pkg_data_complete, :type => "boolean"
     publish :function => :GetPackageSummary, :type => "map <string, any> ()"
-    publish :function => :StripReleaseNo, :type => "string (string)"
-    publish :function => :StripPath, :type => "string (string)"
-    publish :function => :SetMediaType, :type => "void (string)"
     publish :function => :InitPkgData, :type => "void (boolean)"
     publish :function => :SetCurrentCdNo, :type => "void (integer, integer)"
     publish :function => :UpdateCurrentCdProgress, :type => "void (boolean)"
