@@ -4,11 +4,25 @@
 # Package:	Package selections
 # Authors:	Anas Nashif <nashif@suse.de>
 #
-# $Id$
 require "yast"
 
+# html_escape()
+require "erb"
+
 module Yast
   class PackagesClass < Module
+    include Yast::Logger
+    include ERB::Util
+
+    # All known types of resolvables
+    RESOLVABLE_TYPES = [:product, :patch, :package, :pattern, :language]
+    # Minimum set of packages required to enable VNC server
+    VNC_BASE_PACKAGES = ["xorg-x11", "xorg-x11-Xvnc", "xorg-x11-fonts", "xinetd"]
+    # Default window manager for VNC if none is installed
+    DEFAULT_WM = "icewm"
+    # Minimum set of packages required for installation with remote X11 server
+    REMOTE_X11_BASE_PACKAGES = [ "xorg-x11-server", "xorg-x11-fonts", "icewm" ]
+
     def main
       Yast.import "UI"
       Yast.import "Pkg"
@@ -43,6 +57,7 @@ module Yast
       Yast.import "Installation"
       Yast.import "URL"
       Yast.import "PackagesProposal"
+      Yast.import "HTML"
 
       Yast.include self, "packager/load_release_notes.rb"
 
@@ -184,7 +199,7 @@ module Yast
 
       Builtins.foreach(media_sizes) { |inst_sizes| Builtins.foreach(inst_sizes) do |inst_size|
         sz = Ops.add(sz, inst_size)
-      end } 
+      end }
 
 
       Builtins.y2milestone(
@@ -233,7 +248,7 @@ module Yast
           Builtins.y2milestone("Found remote repository %1: %2", repo, url)
           remote_repos = Builtins.add(remote_repos, repo)
         end
-      end 
+      end
 
 
       # shortcut, no remote repository found
@@ -256,7 +271,7 @@ module Yast
         Builtins.foreach(repo_media_sizes) do |media_size|
           ret = Ops.add(ret, media_size)
         end
-      end 
+      end
 
 
       Builtins.y2milestone(
@@ -566,7 +581,7 @@ module Yast
             Ops.set(summary, "warning_level", :warning)
           end
         end
-      end 
+      end
 
 
       Builtins.y2milestone("Proposal summary: %1", summary)
@@ -621,7 +636,7 @@ module Yast
               partition
             )
             warning = Ops.add(warning, w)
-          end 
+          end
 
 
           if warning != ""
@@ -646,10 +661,122 @@ module Yast
       deep_copy(ret)
     end
 
+    # group products according to the current state
+    # @param [Array<Hash>] products list of products (returned by Pkg.ResolvableProperties call)
+    # @return [Hash<Symbol,Object>] grouped products
+    #   the keys are :new, :removed, :kept, :updated
+    #   For each key the value is a list of products, except for :updated
+    #   key which contains a Hash with old_product => new_product mapping
+    def group_products_by_status(products)
+      to_install = products_to_install(products)
+      to_remove = products_to_remove(products)
+      to_update = products_to_update(to_install, to_remove)
 
+      # remove the updated products from selected and removed lists
+      to_remove -= to_update.keys
+      to_install -= to_update.values
 
+      ret = {
+        :new => to_install,
+        :removed => to_remove,
+        :kept => kept_products(products),
+        :updated => to_update
+      }
 
+      log.info "Product update status: #{ret}"
 
+      ret
+    end
+
+    # create a product update summary (in rich text format)
+    # usable in update proposal
+    # @see #product_update_warning how to set and display possible issues
+    # @param [Array<Hash>] products list of products (returned by Pkg.ResolvableProperties call)
+    # @return [Array<String>] list of rich text descriptions
+    def product_update_summary(products)
+      status = group_products_by_status(products)
+
+      # newly installed products
+      ret = status[:new].map do |product|
+        log.info "New product will be installed: #{product}"
+        _("New product <b>%s</b> will be installed") % h(product_label(product))
+      end
+
+      ret += status[:updated].map do |removed, installed|
+        old_product = product_label(removed)
+        new_product = product_label(installed)
+        log.info "Detected product update: #{old_product} -> #{new_product}"
+
+        (old_product == new_product) ?
+          # product update: %s is a product name
+        _("Product <b>%s</b> will be updated") % h(old_product) :
+          # product update: %{old_product} is an old product, %{new_product} is the new one
+        _("Product <b>%{old_product}</b> will be updated to <b>%{new_product}</b>") % {
+          :old_product => h(old_product), :new_product => h(new_product)
+        }
+      end
+
+      ret += status[:kept].map do |product|
+        log.info "Unchanged product: #{product}"
+        _("Product <b>%s</b> will stay installed") % h(product_label(product))
+      end
+
+      ret += status[:removed].map do |product|
+        transact_by = product["transact_by"]
+        log.warn "Product will be removed (by #{transact_by}): #{product}"
+
+        # Removing another product might be an issue
+        # (just warn if removed by user or by YaST)
+        msg = (transact_by == :user || transact_by == :app_high) ?
+          _("<b>Warning:</b> Product <b>%s</b> will be removed.") % h(product_label(product)) :
+          _("<b>Error:</b> Product <b>%s</b> will be automatically removed.</font>") \
+            % h(product_label(product))
+
+        HTML.Colorize(msg, "red")
+      end
+
+      log.info "Product update summary: #{ret}"
+      ret
+    end
+
+    # create a warning for product update summary (in rich text format) if
+    # there is an update problem
+    # @see #product_update_summary how to get the summary text
+    # @param [Array<Hash>] products list of products (returned by Pkg.ResolvableProperties call)
+    # @return [Hash] hash with warning attributes or empty if there is no problem
+    def product_update_warning(products)
+      status = group_products_by_status(products)
+
+      return {} if status[:removed].all? { |product| product["transact_by"] != :solver }
+
+      # Automatic product removal MUST be confirmed by user, otherwise update
+      # cannot be started.
+      return {
+        "warning_level" => :blocker,
+        # TRANSLATORS: update proposal warning, do NOT translate "-release",
+        # it is part of a package name (like "sles-release")
+        "warning" => _(
+          "<ul><li><b>Some products are marked for automatic removal.</b></li>\n" \
+            "<ul><li>Contact the vendor of the removed add-on to provide you with a new\n" \
+            "installation media</li><li>Or select the appropriate online extension or module\n" \
+            "in the registration step</li><li>Or to continue with product upgrade go to the\n" \
+            "software selection and mark the product (the -release package) for removal.\n" \
+            "</li></ul></li></ul>")
+      }
+    end
+
+    # return a printable name of product resolvable
+    # @param [Hash] product the product (returned by Pkg.ResolvableProperties call)
+    # @return [String] product name
+    def product_label(product)
+      display_name = product["display_name"]
+      return display_name if display_name && !display_name.empty?
+
+      short_name = product["short_name"]
+      return short_name if short_name && !short_name.empty?
+
+      product["name"]
+    end
 
     # proposal control functions
 
@@ -801,7 +928,6 @@ module Yast
           "xorg-x11-server",
           "xorg-x11-server-glx",
           "libusb",
-          "sax2-tools",
           "yast2-x11"
         ]
       end
@@ -817,17 +943,9 @@ module Yast
     def modePackages
       packages = []
 
-      if Linuxrc.vnc
-        packages.concat [ "tightvnc", "yast2-qt", "xorg-x11-Xvnc",
-          "xorg-x11-fonts", "icewm", "sax2-tools", "yast2-x11", "xinetd" ]
-      end
-
+      packages.concat(vnc_packages) if Linuxrc.vnc
       #this means we have a remote X server
-      if Linuxrc.display_ip
-        packages.concat [ "yast2-qt", "xorg-x11-server", "xorg-x11-fonts",
-          "icewm", "sax2-tools", "yast2-x11" ]
-      end
-
+      packages.concat(remote_x11_packages) if Linuxrc.display_ip
       packages << "sbl" if Linuxrc.braille
       packages << "openssh" if Linuxrc.usessh
 
@@ -851,24 +969,25 @@ module Yast
       ret = []
 
       add_biosdevname = false
-      cmdline = Convert.to_string(
-        SCR.Read(path(".target.string"), "/proc/cmdline")
-      )
+      options = SCR.Read(path(".proc.cmdline"))
+      option = options.grep(/^biosdevname=/i).first
+      if option
+        value = option[/^biosdevname=(\d+)/i, 1]
+      else #missing biosdevname option
+        value = nil
+      end
 
-      options = Builtins.splitstring(cmdline, " \t")
-
-      if Builtins.contains(options, "biosdevname=1")
+      if value == "1"
         Builtins.y2milestone("Biosdevname explicitly enabled")
         add_biosdevname = true
-      elsif Builtins.contains(options, "biosdevname=0")
+      elsif value == "0"
         Builtins.y2milestone("Biosdevname explicitly disabled")
         add_biosdevname = false
       else
         Builtins.y2milestone("Missing biosdevname option, autodetecting...")
         add_biosdevname = true if DellSystem()
       end
-
-      ret = Builtins.add(ret, "biosdevname") if add_biosdevname
+      ret << "biosdevname" if add_biosdevname
 
       Builtins.y2milestone("Packages added by kernel command line: %1", ret)
 
@@ -978,6 +1097,15 @@ module Yast
         end
       end
 
+      # select FIPS pattern
+      if (Linuxrc.InstallInf("Cmdline") || "").split.include?("fips=1")
+        fips_pattern = "fips"
+        if !Pkg.ResolvableProperties(fips_pattern, :pattern, "").empty?
+          log.info "fips=1 boot option detected, adding '#{fips_pattern}' pattern"
+          pattern_list << fips_pattern
+        end
+      end
+
       # FATE #302116
       # BNC #431580
       required_patterns = PackagesProposal.GetAllResolvables(:pattern)
@@ -1372,7 +1500,7 @@ module Yast
       # bnc #432668
       # Do not call init
       if Mode.live_installation
-        Builtins.y2milestone("live_installation, not calling Init") 
+        Builtins.y2milestone("live_installation, not calling Init")
         # bnc #427935
         # Initialize the base_source_id first
       else
@@ -1546,7 +1674,7 @@ module Yast
           AddOnProduct.UpdateInstSys(Ops.add(spdir, "/y2update.tgz"))
         end
         @theSources = Builtins.add(@theSources, sp_source)
-        Builtins.y2internal(
+        Builtins.y2milestone(
           "Service pack repository: %1, changing to URL: %2",
           sp_source,
           base_url
@@ -1674,7 +1802,7 @@ module Yast
           sources_set = Builtins.add(sources_set, one_source)
         end
 
-        return Pkg.SourceEditSet(sources_set) 
+        return Pkg.SourceEditSet(sources_set)
         # Bad luck, nothing useful found
       else
         Builtins.y2warning("No name found")
@@ -1769,6 +1897,12 @@ module Yast
     def Initialize_StageInitial(show_popup, base_url, log_url)
       initial_repository = nil
       ImportGPGKeys()
+
+      # prefer CD/DVD media to download during installation/update
+      # (BNC#780617,865819)
+      Builtins.y2milestone("Prefer CD/DVD media to download")
+      Pkg.SetZConfig({ "download_media_prefer_download" => false })
+
       while initial_repository == nil
         initial_repository = Pkg.SourceCreateBase(base_url, "")
         if initial_repository == -1 || initial_repository == nil
@@ -1980,43 +2114,38 @@ module Yast
       ret
     end
 
-    # Select system patterns
-    # @param [Boolean] reselect boolean true to select only those which are alrady selected
+    # Selects system-specific and default patterns for installation
+    #
+    # @param [Boolean] reselect whether to re-select all already selected patterns
     def SelectSystemPatterns(reselect)
-      system_patterns = ComputeSystemPatternList()
+      patterns = patterns_to_install.dup
+      log.info "Selecting system patterns #{patterns}"
 
-      # autoinstallation has patterns specified in the profile
-      if !Mode.autoinst
-        system_patterns = Convert.convert(
-          Builtins.toset(Builtins.merge(system_patterns, Product.patterns)),
-          :from => "list",
-          :to   => "list <string>"
-        )
-      end
       if !reselect
-        Builtins.y2milestone("Selecting system patterns %1", system_patterns)
-        Builtins.foreach(system_patterns) do |p|
-          prop = Ops.get(Pkg.ResolvableProperties(p, :pattern, ""), 0, {})
-          if Ops.get(prop, "status") == :available &&
-              Ops.get(prop, "transact_by") == :user
-            Builtins.y2milestone("Ignoring deselected pattern '%1'", p)
+        patterns.each do |pattern_name|
+          prop = Pkg.ResolvableProperties(pattern_name, :pattern, "").first
+
+          if prop.nil?
+            report_missing_pattern(pattern_name)
+            next
+          elsif prop["status"] == :available && prop["transact_by"] == :user
+            log.info "Skipping pattern #{pattern_name} deselected by user"
           else
-            Pkg.ResolvableInstall(p, :pattern)
+            Pkg.ResolvableInstall(pattern_name, :pattern)
           end
         end
       else
-        Builtins.y2milestone("Re-selecting system patterns %1", system_patterns)
-        pats = Builtins.filter(system_patterns) do |p|
-          descrs = Pkg.ResolvableProperties(p, :pattern, "")
-          descrs = Builtins.filter(descrs) do |descr|
-            Ops.get(descr, "status") == :selected
-          end
-          Ops.greater_than(Builtins.size(descrs), 0)
+        patterns.select! do |pattern_name|
+          descrs = Pkg.ResolvableProperties(pattern_name, :pattern, "")
+          report_missing_pattern(pattern_name) if descrs.empty?
+          descrs.any?{ |descr| descr["status"] == :selected }
         end
-        Builtins.y2milestone("Selected patterns to be reselected: %1", pats)
-        Builtins.foreach(pats) do |p|
-          Pkg.ResolvableRemove(p, :pattern)
-          Pkg.ResolvableInstall(p, :pattern)
+
+        log.info "Selected patterns to be reselected: #{patterns}"
+
+        patterns.each do |pattern_name|
+          Pkg.ResolvableRemove(pattern_name, :pattern)
+          Pkg.ResolvableInstall(pattern_name, :pattern)
         end
       end
 
@@ -2371,6 +2500,125 @@ module Yast
       nil
     end
 
+    # Reads software->default_patterns and returns lisf of patterns that should
+    # be selected for installation by default
+    #
+    # @return [Array] list of patterns
+    def default_patterns
+      product_feature_items("software", "default_patterns")
+    end
+
+    # Reads software->optional_default_patterns and returns lisf of patterns that should
+    # be selected for installation by default (if they exist)
+    #
+    # @return [Array] list of patterns
+    def optional_default_patterns
+      product_feature_items("software", "optional_default_patterns")
+    end
+
+    # Log only resolvables with resolvable["status"] matching these below
+    LOG_RESOLVABLE_STATUS = [:selected, :removed]
+
+    # Log only resolvables with resolvable["transact_by"] matching these below
+    LOG_RESOLVABLE_TRANSACT_BY = [:user, :app_high]
+
+    # Reads the current user selection and dumps it to log
+    def log_software_selection
+      log.info "-" * 10 << " Transaction Status Begin " << "-" * 10
+
+      RESOLVABLE_TYPES.each do |type|
+        resolvables = Pkg.ResolvableProperties("", type, "")
+        resolvables.select!{ |r| LOG_RESOLVABLE_TRANSACT_BY.include? r["transact_by"] }
+
+        LOG_RESOLVABLE_TRANSACT_BY.each do |transact_by|
+          changed_resolvables = resolvables.select{ |r| r["transact_by"] == transact_by}
+          next if changed_resolvables.empty?
+
+          decided_resolvables = changed_resolvables.select{ |r| LOG_RESOLVABLE_STATUS.include? r["status"] }
+          log_resolvables("Resolvables of type #{type} set by #{transact_by}:", decided_resolvables)
+
+          locked_resolvables = changed_resolvables.select{ |r| r["locked"] }
+          log_resolvables("Locked resolvables of type #{type} set by #{transact_by}:", locked_resolvables)
+        end
+      end
+
+      log.info "-" * 10 << " Transaction Status End " << "-" * 10
+      nil
+    end
+
+    # List of packages expected to be installed in order to enable
+    # remote administration (VNC)
+    #
+    # @return Array<String>
+    def vnc_packages
+      packages = VNC_BASE_PACKAGES.dup
+      # At least one windowmanager must be installed (#427044)
+      # If none is there, use a fallback
+      packages << DEFAULT_WM unless has_window_manager?
+      packages << "yast2-x11" if Mode.autoinst
+      packages
+    end
+
+    # List of packages expected to be installed in order to use
+    # a remote X11 server
+    #
+    # @return Array<String>
+    def remote_x11_packages
+      packages = REMOTE_X11_BASE_PACKAGES.dup
+      packages << "yast2-x11" if Mode.autoinst
+      packages
+    end
+
+  private
+
+    # Reads product feature defined by parameters, logs what it gets
+    # and returns list of items split by whitespaces
+    #
+    # @param [String] section in control file
+    # @param [String] feature in section
+    # @return [Array] of items
+    def product_feature_items(section, feature)
+      feature_items = ProductFeatures.GetStringFeature(section, feature)
+      log.info "Product feature #{section}->#{feature} items: #{feature_items.inspect}"
+      feature_items.strip.split
+    end
+
+    def log_resolvables(text, resolvables)
+      return if resolvables.empty?
+
+      log.info text
+
+      resolvables.each do |r|
+        r_info = {:name => r["name"], :version => r["version"], :arch => r["arch"], :status => r["status"]}
+        log.info "- #{r_info}"
+      end
+    end
+
+    # Computes all patterns that are expected to be selected for default installation
+    def patterns_to_install
+      patterns = ComputeSystemPatternList().dup
+
+      # autoinstallation has patterns specified in the profile
+      if !Mode.autoinst
+        (default_patterns | optional_default_patterns).inject(patterns, :<<)
+      end
+
+      patterns
+    end
+
+    def report_missing_pattern(pattern_name)
+      if optional_default_patterns.include?(pattern_name)
+        log.info "Optional pattern #{pattern_name} does not exist, skipping..."
+      else
+        log.error "Pattern #{pattern_name} does not exist"
+        # Error message, %{pattern_name} is replaced with the missing pattern name in runtime
+        Report.Error(_(
+          "Failed to select default product pattern %{pattern_name}.\n" +
+          "Pattern has not been found."
+        ) % {:pattern_name => pattern_name})
+      end
+    end
+
     publish :variable => :install_sources, :type => "boolean"
     publish :variable => :timestamp, :type => "integer"
     publish :variable => :metadir, :type => "string"
@@ -2410,6 +2658,54 @@ module Yast
     publish :function => :InitializeCatalogs, :type => "void ()"
     publish :function => :InitFailed, :type => "boolean ()"
     publish :function => :SelectKernelPackages, :type => "void ()"
+    publish :function => :default_patterns, :type => "list <string> ()"
+    publish :function => :log_software_selection, :type => "void ()"
+    publish :function => :vnc_packages, :type => "list <string> ()"
+    publish :function => :remote_x11_packages, :type => "list <string> ()"
+
+    private
+
+    # list of all products that will be installed (are selected)
+    def products_to_install(products)
+      products.select { |product| product["status"] == :selected }
+    end
+
+    # list of all products that will be removed
+    def products_to_remove(products)
+      products.select { |product| product["status"] == :removed }
+    end
+
+    def products_to_update(installed_products, removed_products)
+      # process the selected and removed products and find product updates
+      # map content: old_product => new_product
+      updated_products = {}
+      installed_products.each do |installed_product|
+        removed = removed_products.find do |removed_product|
+          installed_name = installed_product["name"]
+          removed_name = removed_product["name"]
+
+          # check the current product names or product renames
+          removed_name == installed_name ||
+            AddOnProduct.renamed?(removed_name, installed_name)
+        end
+
+        updated_products[removed] = installed_product if removed
+      end
+
+      updated_products
+    end
+
+    # list of all products that will be unchanged (kept installed)
+    def kept_products(products)
+      products.select { |product| product["status"] == :installed }
+    end
+
+    # Checks if a window manager is installed or selected for installation
+    #
+    # @return [Boolean] true if there is a window manager
+    def has_window_manager?
+      Pkg.IsSelected("windowmanager") || Pkg.IsProvided("windowmanager")
+    end
   end
 
   Packages = PackagesClass.new
