@@ -10,9 +10,16 @@
 #		Lukas Ocilka <locilka@suse.cz>
 #
 require "yast"
+require "uri"
 
 module Yast
   class ProductLicenseClass < Module
+    attr_accessor :license_patterns, :license_file_print
+
+    include Yast::Logger
+
+    DOWNLOAD_URL_SCHEMA = ["http", "https", "ftp"]
+
     def main
       Yast.import "Pkg"
       Yast.import "UI"
@@ -35,9 +42,6 @@ module Yast
 
       textdomain "packager"
 
-      # list of already accepted licenses
-      @already_accepted_licenses = []
-
       @license_patterns = [
         "license\\.html",
         "license\\.%1\\.html",
@@ -100,40 +104,6 @@ module Yast
       Ops.get(tmp, 0, "")
     end
 
-    # Creates a unique identification from filename
-    # (MD5sum + file size)
-    #
-    # @param [String] filename
-    # @return [String] unique ID
-    def GetLicenseIdentString(filename)
-      if !FileUtils.Exists(filename)
-        Builtins.y2error("License '%1' doesn't exist", filename)
-        return nil
-      end
-
-      filemd5 = FileUtils.MD5sum(filename)
-      return nil if filemd5 == nil
-
-      ret = Builtins.sformat("%1-%2", filemd5, FileUtils.GetSize(filename))
-
-      Builtins.y2milestone("License ident for '%1' is '%2'", filename, ret)
-
-      ret
-    end
-
-    # Checks whether the license (file) has been already accepted
-    #
-    # @param string filename
-    # @return [Boolean] whether the license has been accepted before
-    def IsLicenseAlreadyAccepted(license_ident)
-      if license_ident == nil || license_ident == ""
-        Builtins.y2error("Wrong license ID '%1'", license_ident)
-        return false
-      end
-
-      Builtins.contains(@already_accepted_licenses, license_ident)
-    end
-
     # Sets that the license (file) has been already accepted
     #
     # @param string filename
@@ -143,15 +113,6 @@ module Yast
         return
       end
 
-      Builtins.y2milestone(
-        "Adding License ID '%1' as already accepted",
-        license_ident
-      )
-      @already_accepted_licenses = Builtins.add(
-        @already_accepted_licenses,
-        license_ident
-      )
-
       nil
     end
 
@@ -272,6 +233,8 @@ module Yast
       lang_pairs = Builtins.maplist(languages) do |l|
         name_print = Ops.get(lang_names, l, "")
         if name_print == ""
+          # TODO FIXME: the language code might be longer than 2 characters,
+          # e.g. "ast_ES"
           l_short = Builtins.substring(l, 0, 2)
 
           Builtins.foreach(lang_names) do |k, v|
@@ -370,35 +333,16 @@ module Yast
     end
 
     def GetLicenseDialog(languages, license_language, licenses, id, spare_space)
-      languages = deep_copy(languages)
-      display = UI.GetDisplayInfo
-      space = Ops.get_boolean(display, "TextMode", true) ? 1 : 3
+      space = UI.TextMode ? 1 : 3
 
       license_buttons = VBox(
-        VSpacing(spare_space ? 0 : 2),
-        RadioButtonGroup(
-          Id(Builtins.sformat("eula_%1", id)),
-          HBox(
-            HSpacing(Ops.multiply(2, space)),
-            VBox(
-              Left(
-                RadioButton(
-                  Id(Builtins.sformat("yes_%1", id)),
-                  Opt(:notify),
-                  # radio button
-                  _("&Yes, I Agree to the License Agreement")
-                )
-              ),
-              Left(
-                RadioButton(
-                  Id(Builtins.sformat("no_%1", id)),
-                  Opt(:notify),
-                  # radio button
-                  _("N&o, I Do not Agree")
-                )
-              )
-            ),
-            HSpacing(Ops.multiply(2, space))
+        VSpacing(spare_space ? 0 : 1),
+        HCenter(
+          CheckBox(
+            Id("eula_#{id}"),
+            Opt(:notify),
+            # check box label
+            _("I &Agree to the License Terms.")
           )
         )
       )
@@ -406,7 +350,7 @@ module Yast
       VBox(
         VSpacing(spare_space ? 0 : 1),
         HBox(
-          HSpacing(Ops.multiply(2, space)),
+          HSpacing(2 * space),
           (
             licenses_ref = arg_ref(licenses.value);
             _GetLicenseDialogTerm_result = GetLicenseDialogTerm(
@@ -418,7 +362,7 @@ module Yast
             licenses.value = licenses_ref.value;
             _GetLicenseDialogTerm_result
           ),
-          HSpacing(Ops.multiply(2, space))
+          HSpacing(2 * space)
         ),
         # BNC #448598
         # yes/no buttons exist only if needed
@@ -426,23 +370,26 @@ module Yast
         AcceptanceNeeded(id) ? license_buttons : Empty(),
         VSpacing(spare_space ? 0.5 : 1),
         HBox(
-          HSpacing(Ops.multiply(2, space)),
+          HSpacing(2 * space),
           @license_file_print != nil ?
             Left(
               # FATE #302018
-              Label(
-                # TRANSLATORS: addition license information
-                # %1 is replaced with the filename
-                Builtins.sformat(
-                  _(
-                    "If you want to print this EULA, you can find it\non the first media in the file %1"
-                  ),
-                  @license_file_print
+              ReplacePoint(
+                Id(:printing_hint),
+                Label(
+                  # TRANSLATORS: addition license information
+                  # %1 is replaced with the filename
+                  Builtins.sformat(
+                    _(
+                      "If you want to print this EULA, you can find it\non the first media in the file %1"
+                    ),
+                    @license_file_print
+                  )
                 )
               )
             ) :
             Empty(),
-          HSpacing(Ops.multiply(2, space))
+          HSpacing(2 * space)
         ),
         VSpacing(spare_space ? 0 : 1)
       )
@@ -457,12 +404,16 @@ module Yast
       )
     end
 
+    # Displays License dialog
+    def DisplayLicenseDialog(languages, back, license_language, licenses, id)
+      # dialog title
+      DisplayLicenseDialogWithTitle(languages, back, license_language, licenses, id, _("License Agreement"))
+    end
+
     # Displays License with Help and ( ) Yes / ( ) No radio buttons
     # @param string file with the license
-    def DisplayLicenseDialog(languages, back, license_language, licenses, id)
+    def DisplayLicenseDialogWithTitle(languages, back, license_language, licenses, id, caption)
       languages = deep_copy(languages)
-      # dialog caption
-      caption = _("License Agreement")
 
       contents = (
         licenses_ref = arg_ref(licenses.value);
@@ -489,6 +440,9 @@ module Yast
         default_next_button_state
       )
 
+      # set the initial license download URL
+      update_license_location(license_language, licenses)
+
       Wizard.SetTitleIcon("yast-license")
       Wizard.SetFocusToNextButton
 
@@ -584,7 +538,7 @@ module Yast
         end
 
         # Success
-        return true 
+        return true
 
         # Nothing to unpack
       else
@@ -796,13 +750,13 @@ module Yast
       # Bugzilla #299732
       # Base Product - LiveCD installation
       if Mode.live_installation
-        SearchForLicense_LiveCDInstallation(src_id, fallback_dir) 
+        SearchForLicense_LiveCDInstallation(src_id, fallback_dir)
 
         # Base-product - license not in installation
         #   * Stage is not initial
         #   * source ID is not defined
       elsif !Stage.initial && src_id == nil
-        SearchForLicense_NormalRunBaseProduct(src_id, fallback_dir) 
+        SearchForLicense_NormalRunBaseProduct(src_id, fallback_dir)
 
         # Base-product - first-stage installation
         #   * Stage is initial
@@ -812,12 +766,12 @@ module Yast
         SearchForLicense_FirstStageBaseProduct(
           src_id == nil ? Ops.get(Pkg.SourceGetCurrent(true), 0, 0) : src_id,
           fallback_dir
-        ) 
+        )
 
         # Add-on-product license
         #   * Source ID is set
       elsif src_id != nil && Ops.greater_than(src_id, -1)
-        SearchForLicense_AddOnProduct(src_id, fallback_dir) 
+        SearchForLicense_AddOnProduct(src_id, fallback_dir)
 
         # Fallback
       else
@@ -930,25 +884,7 @@ module Yast
         licenses.value = licenses_ref.value;
         _WhichLicenceFile_result
       )
-      license_ident.value = GetLicenseIdentString(base_license)
-
-      # agreement might be required even if license has been already accepted
-      # defined, properly ($md5sum(32)-(1)$size(1..n))
-      #
-      # see also BNC #448598
-      # Even if it it shown it sometimes doesn't need to be even accepted by
-      # selecting "yes, I agree"
-      if require_agreement != true &&
-          Builtins.tostring(license_ident.value) != nil &&
-          Ops.greater_than(Builtins.size(license_ident.value), 33) &&
-          IsLicenseAlreadyAccepted(license_ident.value)
-        Builtins.y2milestone("License has been already accepted/shown")
-
-        CleanUpLicense(@tmpdir)
-        return :accepted
-      else
-        Builtins.y2milestone("License needs to be shown")
-      end
+      log.info "License needs to be shown"
 
       # bugzilla #303922
       # src_id == nil (the initial product license)
@@ -957,7 +893,7 @@ module Yast
         if Stage.initial
           # Wizard::OpenNextBackStepsDialog();
           # WorkflowManager::RedrawWizardSteps();
-          Builtins.y2milestone("Initial stage, not opening any window...") 
+          Builtins.y2milestone("Initial stage, not opening any window...")
           # use normal wizard
         else
           Wizard.OpenNextBackDialog
@@ -995,6 +931,9 @@ module Yast
         Builtins.y2error("No such widget: %1", rp_id)
       end
 
+      # update displayed license URL after changing the license translation
+      update_license_location(@lic_lang, licenses)
+
       nil
     end
 
@@ -1017,16 +956,17 @@ module Yast
           Builtins.y2error("Widget %1 does not exist", eula_id)
           next
         end
+
         # All licenses have to be accepted
-        license_accepted = Convert.to_string(
-          UI.QueryWidget(Id(eula_id), :CurrentButton)
-        )
+        license_accepted = UI.QueryWidget(Id(eula_id), :Value)
+
         Builtins.y2milestone(
           "License %1 accepted: %2",
           eula_id,
           license_accepted
         )
-        if !Builtins.regexpmatch(license_accepted, "^yes_")
+
+        if !license_accepted
           accepted = false
           raise Break
         end
@@ -1045,18 +985,6 @@ module Yast
         if UI.WidgetExists(Id(eula_id)) != true
           Builtins.y2error("Widget %1 does not exist", eula_id)
         end
-        current_button = Convert.to_string(
-          UI.QueryWidget(Id(eula_id), :CurrentButton)
-        )
-        # license have to be accepted or declined
-        if current_button == nil
-          Builtins.y2warning(
-            "License %1 hasn't been accepted or declined",
-            eula_id
-          )
-          ret = false
-          raise Break
-        end
       end
 
       ret
@@ -1067,97 +995,79 @@ module Yast
 
       while true
         ret = UI.UserInput
+        log.info "User ret: #{ret}"
 
-        if Ops.is_string?(ret) &&
-            Builtins.regexpmatch(Builtins.tostring(ret), "^license_language_")
+        if ret.is_a?(::String) && ret.start_with?("license_language_")
           licenses_ref = arg_ref(licenses.value)
-          UpdateLicenseContent(licenses_ref, GetId(Builtins.tostring(ret)))
+          UpdateLicenseContent(licenses_ref, GetId(ret))
           licenses.value = licenses_ref.value
-          ret = :language 
-          # bugzilla #303828
-          # disabled next button unless yes/no is selected
-        elsif Ops.is_string?(ret) &&
-            (Builtins.regexpmatch(Builtins.tostring(ret), "^yes_") ||
-              Builtins.regexpmatch(Builtins.tostring(ret), "^no_"))
-          Wizard.EnableNextButton if AllLicensesAcceptedOrDeclined() 
-          # Aborting the license dialog
+          ret = :language
+        # bugzilla #303828
+        # disabled next button unless yes/no is selected
+        elsif ret.is_a?(::String) && ret.start_with?("eula_")
+          Wizard.EnableNextButton if AllLicensesAcceptedOrDeclined()
+        # Aborting the license dialog
         elsif ret == :abort
-          # bugzilla #218677
-          if base_product
-            if Popup.ConfirmAbort(:painless)
-              Builtins.y2milestone("Aborting...")
-              ret = :abort
-              break
-            end
+          # bnc#886662
+          if Stage.initial
+            next unless Popup.ConfirmAbort(:painless)
           else
             # popup question
-            if Popup.YesNo(_("Really abort the add-on product installation?"))
-              Builtins.y2milestone("Aborting...")
-              ret = :abort
-              break
-            end
+            next unless Popup.YesNo(_("Really abort the add-on product installation?"))
           end
+
+          log.warn "Aborting..."
+          break
         elsif ret == :next
-          # License declined
-          if AllLicensesAccepted() != true
-            # message is void in case not accepting license doesn't stop the installation
-            if action == "continue"
-              Builtins.y2milestone(
-                "action in case of license refusal is continue, not asking user"
-              )
-              ret = :accepted
-              break
-            end
-            # text changed due to bug #162499
-            refuse_popup_text = base_product ?
-              # text asking whether to refuse a license (Yes-No popup)
-              _(
-                "Refusing the license agreement cancels the installation.\nReally refuse the agreement?"
-              ) :
-              # text asking whether to refuse a license (Yes-No popup)
-              _(
-                "Refusing the license agreement cancels the add-on\nproduct installation. Really refuse the agreement?"
-              )
-            if !Popup.YesNo(refuse_popup_text)
-              next
-            else
-              Builtins.y2milestone("License has been declined.")
-              if action == "abort"
-                ret = :abort
-                break
-              elsif action == "continue"
-                ret = :accepted
-                break
-              elsif action == "halt"
-                ret = :halt
-                break
-                # timed ok/cancel popup
-                if !Popup.TimedOKCancel(_("The system is shutting down..."), 10)
-                  next
-                else
-                  ret = :halt
-                  break
-                end
-              else
-                Builtins.y2error("Unknown action %1", action)
-                ret = :abort
-                break
-              end
-            end
-          else
-            Builtins.y2milestone("All licenses have been accepted.")
+          if AllLicensesAccepted()
+            log.info "All licenses have been accepted."
             ret = :accepted
             break
           end
+
+          # License declined
+
+          # message is void in case not accepting license doesn't stop the installation
+          if action == "continue"
+            log.info "action in case of license refusal is continue, not asking user"
+            ret = :accepted
+            break
+          end
+
+          # text changed due to bug #162499
+          refuse_popup_text = base_product ?
+            # text asking whether to refuse a license (Yes-No popup)
+            _("Refusing the license agreement cancels the installation.\nReally refuse the agreement?")
+            :
+            # text asking whether to refuse a license (Yes-No popup)
+            _("Refusing the license agreement cancels the add-on\nproduct installation. Really refuse the agreement?")
+          next unless Popup.YesNo(refuse_popup_text)
+
+          log.info "License has been declined."
+
+          case action
+          when "abort"
+            ret = :abort
+          when "halt"
+            # timed ok/cancel popup
+            next unless Popup.TimedOKCancel(_("The system is shutting down..."), 10)
+            ret = :halt
+          else
+            log.error "Unknown action #{action}"
+            ret = :abort
+          end
+
+          break
         elsif ret == :back
           ret = :back
           break
         else
-          Builtins.y2error("Unhandled input: %1", ret)
+          log.error "Unhandled input: #{ret}"
         end
       end
 
-      Convert.to_symbol(ret)
+      log.info "Returning #{ret}"
+      ret
     end
 
     # Generic cleanup
@@ -1297,6 +1207,19 @@ module Yast
     #   has been already accepetd, ask user to accept it again (because of 'going back'
     #   in the installation proposal).
     def AskLicensesAgreement(dirs, patterns, action, enable_back, base_product, require_agreement)
+      # dialog caption
+      caption = _("License Agreement")
+      heading = nil
+
+      AskLicensesAgreementWithHeading(dirs, patterns, action, enable_back,
+          base_product, require_agreement, caption, heading)
+    end
+
+    # @see {AskLicensesAgreement} for details
+    # @param caption [String] custom dialog title
+    # @param heading [String] optional heading displayed above the license text
+    def AskLicensesAgreementWithHeading(dirs, patterns, action, enable_back,
+          base_product, require_agreement, caption, heading)
       dirs = deep_copy(dirs)
       patterns = deep_copy(patterns)
       if dirs == nil || dirs == []
@@ -1306,13 +1229,6 @@ module Yast
         return :auto
       end
 
-      init_ret = nil
-
-      if init_ret == :auto || init_ret == :accepted
-        Builtins.y2milestone("Returning %1", init_ret)
-        return init_ret
-      end
-
       created_new_dialog = false
 
       # #459391
@@ -1325,9 +1241,6 @@ module Yast
         created_new_dialog = true
       end
 
-      # dialog caption
-      caption = _("License Agreement")
-
       license_idents = []
 
       # initial loop
@@ -1335,7 +1248,13 @@ module Yast
 
       licenses = []
       counter = -1
-      contents = VBox()
+      contents = VBox(
+        heading ? VBox(
+          VSpacing(0.5),
+          Left(Heading(heading)),
+          VSpacing(0.5)
+        ) : Empty()
+      )
       # If acceptance is not needed, there's no need to disable the button
       # by default
       default_next_button_state = true
@@ -1432,7 +1351,7 @@ module Yast
       CleanUpLicense(@tmpdir)
 
       # bugzilla #303922
-      Wizard.CloseDialog if created_new_dialog || !Stage.initial
+      Wizard.CloseDialog if created_new_dialog
 
       CleanUp()
 
@@ -1629,6 +1548,55 @@ module Yast
     publish :function => :ShowLicenseInInstallation, :type => "boolean (any, integer)"
     publish :function => :AskInstalledLicenseAgreement, :type => "symbol (string, string)"
     publish :function => :AskInstalledLicensesAgreement, :type => "symbol (list <string>, string)"
+
+    private
+
+    # check if the license location is an URL for download
+    # @param [String] location
+    # @return [Boolean] true if it is a HTTP, HTTPS or an FTP URL
+    def location_is_url?(location)
+      return false unless location.is_a?(::String)
+      DOWNLOAD_URL_SCHEMA.include?(URI(location).scheme)
+    rescue URI::InvalidURIError => e
+      log.error "Error while parsing URL #{location.inspect}: #{e.message}"
+      false
+    end
+
+    # split a long URL to multiple lines
+    # @param [String] url URL
+    # @return [String] URL split to multiple lines if too long
+    def format_url(url)
+      url.scan(/.{1,57}/).join("\n")
+    end
+
+    # crate a label describing the license URL location
+    # @param [String] display_url URL to display
+    # return [String] translated label
+    def license_download_label(display_url)
+      # TRANSLATORS: %{license_url} is an URL where the displayed license can be found
+      (_("If you want to print this EULA, you can download it from\n%{license_url}") %
+        { :license_url => display_url } )
+    end
+
+    # update license location displayed in the dialog (e.g. after license translation
+    # is changed)
+    # @param [String] lang language of the currently displayed license
+    # @param [Yast::ArgRef] reference to the list of licenses
+    def update_license_location(lang, licenses)
+      if location_is_url?(license_file_print) && UI.WidgetExists(:printing_hint)
+        # name of the license file
+        file = File.basename(WhichLicenceFile(lang, licenses))
+
+        url = URI(license_file_print)
+        url.path = File.join(url.path, file)
+        log.info "Updating license URL: #{url}"
+
+        display_url = format_url(url.to_s)
+
+        UI.ReplaceWidget(:printing_hint, Label(license_download_label(display_url)))
+      end
+    end
+
   end
 
   ProductLicense = ProductLicenseClass.new
