@@ -109,6 +109,13 @@ require "yast"
 
 module Yast
   class SlideShowClass < Module
+    include Yast::Logger
+
+    module UI_ID
+      TOTAL_PROGRESS = :progressTotal
+      CURRENT_PACKAGE = :progressCurrentPackage
+    end
+
     def main
       Yast.import "UI"
 
@@ -129,9 +136,7 @@ module Yast
 
       @current_slide_no = 0
       @slide_start_time = 0
-      @slide_min_interval = 30 # const - minimum seconds between slide changes
-      @slide_max_interval = 3 * 60 # const - maximum seconds between slide changes
-      @slide_interval = @slide_min_interval
+      @slide_interval = 30 # FIXME: constant
       @language = "en"
       @widgets_created = false
       @user_switched_to_details = false
@@ -142,6 +147,7 @@ module Yast
       @user_abort = false
 
       # we need to remember the values for tab switching
+      # these are the initial values
       @total_progress_label = _("Installing...")
       @sub_progress_label = _("Installing...")
       @total_progress_value = 0
@@ -158,6 +164,10 @@ module Yast
 
       @_stages = {} # list of the configured stages
       @_current_stage = nil # current stage
+
+      @_rn_tabs = {} # tabs with release notes
+      @_relnotes = {} # texts with release notes, product -> text
+      @_base_product = "" # base product for release notes ordering
     end
 
     # Set the flag that user requested abort of the installation
@@ -182,7 +192,6 @@ module Yast
       nil
     end
 
-
     # Reset the internal (global) timer.
     #
     def ResetTimer
@@ -191,7 +200,6 @@ module Yast
       nil
     end
 
-
     # Stop the internal (global) timer and account elapsed time.
     #
     def StopTimer
@@ -221,7 +229,6 @@ module Yast
       @widgets_created && UI.WidgetExists(:detailsPage)
     end
 
-
     # Check if currently the "Slide Show" page is shown
     # @return true if showing details, false otherwise
     #
@@ -232,71 +239,76 @@ module Yast
     # Check if currently the "Release Notes" page is shown
     # @return true if showing details, false otherwise
     #
-    def ShowingRelNotes
-      @widgets_created && UI.WidgetExists(:relNotesPage)
+    def ShowingRelNotes(id)
+      @widgets_created && UI.WidgetExists(id)
+    end
+
+    def ProductRelNotesID(product)
+      ("rn_" + product).to_sym
     end
 
     # Restart the subprogress of the slideshow. This means the
-    # label will be set to \param text, value to 0.
+    # label will be set to given text, value to 0.
     # @param [String] text	new label for the subprogress
     def SubProgressStart(text)
-      if UI.WidgetExists(:progressCurrentPackage)
-        UI.ChangeWidget(:progressCurrentPackage, :Value, 0)
-        UI.ChangeWidget(:progressCurrentPackage, :Label, text)
-      end
-
-      @sub_progress_label = text
-
-      nil
+      SubProgress(0, text)
     end
 
-    # Update status of subprogress of the slideshow. The new value will be set
-    # to \param value, if the \text is not nil, the label will be updated
-    # to this text as well. Otherwise label will not change.
+    # Updates status of the sub-progress in slide show. The new value and label
+    # will be set to values given as parametes. If a given parameter contains *nil*,
+    # respective value/label will not be updated.
+    #
     # @param [Fixnum] value	new value for the subprogress
-    # @param [String] text	new label for the subprogress
-    def SubProgress(value, text)
-      if UI.WidgetExists(:progressCurrentPackage)
-        UI.ChangeWidget(:progressCurrentPackage, :Value, value)
-        UI.ChangeWidget(:progressCurrentPackage, :Label, text) if text != nil
-      end
+    # @param [String] label	new label for the subprogress
+    def SubProgress(value, label)
+      value ||= @sub_progress_value
+      label ||= @sub_progress_label
 
-      @sub_progress_value = value
-      @sub_progress_label = text if text != nil
+      if UI.WidgetExists(UI_ID::CURRENT_PACKAGE)
+        if @sub_progress_value != value
+          @sub_progress_value = value
+          UI.ChangeWidget(UI_ID::CURRENT_PACKAGE, :Value, value)
+        end
+
+        if @sub_progress_label != label
+          @sub_progress_label = label
+          UI.ChangeWidget(UI_ID::CURRENT_PACKAGE, :Label, label)
+        end
+      end
 
       nil
     end
 
     # Restart the global progress of the slideshow. This means the
-    # label will be set to \param text, value to 0.
+    # label will be set to given text, value to 0.
+    #
     # @param [String] text	new label for the global progress
     def GlobalProgressStart(text)
-      @total_progress_label = text
-      if UI.WidgetExists(:progressTotal)
-        UI.ChangeWidget(:progressTotal, :Value, 0)
-        UI.ChangeWidget(:progressTotal, :Label, text)
-      end
-
-      @total_progress_label = text
-      @total_progress_value = 0
-
-      nil
+      UpdateGlobalProgress(0, text)
     end
 
-    # Update status of global progress of the slideshow. The new value will be set
-    # to \param value, if the \text is not nil, the label will be updated
-    # to this text as well. Otherwise label will not change.
+    # Updates status of the global progress in slide show. The new value and label
+    # will be set to values given as parametes. If a given parameter contains *nil*,
+    # respective value/label will not be updated.
+    #
     # @param [Fixnum] value	new value for the global progress
-    # @param text	new label for the global progress
-    def UpdateGlobalProgress(value, new_text)
-      @total_progress_label = new_text if new_text != nil
-      @total_progress_value = value
+    # @param [String] label	new label for the global progress
+    def UpdateGlobalProgress(value, label)
+      value ||= @total_progress_value
+      label ||= @total_progress_label
 
-      if UI.WidgetExists(:progressTotal)
-        UI.ChangeWidget(:progressTotal, :Value, value)
-        UI.ChangeWidget(:progressTotal, :Label, new_text) if new_text != nil
+      if UI.WidgetExists(UI_ID::TOTAL_PROGRESS)
+        if @total_progress_value != value
+          @total_progress_value = value
+          UI.ChangeWidget(UI_ID::TOTAL_PROGRESS, :Value, value)
+        end
+
+        if @total_progress_label != label
+          @total_progress_label = label
+          UI.ChangeWidget(UI_ID::TOTAL_PROGRESS, :Label, label)
+        end
       else
-        Builtins.y2milestone("progressTotal widget missing")
+        log.warn "progressTotal widget missing"
       end
 
       # update slide
@@ -363,13 +375,11 @@ module Yast
       nil
     end
 
-    # Return the current global progress label.
-    # @return [String]	current label
+    # Sets the current global progress label.
+    #
+    # @param [String]	new label
     def SetGlobalProgressLabel(text)
-      @total_progress_label = text
-      if UI.WidgetExists(:progressTotal)
-        UI.ChangeWidget(:progressTotal, :Label, text)
-      end
+      UpdateGlobalProgress(nil, text)
 
       nil
     end
@@ -377,27 +387,23 @@ module Yast
     # Append message to the installation log.
     # @param [String] msg	message to be added, without trailing eoln
     def AppendMessageToInstLog(msg)
-      log_line = Ops.add(msg, "\n")
-      @inst_log = Ops.add(@inst_log, log_line)
+      log_line = "#{msg}\n"
 
-      if ShowingDetails()
-        if UI.WidgetExists(:instLog)
-          UI.ChangeWidget(:instLog, :LastLine, log_line)
-        end
+      @inst_log << log_line
+
+      if ShowingDetails() && UI.WidgetExists(:instLog)
+        UI.ChangeWidget(:instLog, :LastLine, log_line)
       end
 
       nil
     end
 
-
-
     # Check if the dialog is currently set up so the user could switch to the slide page.
     #
     def HaveSlideWidget
       UI.WidgetExists(:dumbTab)
     end
 
-
     # Check if the slide show is available. This must be called before trying
     # to access any slides; some late initialization is done here.
     #
@@ -418,7 +424,6 @@ module Yast
       nil
     end
 
-
     # Set the slide show text.
     # @param [String] text
     #
@@ -428,7 +433,6 @@ module Yast
       nil
     end
 
-
     # Set the curent language. Must be called once during initialization.
     #
     def SetLanguage(new_language)
@@ -438,19 +442,18 @@ module Yast
       nil
     end
 
-
     # Create one single item for the CD statistics table
     #
     def TableItem(id, col1, col2, col3, col4)
       Item(Id(id), col1, col2, col3, col4)
     end
 
-
     # Load a slide image + text.
     # @param [Fixnum] slide_no number of slide to load
     #
     def LoadSlide(slide_no)
-      slide_no = 0 if Ops.greater_than(slide_no, Builtins.size(Slides.slides))
+      slide_no = 0 if slide_no >= Slides.slides.size
+      log.info "load slide #{slide_no}"
 
       @current_slide_no = slide_no
 
@@ -462,21 +465,12 @@ module Yast
       nil
     end
 
-
     # Check if the current slide needs to be changed and do that if
     # necessary.
     #
     def ChangeSlideIfNecessary
-      if Ops.less_than(
-          Ops.add(@current_slide_no, 1),
-          Builtins.size(Slides.slides)
-        ) &&
-          Ops.greater_than(
-            Builtins.time,
-            Ops.add(@slide_start_time, @slide_interval)
-          )
-        Builtins.y2debug("Loading slide #%1", Ops.add(@current_slide_no, 2))
-        LoadSlide(Ops.add(@current_slide_no, 1))
+      if Builtins.time > (@slide_start_time + @slide_interval)
+        LoadSlide(@current_slide_no + 1)
       end
 
       nil
@@ -500,7 +494,7 @@ module Yast
           # too much flicker upon update (UI::RecalcLayout() ) on NCurses
           # Progress bar for overall progress of software package installation
           ProgressBar(
-            Id(:progressTotal),
+            Id(UI_ID::TOTAL_PROGRESS),
             @total_progress_label,
             100,
             @total_progress_value
@@ -513,7 +507,6 @@ module Yast
       deep_copy(widgets)
     end
 
-
     # Construct widgets describing a page with the real slide show
     # (the RichText / HTML page)
     #
@@ -535,7 +528,7 @@ module Yast
             # Table headings for CD statistics during installation
             _("Media"),
             # Table headings for CD statistics during installation - keep as short as possible!
-            Right(_("Installed Size")),
+            Right(_("Remaining")),
             # Table headings for CD statistics during installation
             Right(_("Packages")),
             # Table headings for CD statistics during installation
@@ -557,7 +550,7 @@ module Yast
           @_show_table ? DetailsTableWidget() : Empty(),
           VWeight(1, LogView(Id(:instLog), _("Actions performed:"), 6, 0)),
           ProgressBar(
-            Id(:progressCurrentPackage),
+            Id(UI_ID::CURRENT_PACKAGE),
             @sub_progress_label,
             100,
             @sub_progress_value
@@ -573,13 +566,12 @@ module Yast
     #
     # @return	A term describing the widgets
     #
-    def RelNotesPageWidgets
-      widgets = AddProgressWidgets(:relNotesPage, RichText(@relnotes))
+    def RelNotesPageWidgets(id)
+      widgets = AddProgressWidgets(:relNotesPage, RichText(@_rn_tabs[id]))
       Builtins.y2debug("widget term: \n%1", widgets)
       deep_copy(widgets)
     end
 
-
     # Switch from the 'details' view to the 'slide show' view.
     #
     def SwitchToSlideView
@@ -587,7 +579,7 @@ module Yast
 
       if UI.WidgetExists(:tabContents)
         UI.ChangeWidget(:dumbTab, :CurrentItem, :showSlide)
-        UI.ReplaceWidget(:tabContents, SlidePageWidgets()) 
+        UI.ReplaceWidget(:tabContents, SlidePageWidgets())
         # UpdateTotalProgress(false);		// FIXME: this breaks other stages!
       end
 
@@ -597,7 +589,7 @@ module Yast
     # Rebuild the details page.
     def RebuildDetailsView
       if UI.WidgetExists(:tabContents)
-        UI.ChangeWidget(:dumbTab, :CurrentItem, :showDetails)
+        UI.ChangeWidget(:dumbTab, :CurrentItem, :showDetails) if UI.WidgetExists(:dumbTab)
         UI.ReplaceWidget(:tabContents, DetailsPageWidgets())
         Builtins.y2milestone("Contents set to details")
       end
@@ -623,19 +615,18 @@ module Yast
 
     # Switch to the 'release notes' view.
     #
-    def SwitchToReleaseNotesView
-      return if ShowingRelNotes()
+    def SwitchToReleaseNotesView(id)
+      return if ShowingRelNotes(id)
 
       if UI.WidgetExists(:tabContents)
-        UI.ChangeWidget(:dumbTab, :CurrentItem, :showRelNotes)
-        UI.ReplaceWidget(:tabContents, RelNotesPageWidgets()) 
+        UI.ChangeWidget(:dumbTab, :CurrentItem, id)
+        UI.ReplaceWidget(:tabContents, RelNotesPageWidgets(id))
         # UpdateTotalProgress(false);
       end
 
       nil
     end
 
-
     # Help text for the dialog
     def HelpText
       # Help text while software packages are being installed (displayed only in rare cases)
@@ -647,6 +638,20 @@ module Yast
       help_text
     end
 
+    # set the release notes for slide show
+    # @param [map<string,string>] map product name -> release notes text
+    # @param [string] base product name
+    def SetReleaseNotes(relnotes, base_product)
+      @_relnotes = relnotes
+      @_base_product = base_product
+    end
+
+    def add_relnotes_for_product(product, relnotes, tabs)
+      id = ProductRelNotesID product
+      # Translators: Tab name, keep short, %s is product name, e.g. SLES
+      tabs << Item(Id(id), _("%s Release Notes") % product)
+      @_rn_tabs[id] = relnotes
+    end
 
     # Rebuild the dialog. Useful if slides become available post-creating the dialog.
     def RebuildDialog
@@ -660,12 +665,15 @@ module Yast
           # tab
           Item(Id(:showDetails), _("&Details"))
         ]
-        if @relnotes != nil && @relnotes != ""
-          # tab
-          tabs = Builtins.add(
-            tabs,
-            Item(Id(:showRelNotes), _("Release &Notes"))
-          )
+
+        @_rn_tabs = {}
+        if @_relnotes.key?(@_base_product)
+          add_relnotes_for_product @_base_product, @_relnotes[@_base_product], tabs
+        end
+        @_relnotes.each do | product, relnotes |
+          if @_base_product != product
+            add_relnotes_for_product product, relnotes, tabs
+          end
         end
 
         contents = DumbTab(
@@ -685,20 +693,25 @@ module Yast
           )
         )
       else
-        # no tabs
-        contents = DetailsPageWidgets()
+        # no tabs, but we need to modify hide cd statistics table, so add replace point
+        contents = ReplacePoint(Id(:tabContents), DetailsPageWidgets())
       end
 
       Builtins.y2milestone("SlideShow contents: %1", contents)
 
       Wizard.SetContents(
-        # Dialog heading while software packages are being installed
-        _("Perform Installation"),
+        if Mode.update
+          # Dialog heading - software packages are being upgraded
+          _("Performing Upgrade")
+        else
+          # Dialog heading - software packages are being installed
+          _("Performing Installation")
+        end,
         contents,
         HelpText(),
-        false,
-        false
-      ) # has_back, has_next
+        false, # no back button
+        false  # no next button
+      )
 
       @widgets_created = true
 
@@ -710,8 +723,6 @@ module Yast
       nil
     end
 
-
-
     # Open the slide show base dialog with empty work area (placeholder for
     # the image) and CD statistics.
     #
@@ -745,10 +756,9 @@ module Yast
       nil
     end
 
-
     # Initialize generic data to default values
     def Reset
-      @current_slide_no = 0
+      @current_slide_no = -1
       @slide_start_time = 0
       @total_time_elapsed = 0
       @start_time = -1
@@ -760,8 +770,6 @@ module Yast
       nil
     end
 
-
-
     # Process (slide show) input (button press).
     #
     def HandleInput(button)
@@ -778,19 +786,18 @@ module Yast
         else
           UI.ChangeWidget(:dumbTab, :CurrentItem, :showDetails)
         end
-      elsif button == :showRelNotes && !ShowingRelNotes()
+      elsif @_rn_tabs.key?(button) && !ShowingRelNotes(button)
         @user_switched_to_details = false
-        SwitchToReleaseNotesView()
+        SwitchToReleaseNotesView(button)
       elsif button == :debugHotkey
         @debug = !@debug
         Builtins.y2milestone("Debug mode: %1", @debug)
-      end 
+      end
       # note: `abort is handled in SlideShowCallbacks::HandleInput()
 
       nil
     end
 
-
     # Check for user button presses and handle them. Generic handling to be used in the
     # progress handlers.
     #
@@ -845,7 +852,6 @@ module Yast
       nil
     end
 
-
     # Close the slide show dialog.
     #
     def CloseDialog
@@ -908,6 +914,7 @@ module Yast
     #  ]
     def Setup(stages)
       stages = deep_copy(stages)
+      log.info "SlideShow stages: #{stages}"
       # initiliaze the generic counters
       Reset()
 
@@ -935,6 +942,7 @@ module Yast
 
       @_stages = {} # prepare a new stages description
 
+      total_size = 0
       # distribute the total time to stages as per cents
       Builtins.foreach(stages) do |stage|
         if Ops.get_symbol(stage, "units", :sec) == :sec
@@ -964,17 +972,36 @@ module Yast
           )
           Ops.set(stage, "start", start)
           if Ops.greater_than(
-              Ops.add(Ops.get_integer(stage, "size", 0), start),
-              100
+            Ops.add(Ops.get_integer(stage, "size", 0), start),
+            100
             )
             Ops.set(stage, "size", Ops.subtract(100, start))
           end
 
           start = Ops.add(start, Ops.get_integer(stage, "size", 0))
         end
+        total_size += stage["size"]
         Ops.set(@_stages, Ops.get_string(stage, "name", ""), stage)
         # setup first stage
-        @_current_stage = deep_copy(stage) if @_current_stage == nil
+        @_current_stage = deep_copy(stage) if @_current_stage.nil?
+      end
+
+      # Because of using integers in the calculation above the sum of the sizes
+      # might not be 100% due to rounding. Update the last stage so the
+      # total installation progress is 100%.
+      if total_size != 100
+        log.info "Total global progress: #{total_size}%, adjusting to 100%..."
+
+        # find the last stage and adjust it
+        updated_stage_name = stages.last["name"]
+        updated_stage = @_stages[updated_stage_name]
+
+        new_size = 100 - total_size + updated_stage["size"]
+        log.info "Updating '#{updated_stage_name}' stage size from " \
+          "#{updated_stage["size"]}% to #{new_size}%"
+
+        updated_stage["size"] = new_size
+        @_stages[updated_stage_name] = updated_stage
       end
 
       Builtins.y2milestone("Global progress bar: %1", @_stages)
@@ -994,60 +1021,59 @@ module Yast
       deep_copy(@_stages)
     end
 
-    publish :variable => :total_time_elapsed, :type => "integer"
-    publish :variable => :start_time, :type => "integer"
-    publish :variable => :initial_recalc_delay, :type => "integer"
-    publish :variable => :recalc_interval, :type => "integer"
-    publish :variable => :next_recalc_time, :type => "integer"
-    publish :variable => :current_slide_no, :type => "integer"
-    publish :variable => :slide_start_time, :type => "integer"
-    publish :variable => :slide_min_interval, :type => "integer"
-    publish :variable => :slide_max_interval, :type => "integer"
-    publish :variable => :slide_interval, :type => "integer"
-    publish :variable => :language, :type => "string"
-    publish :variable => :widgets_created, :type => "boolean"
-    publish :variable => :user_switched_to_details, :type => "boolean"
-    publish :variable => :opened_own_wizard, :type => "boolean"
-    publish :variable => :inst_log, :type => "string"
-    publish :variable => :debug, :type => "boolean"
-    publish :variable => :textmode, :type => "boolean"
-    publish :variable => :display_width, :type => "integer"
-    publish :variable => :relnotes, :type => "string"
-    publish :function => :ChangeSlideIfNecessary, :type => "void ()"
-    publish :function => :SetUserAbort, :type => "void (boolean)"
-    publish :function => :GetUserAbort, :type => "boolean ()"
-    publish :function => :StartTimer, :type => "void ()"
-    publish :function => :ResetTimer, :type => "void ()"
-    publish :function => :StopTimer, :type => "void ()"
-    publish :function => :ShowingDetails, :type => "boolean ()"
-    publish :function => :ShowingSlide, :type => "boolean ()"
-    publish :function => :ShowingRelNotes, :type => "boolean ()"
-    publish :function => :SubProgressStart, :type => "void (string)"
-    publish :function => :SubProgress, :type => "void (integer, string)"
-    publish :function => :GlobalProgressStart, :type => "void (string)"
-    publish :function => :CurrentStageDescription, :type => "string ()"
-    publish :function => :MoveToStage, :type => "void (string)"
-    publish :function => :StageProgress, :type => "void (integer, string)"
-    publish :function => :SetGlobalProgressLabel, :type => "void (string)"
-    publish :function => :AppendMessageToInstLog, :type => "void (string)"
-    publish :function => :HaveSlideWidget, :type => "boolean ()"
-    publish :function => :CheckForSlides, :type => "void ()"
-    publish :function => :SetLanguage, :type => "void (string)"
-    publish :function => :TableItem, :type => "term (string, string, string, string, string)"
-    publish :function => :SwitchToSlideView, :type => "void ()"
-    publish :function => :SwitchToDetailsView, :type => "void ()"
-    publish :function => :SwitchToReleaseNotesView, :type => "void ()"
-    publish :function => :RebuildDialog, :type => "void ()"
-    publish :function => :Reset, :type => "void ()"
-    publish :function => :HandleInput, :type => "void (any)"
-    publish :function => :GenericHandleInput, :type => "void ()"
-    publish :function => :OpenDialog, :type => "void ()"
-    publish :function => :CloseDialog, :type => "void ()"
-    publish :function => :ShowTable, :type => "void ()"
-    publish :function => :HideTable, :type => "void ()"
-    publish :function => :UpdateTable, :type => "void (list <term>)"
-    publish :function => :Setup, :type => "void (list <map <string, any>>)"
-    publish :function => :GetSetup, :type => "map <string, map <string, any>> ()"
+    publish variable: :total_time_elapsed, type: "integer"
+    publish variable: :start_time, type: "integer"
+    publish variable: :initial_recalc_delay, type: "integer"
+    publish variable: :recalc_interval, type: "integer"
+    publish variable: :next_recalc_time, type: "integer"
+    publish variable: :current_slide_no, type: "integer"
+    publish variable: :slide_start_time, type: "integer"
+    publish variable: :slide_interval, type: "integer"
+    publish variable: :language, type: "string"
+    publish variable: :widgets_created, type: "boolean"
+    publish variable: :user_switched_to_details, type: "boolean"
+    publish variable: :opened_own_wizard, type: "boolean"
+    publish variable: :inst_log, type: "string"
+    publish variable: :debug, type: "boolean"
+    publish variable: :textmode, type: "boolean"
+    publish variable: :display_width, type: "integer"
+    publish variable: :relnotes, type: "string"
+    publish function: :ChangeSlideIfNecessary, type: "void ()"
+    publish function: :SetUserAbort, type: "void (boolean)"
+    publish function: :GetUserAbort, type: "boolean ()"
+    publish function: :StartTimer, type: "void ()"
+    publish function: :ResetTimer, type: "void ()"
+    publish function: :StopTimer, type: "void ()"
+    publish function: :ShowingDetails, type: "boolean ()"
+    publish function: :ShowingSlide, type: "boolean ()"
+    publish function: :ShowingRelNotes, type: "boolean (symbol)"
+    publish function: :SubProgressStart, type: "void (string)"
+    publish function: :SubProgress, type: "void (integer, string)"
+    publish function: :GlobalProgressStart, type: "void (string)"
+    publish function: :CurrentStageDescription, type: "string ()"
+    publish function: :MoveToStage, type: "void (string)"
+    publish function: :StageProgress, type: "void (integer, string)"
+    publish function: :SetGlobalProgressLabel, type: "void (string)"
+    publish function: :AppendMessageToInstLog, type: "void (string)"
+    publish function: :HaveSlideWidget, type: "boolean ()"
+    publish function: :CheckForSlides, type: "void ()"
+    publish function: :SetLanguage, type: "void (string)"
+    publish function: :TableItem, type: "term (string, string, string, string, string)"
+    publish function: :SwitchToSlideView, type: "void ()"
+    publish function: :SwitchToDetailsView, type: "void ()"
+    publish function: :SwitchToReleaseNotesView, type: "void (symbol)"
+    publish function: :RebuildDialog, type: "void ()"
+    publish function: :Reset, type: "void ()"
+    publish function: :HandleInput, type: "void (any)"
+    publish function: :GenericHandleInput, type: "void ()"
+    publish function: :OpenDialog, type: "void ()"
+    publish function: :CloseDialog, type: "void ()"
+    publish function: :ShowTable, type: "void ()"
+    publish function: :HideTable, type: "void ()"
+    publish function: :UpdateTable, type: "void (list <term>)"
+    publish function: :Setup, type: "void (list <map <string, any>>)"
+    publish function: :GetSetup, type: "map <string, map <string, any>> ()"
+    publish function: :SetReleaseNotes, type: "void (map<string, string>, string)"
   end
 
   SlideShow = SlideShowClass.new
