@@ -160,7 +160,7 @@ module Yast
         # already known but not assigned
         next if Builtins.contains(last_known_interfaces, interface)
         # already configured in some zone
-        next if SuSEFirewall.GetZoneOfInterface(interface) != nil
+        next if !SuSEFirewall.GetZoneOfInterface(interface).nil?
         # any dial-up interfaces presented and the new one isn't dial-up
         if had_dialup_interfaces && !IsDialUpInterface(interface)
           AddWarning(
@@ -199,12 +199,12 @@ module Yast
     # @return [Boolean] if enabled
     def ServiceEnabled(service, zones)
       zones = deep_copy(zones)
-      if service == nil || service == ""
+      if service.nil? || service == ""
         Builtins.y2error("Ups, service: %1?", service)
         return false
       end
 
-      if zones == nil || zones == []
+      if zones.nil? || zones == []
         Builtins.y2error("Ups, zones: %1?", zones)
         return false
       end
@@ -240,9 +240,11 @@ module Yast
         zones
       )
 
-      Builtins.foreach(zones) { |one_zone| Builtins.foreach(fallback_ports) do |one_port|
-        SuSEFirewall.AddService(one_port, "TCP", one_zone)
-      end }
+      Builtins.foreach(zones) do |one_zone|
+        Builtins.foreach(fallback_ports) do |one_port|
+          SuSEFirewall.AddService(one_port, "TCP", one_zone)
+        end
+      end
 
       nil
     end
@@ -290,7 +292,7 @@ module Yast
       Builtins.foreach(SuSEFirewall.GetKnownFirewallZones) do |zone|
         # either service is supported
         if SuSEFirewall.IsServiceSupportedInZone(service, zone)
-          ret = true 
+          ret = true
           # or check for ports
         else
           all_ports = true
@@ -325,10 +327,10 @@ module Yast
 
       # Opening the service for non-dial-up interfaces
       if Ops.greater_than(Builtins.size(non_dial_up_interfaces), 0)
-        OpenServiceInInterfaces(service, fallback_ports, non_dial_up_interfaces) 
+        OpenServiceInInterfaces(service, fallback_ports, non_dial_up_interfaces)
         # Only dial-up network interfaces, there mustn't be any non-dial-up one
       elsif Ops.greater_than(Builtins.size(dial_up_interfaces), 0)
-        OpenServiceInInterfaces(service, fallback_ports, dial_up_interfaces) 
+        OpenServiceInInterfaces(service, fallback_ports, dial_up_interfaces)
         # No network interfaces are known
       elsif Builtins.size(@known_interfaces) == 0
         if SuSEFirewall.IsAnyNetworkInterfaceSupported == true
@@ -402,7 +404,7 @@ module Yast
         SetInterfacesToZone(dial_up_interfaces, "EXT")
         if ProductFeatures.GetBooleanFeature("globals", "firewall_enable_ssh")
           SuSEFirewall.SetServicesForZones([@ssh_service], ["INT", "EXT"], true)
-        end 
+        end
 
         # has non-dial-up and doesn't have dial-up interfaces
       elsif Ops.greater_than(Builtins.size(non_dup_interfaces), 0) &&
@@ -410,7 +412,7 @@ module Yast
         SetInterfacesToZone(non_dup_interfaces, "EXT")
         if ProductFeatures.GetBooleanFeature("globals", "firewall_enable_ssh")
           SuSEFirewall.SetServicesForZones([@ssh_service], ["EXT"], true)
-        end 
+        end
 
         # doesn't have non-dial-up and has dial-up interfaces
       elsif Builtins.size(non_dup_interfaces) == 0 &&
@@ -532,7 +534,7 @@ module Yast
       if !GetChangedByUser()
         Builtins.y2milestone("Calling firewall configuration proposal")
         Reset()
-        ProposeFunctions() 
+        ProposeFunctions()
         # Changed - don't break user's configuration
       else
         Builtins.y2milestone("Calling firewall configuration update proposal")
@@ -576,17 +578,19 @@ module Yast
       output = Ops.add(
         Ops.add(
           Ops.add(output, "<li>"),
-          firewall_is_enabled ?
+          if firewall_is_enabled
             # TRANSLATORS: Proposal informative text "Firewall is enabled (disable)" with link around
             # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
             _(
               "Firewall is enabled (<a href=\"firewall--disable_firewall_in_proposal\">disable</a>)"
-            ) :
+            )
+          else
             # TRANSLATORS: Proposal informative text "Firewall is disabled (enable)" with link around
             # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
             _(
               "Firewall is disabled (<a href=\"firewall--enable_firewall_in_proposal\">enable</a>)"
             )
+          end
         ),
         "</li>\n"
       )
@@ -615,20 +619,22 @@ module Yast
           output = Ops.add(
             Ops.add(
               Ops.add(output, "<li>"),
-              is_ssh_enabled ?
+              if is_ssh_enabled
                 # TRANSLATORS: Network proposal informative text with link around
                 # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
                 _(
                   "SSH port is open (<a href=\"firewall--disable_ssh_in_proposal\">close</a>)"
-                ) :
+                )
+              else
                 # TRANSLATORS: Network proposal informative text with link around
                 # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
                 _(
                   "SSH port is blocked (<a href=\"firewall--enable_ssh_in_proposal\">open</a>)"
                 )
+              end
             ),
             "</li>\n"
-          ) 
+          )
 
           # No known interfaces, but 'any' is supported
           # and ssh is enabled there
@@ -676,7 +682,7 @@ module Yast
               )
             ) do |zone|
               if SuSEFirewall.IsServiceSupportedInZone(@vnc_service, zone) == true
-                is_vnc_enabled = true 
+                is_vnc_enabled = true
                 # checking also fallback ports
               else
                 set_vnc_enabled_to = true
@@ -697,17 +703,19 @@ module Yast
           output = Ops.add(
             Ops.add(
               Ops.add(output, "<li>"),
-              is_vnc_enabled ?
+              if is_vnc_enabled
                 # TRANSLATORS: Network proposal informative text "Remote Administration (VNC) is enabled" with link around
                 # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
                 _(
                   "Remote Administration (VNC) ports are open (<a href=\"firewall--disable_vnc_in_proposal\">close</a>)"
-                ) :
+                )
+              else
                 # TRANSLATORS: Network proposal informative text "Remote Administration (VNC) is disabled" with link around
                 # IMPORTANT: Please, do not change the HTML link <a href="...">...</a>, only visible text
                 _(
                   "Remote Administration (VNC) ports are blocked (<a href=\"firewall--enable_vnc_in_proposal\">open</a>)"
                 )
+              end
             ),
             "</li>\n"
           )
@@ -731,11 +739,13 @@ module Yast
           output = Ops.add(
             Ops.add(
               Ops.add(output, "<li>"),
-              is_iscsi_enabled ?
+              if is_iscsi_enabled
                 # TRANSLATORS: Network proposal informative text
-                _("iSCSI Target ports are open") :
+                _("iSCSI Target ports are open")
+              else
                 # TRANSLATORS: Network proposal informative text
                 _("iSCSI Target ports are blocked")
+              end
             ),
             "</li>\n"
           )
@@ -768,14 +778,14 @@ module Yast
       { "output" => output, "warning" => warning }
     end
 
-    publish :function => :OpenServiceOnNonDialUpInterfaces, :type => "void (string, list <string>)"
-    publish :function => :SetChangedByUser, :type => "void (boolean)"
-    publish :function => :GetChangedByUser, :type => "boolean ()"
-    publish :function => :SetProposalInitialized, :type => "void (boolean)"
-    publish :function => :GetProposalInitialized, :type => "boolean ()"
-    publish :function => :Reset, :type => "void ()"
-    publish :function => :Propose, :type => "void ()"
-    publish :function => :ProposalSummary, :type => "map <string, string> ()"
+    publish function: :OpenServiceOnNonDialUpInterfaces, type: "void (string, list <string>)"
+    publish function: :SetChangedByUser, type: "void (boolean)"
+    publish function: :GetChangedByUser, type: "boolean ()"
+    publish function: :SetProposalInitialized, type: "void (boolean)"
+    publish function: :GetProposalInitialized, type: "boolean ()"
+    publish function: :Reset, type: "void ()"
+    publish function: :Propose, type: "void ()"
+    publish function: :ProposalSummary, type: "map <string, string> ()"
   end
 
   SuSEFirewallProposal = SuSEFirewallProposalClass.new
