@@ -41,9 +41,6 @@ module Yast
       # Additional files from Import
       @custom_files = []
 
-      # all read variables
-      @variables = {}
-
       # modified variables
       @modified_variables = {}
 
@@ -71,6 +68,10 @@ module Yast
       @config_modified = false
     end
 
+    def inspect
+      "<#{self} @configfiles=#{@configfiles} >"
+    end
+
     # Data was modified?
     # @return true if modified
     def Modified
@@ -135,7 +136,7 @@ module Yast
         else
           ret = Ops.add(Ops.add(ret, com_line), "\n")
         end
-      end 
+      end
 
 
       ret
@@ -238,7 +239,7 @@ module Yast
           index = Ops.add(index, 1)
           UI.ChangeWidget(Id(:progress), :Value, index)
         end
-      end 
+      end
 
 
       UI.CloseDialog if show_progress == true
@@ -321,7 +322,7 @@ module Yast
           # add line to the previous lines
           multiline = Ops.add(multiline, part)
         end
-      end 
+      end
 
 
       Builtins.y2debug(
@@ -361,7 +362,7 @@ module Yast
             Builtins.y2warning("Unknown metadata line: %1", metaline)
           end
         end
-      end 
+      end
 
 
       deep_copy(ret)
@@ -714,7 +715,7 @@ module Yast
 
       Builtins.foreach(@modified_variables) do |varid, new_value|
         ret = Builtins.add(ret, varid)
-      end 
+      end
 
 
       deep_copy(ret)
@@ -727,7 +728,7 @@ module Yast
 
       Builtins.foreach(@variable_locations) do |varid, new_value|
         ret = Builtins.add(ret, varid)
-      end 
+      end
 
 
       deep_copy(ret)
@@ -749,7 +750,7 @@ module Yast
         else
           ret = Builtins.add(ret, name, [varid])
         end
-      end 
+      end
 
 
       deep_copy(ret)
@@ -977,7 +978,7 @@ module Yast
 
           abort = true if precommandresult == :abort
         end
-      end 
+      end
 
 
       return false if abort
@@ -1066,7 +1067,7 @@ module Yast
         # progress bar label, %1 is variable name (e.g. DISPLAYMANAGER)
         Progress.Title(Builtins.sformat(_("Saving variable %1..."), name))
         Progress.NextStep
-      end 
+      end
 
 
       Progress.Title(_("Saving changes to the files..."))
@@ -1258,7 +1259,6 @@ module Yast
           ret = Builtins.add(ret, m)
         end
       end
-
       deep_copy(ret)
     end
 
