@@ -278,11 +278,13 @@ module Yast
           "Set ret %1",
           SCR.Execute(path(".target.bash_output"), cmd)
         )
-        cmd = "/bin/systemctl try-restart systemd-timedated.service"
-        Builtins.y2milestone(
-          "restarting timedated service: %1",
-          SCR.Execute(path(".target.bash_output"), cmd)
-        )
+        unless Stage.initial
+          cmd = "/bin/systemctl try-restart systemd-timedated.service"
+          Builtins.y2milestone(
+            "restarting timedated service: %1",
+            SCR.Execute(path(".target.bash_output"), cmd)
+          )
+        end
         if !Arch.s390
           cmd = Ops.add("/sbin/hwclock --hctosys ", @hwclock)
           if Stage.initial && @hwclock == "--localtime"
@@ -817,10 +819,10 @@ module Yast
       Builtins.y2milestone("Save Saved data for timezone: <%1>", @timezone)
 
       adjtime = ReadAdjTime()
-      if adjtime.size == 3 || adjtime.nil?
+      if adjtime.nil? || adjtime.size == 3
         new     = adjtime.nil? ? ["0.0 0 0.0", "0"] : adjtime.dup
         new[2]  = @hwclock == "-u" ? "UTC" : "LOCAL"
-        if new[2] != adjtime[2]
+        if adjtime.nil? || new[2] != adjtime[2]
           SCR.Write(path(".etc.adjtime"), new)
           Builtins.y2milestone("Saved /etc/adjtime with '%1'", new[2])
         end
