@@ -1,4 +1,24 @@
 #! /usr/bin/perl -w
+# ------------------------------------------------------------------------------
+# Copyright (c) 2006-2012 Novell, Inc. All Rights Reserved.
+#
+#
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of version 2 of the GNU General Public License as published by the
+# Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, contact Novell, Inc.
+#
+# To contact Novell about this file by physical or electronic mail, you may find
+# current contact information at www.novell.com.
+# ------------------------------------------------------------------------------
+#
+
 #
 # UsersLDAP module:
 # -- routines for handling LDAP users and groups
@@ -107,8 +127,6 @@ my $min_gid 			= 1000;
 my $min_pass_length		= 5;
 my $max_pass_length		= 8;
 
-# Umask which is used for creating new home directories. (/etc/login.defs)
-my $umask			= "022";
 
 # keys in user's map which are not saved anywhere, they are used for internal
 # purposes only
@@ -172,20 +190,10 @@ sub ReadAvailable {
 
     my $self 		= shift;
     my $compat		= 0;
-    my $passwd_source = SCR->Read (".etc.nsswitch_conf.passwd");
-    if (defined $passwd_source) {
-	foreach my $source (split (/ /, $passwd_source)) {
-	    if ($source eq "ldap") { return 1; }
-	    if ($source eq "compat") { $compat = 1; }
-	}
-    }
-    if ($compat) {
-	$passwd_source = SCR->Read (".etc.nsswitch_conf.passwd_compat");
-	if (defined $passwd_source) {
-	    foreach my $source (split (/ /, $passwd_source)) {
-		if ($source eq "ldap") { return 1; }
-	    }
-	}
+    my $binddn = SCR->Read (".ldap_conf.v.binddn");
+
+    if (defined $binddn) {
+	return 1;
     }
     return 0;
 }
@@ -207,7 +215,6 @@ sub Initialize {
 	ReadLdap ();
     }
     Ldap->SetGUI ($use_gui);
-
     my $ldap_mesg = Ldap->LDAPInitWithTLSCheck ({});
     if ($ldap_mesg ne "") {
 	Ldap->LDAPErrorMessage ("init", $ldap_mesg);
@@ -528,7 +535,8 @@ sub Read {
 
     my $user_attrs	= \@user_attributes;
     if (@$user_attrs < 1) {
-	$user_attrs	= [ "uid", "uidNumber", "gidNumber", "gecos", "cn", "homeDirectory", "userPassword" ];
+	$user_attrs	= [ "uid", "uidNumber", "gidNumber", "gecos", "cn",
+	    "homeDirectory", "userPassword", "objectClass" ];
 	y2milestone ("minimal set of user attrs to read: ", @$user_attrs);
     }
     my $group_attrs 	= \@group_attributes;
@@ -625,16 +633,6 @@ sub SetDefaultShadow {
     }
 }
 
-##------------------------------------
-BEGIN { $TYPEINFO{SetUmask} = ["function", "void", "string"];}
-sub SetUmask {
-
-    my $self    = shift;
-    my $u	= shift;
-    if (defined ($u) && $u ne "") {
-	$umask	= $u;
-    }
-}
 
 ##------------------------------------
 BEGIN { $TYPEINFO{GetDefaultShadow} = ["function",
@@ -1271,6 +1269,8 @@ sub WriteUsers {
     my $dn_attr 	= $user_naming_attr;
     my $last_id 	= $last_uid;
     my $users		= $_[0];
+    my $umask		= $useradd_defaults{"umask"};
+    $umask		= "022" unless $umask;
     
     # if ldap home directiories are on this machine
     my $server		= Ldap->file_server ();
@@ -1412,16 +1412,20 @@ sub WriteUsers {
 			}
 		    }
 		}
+		y2usernote ("LDAP user '$username' was created.");
 	    }
         }
         elsif ($action eq "deleted") {
 	    if (! SCR->Write (".ldap.delete", \%arg_map)) {
 		%ret = %{Ldap->LDAPErrorMap ()};
 	    }
-            elsif ($server && $delete_home) {
-                UsersRoutines->DeleteHome ($home);
-		UsersRoutines->DeleteCryptedHome ($home, $org_username);
-            }
+	    else {
+		if ($server && $delete_home) {
+		    UsersRoutines->DeleteHome ($home);
+		    UsersRoutines->DeleteCryptedHome ($home, $org_username);
+		}
+		y2usernote ("LDAP user '$username' was deleted.");
+	    }
         }
         elsif ($action eq "edited") {
 	    # if there are some attributes with empty values, agent should
@@ -1457,6 +1461,7 @@ sub WriteUsers {
 			UsersRoutines->ChownHome ($uid, $gid, $home);
 		    }
 		}
+		y2usernote ("LDAP user '$username' was modified.");
             }
         }
 	if (defined $ret{"msg"}) {
@@ -1660,14 +1665,20 @@ sub WriteGroups {
 	    if (!SCR->Write (".ldap.add",\%arg_map,$self->ConvertMap($group))) {
 		%ret 		= %{Ldap->LDAPErrorMap ()};
 	    }
-	    elsif ($gid > $last_id) {
-		$last_id	= $gid;
+	    else {
+		if ($gid > $last_id) {
+		    $last_id	= $gid;
+		}
+		y2usernote ("LDAP group '$groupname' was created.");
 	    }
         }
         elsif ($action eq "deleted") {
 	    if (!SCR->Write (".ldap.delete", \%arg_map)) {
 		%ret 		= %{Ldap->LDAPErrorMap ()};
 	    }
+	    else {
+		y2usernote ("LDAP group '$groupname' was deleted.");
+	    }
         }
         elsif ($action eq "edited") {
 
@@ -1681,8 +1692,11 @@ sub WriteGroups {
 	    if (!SCR->Write (".ldap.modify", \%arg_map, $self->ConvertMap($group))) {
 		%ret 		= %{Ldap->LDAPErrorMap ()};
 	    }
-	    elsif ($gid > $last_id) {
-		$last_id	= $gid;
+	    else {
+		if ($gid > $last_id) {
+		    $last_id	= $gid;
+		}
+		y2usernote ("LDAP group '$groupname' was modified.");
 	    }
         }
 	if (defined $ret{"msg"}) {
