@@ -1,3 +1,23 @@
+# ------------------------------------------------------------------------------
+# Copyright (c) 2006-2012 Novell, Inc. All Rights Reserved.
+#
+#
+# This program is free software; you can redistribute it and/or modify it under
+# the terms of version 2 of the GNU General Public License as published by the
+# Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program; if not, contact Novell, Inc.
+#
+# To contact Novell about this file by physical or electronic mail, you may find
+# current contact information at www.novell.com.
+# ------------------------------------------------------------------------------
+#
+
 =head1 NAME
 
 YaPI::USERS
@@ -1231,7 +1251,7 @@ sub UserGet {
 	}
     }
     # return only requested attributes...
-    if ($type eq "local" && $config->{"user_attributes"}) {
+    if (($type eq "local" || $type eq "system") && $config->{"user_attributes"}) {
 	my $attrs	= {};
 	foreach my $key (@{$config->{"user_attributes"}}) {
 	    $attrs->{$key}	= 1;
@@ -1314,7 +1334,7 @@ sub UsersGet {
     $ret	= Users->GetUsers ($index, $type);
 
     # return only requested attributes...
-    if ($type eq "local" && $config->{"user_attributes"}) {
+    if (($type eq "local" || $type eq "system") && $config->{"user_attributes"}) {
 	my $attrs	= {};
 	foreach my $key (@{$config->{"user_attributes"}}) {
 	    $attrs->{$key}	= 1;
