@@ -88,12 +88,8 @@ sub addDir {
                      'VALUE' => 'None'
                     },
                     {
-                     'KEY'   => 'Order',
-                     'VALUE' => 'allow,deny'
-                    },
-                    {
-                     'KEY'   => 'Allow',
-                     'VALUE' => 'from all'
+                     'KEY'   => 'Require',
+                     'VALUE' => 'all granted'
                     }
                   ]
     };
@@ -578,7 +574,7 @@ sub WriteListen {
      my ($ip, $fp, $tp, $port) = ('', '', '', '');
 #     if (
       $new =~ m/\[([\w\W]*)\]/; #){
-      $ip=$1;
+      $ip=$1 if ($1);
       if ($new =~ m/\[$ip\]:([\d\:]*)/){
        ($fp, $tp) = split(/:/, $1);
       } else{
